<?php
// app/helpers/document_helper.php

/**
 * Przygotowuje dane do formularza dodawania dokumentu
 *
 * @param string $entityType Typ encji (employee, vehicle, equipment)
 * @param int|null $entityId ID encji (opcjonalne)
 * @return array Dane do formularza
 */

 function generateFormFromTemplate($templateId) {
    $template = DocumentTemplate::getById($templateId);
    if (!$template || empty($template['form_structure'])) {
        return '';
    }

    $formStructure = json_decode($template['form_structure'], true);
    if (json_last_error() !== JSON_ERROR_NONE) {
        error_log("Error parsing form structure JSON: " . json_last_error_msg());
        return '';
    }

    $html = '';
    foreach ($formStructure as $field) {
        $html .= generateFormField($field);
    }

    return $html;
}

function generateFormField($field) {
    $html = '<div class="form-group">';
    $html .= '<label for="' . $field['name'] . '">' . htmlspecialchars($field['label']) . ':</label>';

    switch ($field['type']) {
        case 'text':
        case 'date':
        case 'number':
            $html .= '<input type="' . $field['type'] . '" id="' . $field['name'] . '" name="' . $field['name'] . '" ' . ($field['required'] ? 'required' : '') . '>';
            break;
        case 'textarea':
            $html .= '<textarea id="' . $field['name'] . '" name="' . $field['name'] . '" ' . ($field['required'] ? 'required' : '') . '></textarea>';
            break;
        // Add more field types as needed
    }

    $html .= '</div>';
    return $html;
}
function prepareDocumentAddForm($entityType = null, $entityId = null)
{
    $data = [
        'entityType' => $entityType,
        'entityId' => $entityId,
        'entityName' => null,
        'title' => '',
        'companyId' => null,
    ];

    if ($entityType && $entityId) {
        switch ($entityType) {
            case 'employee':
                $entity = Employee::getById($entityId);
                if ($entity) {
                    $data['entityName'] = $entity['first_name'] . ' ' . $entity['last_name'];
                    $data['title'] = 'Dokument pracownika - ' . $data['entityName'];
                    $data['companyId'] = $entity['company_id'];
                }
                break;
            case 'vehicle':
                $entity = Vehicle::getById($entityId);
                if ($entity) {
                    $data['entityName'] = $entity['brand'] . ' ' . $entity['model'] . ' (' . $entity['registration_number'] . ')';
                    $data['title'] = 'Dokument pojazdu - ' . $data['entityName'];
                    $data['companyId'] = $entity['company_id'];
                }
                break;
            case 'equipment':
                // To zostanie zaimplementowane w przyszłości
                break;
        }
    }

    return $data;
}


function getPrefilledData($entityType, $entityId) {
    $data = [
        'title' => '',
        'company_id' => '',
        'related_entity_name' => ''
    ];

    if ($entityType && $entityId) {
        switch ($entityType) {
            case 'employee':
                $employee = Employee::getById($entityId);
                if ($employee) {
                    $data['title'] = "Dokument pracownika - {$employee['first_name']} {$employee['last_name']}";
                    $data['company_id'] = $employee['company_id'];
                    $data['related_entity_name'] = "{$employee['first_name']} {$employee['last_name']}";
                }
                break;
            case 'vehicle':
                $vehicle = Vehicle::getById($entityId);
                if ($vehicle) {
                    $data['title'] = "Dokument pojazdu - {$vehicle['brand']} {$vehicle['model']}";
                    $data['company_id'] = $vehicle['company_id'];
                    $data['related_entity_name'] = "{$vehicle['brand']} {$vehicle['model']} ({$vehicle['registration_number']})";
                }
                break;
            case 'equipment':
                // To be implemented in the future
                break;
        }
    }

    return $data;
}