<?php
require_once 'model.php';

class Company extends Model {
    public static function getAll() {
        $sql = "SELECT * FROM companies ORDER BY name";
        return self::fetchAll($sql);
    }

    public static function getById($id) {
        $sql = "SELECT * FROM companies WHERE id = :id";
        return self::fetch($sql, ['id' => $id]);
    }

    public static function add($data) {
        try {
            // Logowanie próby dodania firmy
            error_log('Próba dodania nowej firmy: ' . print_r($data, true));

            $sql = "INSERT INTO companies (
                name, nip, legal_form, regon, krs, 
                address, city, postal_code, country, 
                phone, email, website, bank_name, 
                bank_account, is_active
            ) VALUES (
                :name, :nip, :legal_form, :regon, :krs,
                :address, :city, :postal_code, :country,
                :phone, :email, :website, :bank_name,
                :bank_account, :is_active
            )";

            $result = self::execute($sql, $data);
            
            if ($result) {
                error_log('Firma została dodana pomyślnie');
                return true;
            } else {
                error_log('Błąd podczas wykonywania zapytania INSERT');
                return false;
            }
        } catch (PDOException $e) {
            error_log('Błąd PDO podczas dodawania firmy: ' . $e->getMessage());
            return false;
        }
    }

    public static function update($id, $data) {
        $sql = "UPDATE companies SET 
                name = :name, nip = :nip, legal_form = :legal_form, regon = :regon, krs = :krs, 
                address = :address, city = :city, postal_code = :postal_code, country = :country, 
                phone = :phone, email = :email, website = :website, bank_name = :bank_name, 
                bank_account = :bank_account, is_active = :is_active 
                WHERE id = :id";
        $data['id'] = $id;
        return self::execute($sql, $data);
    }

    public static function delete($id) {
        try {
            self::beginTransaction();
            
            // Sprawdź powiązanych pracowników
            $sql = "SELECT COUNT(*) as count FROM employees WHERE company_id = :id";
            $result = self::fetch($sql, ['id' => $id]);
            $employeesCount = $result['count'];
            
            error_log("Sprawdzanie powiązań dla firmy ID: " . $id);
            error_log("- Liczba powiązanych pracowników: " . $employeesCount);
            
            // Sprawdź powiązane koszty
            $sql = "SELECT COUNT(*) as count FROM costs WHERE company_id = :id";
            $result = self::fetch($sql, ['id' => $id]);
            $costsCount = $result['count'];
            
            error_log("- Liczba powiązanych kosztów: " . $costsCount);
            
            if ($employeesCount > 0 || $costsCount > 0) {
                $message = "Nie można usunąć firmy - znaleziono powiązania:";
                if ($employeesCount > 0) $message .= " pracownicy: " . $employeesCount;
                if ($costsCount > 0) $message .= " koszty: " . $costsCount;
                
                error_log($message);
                self::rollBack();
                return [
                    'success' => false,
                    'message' => $message
                ];
            }
            
            // Usuń firmę
            $sql = "DELETE FROM companies WHERE id = :id";
            $result = self::execute($sql, ['id' => $id]);
            
            if ($result) {
                error_log("Firma została usunięta pomyślnie");
                self::commit();
                return ['success' => true];
            } else {
                error_log("Błąd podczas wykonywania zapytania DELETE");
                self::rollBack();
                return [
                    'success' => false,
                    'message' => "Błąd podczas usuwania firmy"
                ];
            }
        } catch (PDOException $e) {
            self::rollBack();
            error_log("Błąd PDO podczas usuwania firmy: " . $e->getMessage());
            return [
                'success' => false,
                'message' => "Wystąpił błąd podczas usuwania firmy: " . $e->getMessage()
            ];
        }
    }
}
