<?php

require_once 'model.php';

class Dashboard extends Model {
    public static function getEmployeeCount() {
        $sql = "SELECT COUNT(*) as count FROM employees WHERE active = 1";
        $result = self::fetch($sql);
        return $result['count'];
    }

    public static function getUpcomingInspections($limit = 5) {
        $sql = "SELECT vi.*, v.brand, v.model, v.registration_number 
                FROM vehicle_inspections vi 
                JOIN vehicles v ON vi.vehicle_id = v.id 
                WHERE vi.id IN (
                    SELECT MAX(vi2.id)
                    FROM vehicle_inspections vi2
                    GROUP BY vi2.vehicle_id, vi2.inspection_type
                )
                ORDER BY 
                    CASE 
                        WHEN vi.expiration_date < CURDATE() THEN 0 
                        ELSE 1 
                    END,
                    vi.expiration_date ASC 
                LIMIT " . intval($limit);
        return self::fetchAll($sql);
    }

    public static function getRecentTasks($limit = 5) {
        $sql = "SELECT * FROM tasks 
                WHERE status != 'done' 
                ORDER BY due_date ASC 
                LIMIT " . intval($limit);
        return self::fetchAll($sql);
    }

    public static function getEmployeesWithEndingContracts($daysThreshold = 30, $limit = 5) {
        $sql = "SELECT e.id, e.first_name, e.last_name, ep.end_date
                FROM employees e
                JOIN employment_periods ep ON e.id = ep.employee_id
                WHERE ep.end_date IS NOT NULL
                AND ep.end_date BETWEEN CURDATE() AND DATE_ADD(CURDATE(), INTERVAL ? DAY)
                ORDER BY ep.end_date ASC
                LIMIT " . intval($limit);
        
        return self::fetchAll($sql, [$daysThreshold]);
    }

    public static function getUpcomingVehiclePolicies()
    {
        $sql = "SELECT d.*, v.brand, v.model, v.registration_number, dc.name as category_name
                FROM documents d
                JOIN vehicles v ON d.related_entity_id = v.id
                JOIN document_categories dc ON d.category_id = dc.id
                WHERE d.related_entity_type = 'vehicle'
                AND dc.name LIKE '%olisa%'
                AND d.policy_end_date IS NOT NULL
                AND d.policy_end_date >= CURDATE()
                ORDER BY d.policy_end_date ASC
                LIMIT 10";
                
        return self::fetchAll($sql);
    }
}
