<?php
// app/models/DocumentGenerator.php

require_once 'model.php';
require_once 'documenttemplate.php';
require_once 'document.php';
require_once __DIR__ . '/../../vendor/autoload.php'; // Upewnij się, że mPDF jest zainstalowane przez Composer

use Mpdf\Mpdf;
use Mpdf\Output\Destination;

class DocumentGenerator extends Model
{
  
   

    public static function updateGeneratedDocument($data)
    {
        $document = Document::getById($data['document_id']);
        if (!$document) {
            return false;
        }

        $template = DocumentTemplate::getById($document['template_id']);
        if (!$template) {
            return false;
        }

        // Generate new PDF content
        $pdfContent = self::generatePDF($template, $data);

        // Update PDF file
        file_put_contents($document['file_path'], $pdfContent);

        // Update document in database
        $updateData = [
            'form_data' => json_encode($data)
        ];

        return Document::update($data['document_id'], $updateData);
    }

    public static function generateDocument($data) {
        error_log("Rozpoczęto generowanie dokumentu. Dane: " . print_r($data, true));
    
        $template = DocumentTemplate::getById($data['template_id']);
        if (!$template) {
            error_log("Nie znaleziono szablonu o ID: " . $data['template_id']);
            return false;
        }
    
        // Pobierz dane pracownika
        $employee = Employee::getById($data['employee_id']);
        $company = Company::getById($data['company_id']);
    
        // Przygotuj dane do wstawienia w dokument
        $documentData = [
            'employee_name' => $employee['first_name'] . ' ' . $employee['last_name'],
            'employee_first_name' => $employee['first_name'],
            'employee_last_name' => $employee['last_name'],
            'company_name' => $company['name'],
            'position' => $employee['position'],
            'instructor_name' => $_SESSION['user_name'],
            'workplace_instruction_date' => $data['workplace_instruction_date'] ?? date('Y-m-d'),
            'general_instruction_date' => $data['general_instruction_date'] ?? 
            (date('d', strtotime('today')) . '-' . date('d.m.Y', strtotime('tomorrow'))),        ];
    
        error_log("Dane do wstawienia w dokument: " . print_r($documentData, true));
    
        // Generuj zawartość PDF
        $pdfContent = self::generatePDF($template, $documentData, ['save_to_file' => true]);
    

        // Zapisz dokument w bazie danych
        $documentData = [
            'title' => $template['name'] . ' - ' . $data['employee_name'],
            'description' => 'Automatycznie wygenerowany dokument',
            'file_path' => $pdfContent,
            'file_type' => 'application/pdf',
            'category_id' => $template['category_id'],
            'company_id' => $data['company_id'],
            'related_entity_type' => 'employee',
            'related_entity_id' => $data['employee_id'],
            'created_by' => $_SESSION['user_id'],
            'is_generated' => true,
            'form_data' => json_encode($data),
            'template_id' => $data['template_id']
        ];
    
        $result = Document::add($documentData);
        if ($result) {
            error_log("Dokument zapisany w bazie danych. ID: $result");
        } else {
            error_log("Błąd podczas zapisywania dokumentu w bazie danych");
        }
    
        return $result;
    }

    public static function generatePreview($template, $data) {
        error_log("Rozpoczęto generowanie podglądu dokumentu.");
        
        // Użyj tymczasowego pliku dla podglądu
        $options = ['save_to_file' => false, 'is_preview' => true];
        
        // Jeśli tło istnieje, upewnij się, że ścieżka jest absolutna
        if (!empty($template['background_image'])) {
            if (!file_exists($template['background_image'])) {
                // Jeśli plik nie istnieje, spróbuj dodać ścieżkę bazową
                $possiblePath = realpath(__DIR__ . '/../../uploads/background/') . '/' . basename($template['background_image']);
                if (file_exists($possiblePath)) {
                    $template['background_image'] = $possiblePath;
                } else {
                    error_log("Nie znaleziono pliku tła: " . $template['background_image']);
                }
            }
        }
        
        return self::generatePDF($template, $data, $options);
    }
    public static function generatePDF($template, $data, $options = []) {
        error_log("Rozpoczęto generowanie PDF. Szablon: " . print_r($template, true));
        error_log("Dane do wstawienia: " . print_r($data, true));
        
        $mpdf = new \Mpdf\Mpdf([
            'format' => 'A4',
            'margin_left' => 0,
            'margin_right' => 0,
            'margin_top' => 0,
            'margin_bottom' => 0,
            'debug' => true
        ]);
        
        error_log("mPDF zainicjalizowany");
        
        // Przygotuj HTML z osadzonymi stylami CSS
        $css = $template['css_styles'];
        $html = $template['html_template'];
        $fullHtml = '<style>' . $css . '</style>' . $html;
        
        error_log("Pełna treść HTML z CSS: " . $fullHtml);
        
        // Zastąp placeholdery rzeczywistymi danymi
        foreach ($data as $key => $value) {
            $fullHtml = str_replace('{{' . $key . '}}', htmlspecialchars($value), $fullHtml);
        }
        
        $isPreview = isset($options['is_preview']) && $options['is_preview'];
        error_log("Czy to podgląd? " . ($isPreview ? "Tak" : "Nie"));
        
        // Dodaj tło, jeśli istnieje
        if (!empty($template['background_image'])) {
            $backgroundPath = $isPreview ? $template['background_image'] : realpath($template['background_image']);
            error_log("Próba dodania tła do dokumentu. Ścieżka: " . $backgroundPath);
            
            if (file_exists($backgroundPath)) {
                $fileInfo = pathinfo($backgroundPath);
                error_log("Typ pliku tła: " . $fileInfo['extension']);
                
                if (strtolower($fileInfo['extension']) === 'pdf') {
                    $mpdf->SetDocTemplate($backgroundPath, true);
                    error_log("Dodano tło PDF: " . $backgroundPath);
                } else {
                    $mpdf->SetDefaultBodyCSS('background', "url('" . $backgroundPath . "')");
                    $mpdf->SetDefaultBodyCSS('background-image-resize', 6);
                    error_log("Dodano tło obrazu: " . $backgroundPath);
                }
            } else {
                error_log("Plik tła nie istnieje: " . $backgroundPath);
            }
        } else {
            error_log("Brak tła do dodania");
        }
        
        error_log("Rozpoczynam renderowanie HTML");
        $mpdf->WriteHTML($fullHtml);
        error_log("HTML wyrenderowany");
        
        error_log("Zakończono generowanie PDF");
        
        if (!empty($options['save_to_file'])) {
            $filename = uniqid() . '.pdf';
            $filepath = realpath(__DIR__ . '/../../uploads/documents/') . '/' . $filename;
            $mpdf->Output($filepath, 'F');
            error_log("Zapisano plik PDF: " . $filepath);
            return $filepath;
        } else {
            return $mpdf->Output('', 'S');
        }
    }
}