<?php
// app/models/DocumentTemplate.php

class DocumentTemplate extends Model {
    // ... (pozostałe metody pozostają bez zmian)

   


    public static function getAll() {
        $sql = "SELECT dt.*, dc.name as category_name 
                FROM document_templates dt 
                LEFT JOIN document_categories dc ON dt.category_id = dc.id 
                ORDER BY dt.name";
        return self::fetchAll($sql);
    }

    public static function getById($id) {
        $sql = "SELECT dt.*, dc.name as category_name 
                FROM document_templates dt 
                LEFT JOIN document_categories dc ON dt.category_id = dc.id 
                WHERE dt.id = :id";
        $result = self::fetch($sql, ['id' => $id]);
        
        if ($result) {
            error_log("Pobrano szablon o ID: " . $id . ". Dane: " . print_r($result, true));
        } else {
            error_log("Nie znaleziono szablonu o ID: " . $id);
        }
        
        return $result;
    }

    

    public static function delete($id) {
        $sql = "DELETE FROM document_templates WHERE id = :id";
        return self::execute($sql, ['id' => $id]);
    }

    public static function getStructure($id) {
        error_log("Getting structure for template ID: " . $id);
        $template = self::getById($id);
        if (!$template) {
            error_log("Template not found for ID: " . $id);
            return null;
        }
        $structure = json_decode($template['form_structure'], true);
        if (json_last_error() !== JSON_ERROR_NONE) {
            error_log("Error parsing JSON structure: " . json_last_error_msg());
            return null;
        }
        error_log("Returned structure: " . json_encode($structure));
        return $structure;
    }
    public static function add($data) {
        error_log("Dodawanie nowego szablonu dokumentu. Dane: " . print_r($data, true));        
        // Obsługa przesyłania pliku tła
        $backgroundImage = '';
        if (isset($_FILES['background_image']) && $_FILES['background_image']['error'] == 0) {
            $backgroundImage = self::uploadBackgroundFile($_FILES['background_image']);
            if (!$backgroundImage) {
                error_log("Błąd podczas przesyłania pliku tła.");
                return false;
            }
        }
    
        $sql = "INSERT INTO document_templates (name, html_template, category_id, form_structure, css_styles, background_image) 
                VALUES (:name, :html_template, :category_id, :form_structure, :css_styles, :background_image)";
        return self::execute($sql, [
            'name' => $data['name'],
            'html_template' => $data['html_template'],
            'category_id' => $data['category_id'],
            'form_structure' => json_encode($data['form_structure'] ?? []),
            'css_styles' => $data['css_styles'] ?? '',
            'background_image' => $backgroundImage
        ]);
    }
    
    public static function update($id, $data) {
        error_log("Aktualizacja szablonu dokumentu o ID: " . $id . ". Dane: " . print_r($data, true));        
        // Pobierz aktualny rekord
        $currentTemplate = self::getById($id);
        
        // Obsługa przesyłania pliku tła
        $backgroundImage = $currentTemplate['background_image'];
        if (isset($_FILES['background_image']) && $_FILES['background_image']['error'] == 0) {
            $newBackgroundImage = self::uploadBackgroundFile($_FILES['background_image']);
            if ($newBackgroundImage) {
                // Usuń stary plik, jeśli istnieje
                if (!empty($backgroundImage) && file_exists($backgroundImage)) {
                    unlink($backgroundImage);
                }
                $backgroundImage = $newBackgroundImage;
            } else {
                error_log("Błąd podczas przesyłania nowego pliku tła.");
                return false;
            }
        }
    
        $sql = "UPDATE document_templates 
                SET name = :name, html_template = :html_template, category_id = :category_id, 
                    form_structure = :form_structure, css_styles = :css_styles, 
                    background_image = :background_image 
                WHERE id = :id";
        return self::execute($sql, [
            'id' => $id,
            'name' => $data['name'],
            'html_template' => $data['html_template'],
            'category_id' => $data['category_id'],
            'form_structure' => json_encode($data['form_structure'] ?? []),
            'css_styles' => $data['css_styles'] ?? '',
            'background_image' => $backgroundImage
        ]);
    }

       private static function uploadBackgroundFile($file) {
        $uploadDir = '/var/www/html/panel/uploads/background/';
        $allowedExtensions = ['jpg', 'jpeg', 'png', 'gif', 'pdf'];
        
        $fileName = basename($file['name']);
        $targetFile = $uploadDir . uniqid() . '_' . $fileName;
        $fileType = strtolower(pathinfo($targetFile, PATHINFO_EXTENSION));

        // Sprawdź, czy rozszerzenie pliku jest dozwolone
        if (!in_array($fileType, $allowedExtensions)) {
            error_log("Niedozwolony typ pliku: " . $fileType);
            return false;
        }

        // Przenieś plik do docelowego katalogu
        if (move_uploaded_file($file['tmp_name'], $targetFile)) {
            error_log("Plik tła przesłany pomyślnie: " . $targetFile);
            return $targetFile;
        } else {
            error_log("Błąd podczas przesyłania pliku tła. Szczegóły: " . print_r($file, true));
            return false;
        }
    }

}