<?php

require_once 'model.php';

class Employee extends Model
{
    public static function add($first_name, $last_name, $pesel, $nip, $date_of_birth, $gender, $address, $city, $postal_code, $country, $phone_number, $email, $position, $hire_date, $created_by, $company_id, $id_card_number = null, $driving_license_number = null)
    {
        try {
            self::beginTransaction();

            $sql = "INSERT INTO employees (first_name, last_name, pesel, nip, date_of_birth, gender, address, city, postal_code, country, phone_number, email, position, created_by, company_id, id_card_number, driving_license_number, created_at, updated_at) 
                VALUES (:first_name, :last_name, :pesel, :nip, :date_of_birth, :gender, :address, :city, :postal_code, :country, :phone_number, :email, :position, :created_by, :company_id, :id_card_number, :driving_license_number, NOW(), NOW())";
            self::execute($sql, [
                'first_name' => $first_name,
                'last_name' => $last_name,
                'pesel' => $pesel,
                'nip' => $nip,
                'date_of_birth' => $date_of_birth,
                'gender' => $gender,
                'address' => $address,
                'city' => $city,
                'postal_code' => $postal_code,
                'country' => $country,
                'phone_number' => $phone_number,
                'email' => $email,
                'position' => $position,
                'created_by' => $created_by,
                'company_id' => $company_id,
                'id_card_number' => $id_card_number,
                'driving_license_number' => $driving_license_number
            ]);


            $employee_id = self::lastInsertId();

            $sql = "INSERT INTO employment_periods (employee_id, start_date, created_by, created_at, updated_at) 
                    VALUES (:employee_id, :start_date, :created_by, NOW(), NOW())";

            self::execute($sql, [
                'employee_id' => $employee_id,
                'start_date' => $hire_date,
                'created_by' => $created_by
            ]);

            self::commit();
            return true;
        } catch (PDOException $e) {
            self::rollBack();
            error_log("Błąd podczas dodawania pracownika: " . $e->getMessage());
            return false;
        }
    }

    public static function getAll($filter = 'all', $search = '', $company_id = null)
    {
        $sql = "SELECT e.*, 
                CASE WHEN ep.end_date IS NULL THEN 'Aktywny' ELSE 'Zwolniony' END AS status,
                ep.start_date as hire_date,
                ep.end_date as termination_date,
                c.name as company_name
                FROM employees e
                LEFT JOIN (
                    SELECT employee_id, MAX(start_date) as last_start_date
                    FROM employment_periods
                    GROUP BY employee_id
                ) last_period ON e.id = last_period.employee_id
                LEFT JOIN employment_periods ep ON ep.employee_id = e.id AND ep.start_date = last_period.last_start_date
                LEFT JOIN companies c ON e.company_id = c.id
                WHERE 1=1";

        $params = [];

        if ($company_id) {
            $sql .= " AND e.company_id = :company_id";
            $params['company_id'] = $company_id;
        }

        if ($filter === 'active') {
            $sql .= " AND ep.end_date IS NULL";
        } elseif ($filter === 'inactive') {
            $sql .= " AND ep.end_date IS NOT NULL";
        }

        if ($search !== '') {
            $sql .= " AND (e.first_name LIKE :search OR e.last_name LIKE :search OR e.pesel LIKE :search OR e.email LIKE :search OR CONCAT(e.first_name, ' ', e.last_name) LIKE :search OR CONCAT(e.last_name, ' ', e.first_name) LIKE :search)";
            $params['search'] = "%$search%";
        }

        $sql .= " ORDER BY e.last_name, e.first_name";

        return self::fetchAll($sql, $params);
    }

    public static function getById($id)
    {
        $sql = "SELECT e.*, 
                CASE WHEN ep.end_date IS NULL THEN 'Aktywny' ELSE 'Zwolniony' END AS status,
                ep.start_date as hire_date,
                ep.end_date as termination_date,
                c.name as company_name
                FROM employees e
                LEFT JOIN (
                    SELECT employee_id, MAX(start_date) as last_start_date
                    FROM employment_periods
                    GROUP BY employee_id
                ) last_period ON e.id = last_period.employee_id
                LEFT JOIN employment_periods ep ON ep.employee_id = e.id AND ep.start_date = last_period.last_start_date
                LEFT JOIN companies c ON e.company_id = c.id
                WHERE e.id = :id";
        return self::fetch($sql, ['id' => $id]);
    }
    public static function update($id, $data)
    {
        $sql = "UPDATE employees SET 
                first_name = :first_name, 
                last_name = :last_name, 
                pesel = :pesel, 
                nip = :nip,
                date_of_birth = :date_of_birth,
                gender = :gender,
                address = :address,
                city = :city,
                postal_code = :postal_code,
                country = :country,
                phone_number = :phone_number, 
                email = :email, 
                company_id = :company_id,
                position = :position,
                id_card_number = :id_card_number,
                driving_license_number = :driving_license_number,
                updated_at = NOW() 
                WHERE id = :id";

        $params = $data;
        $params['id'] = $id;

        // Upewnij się, że wszystkie wymagane pola są obecne
        $requiredFields = ['first_name', 'last_name', 'pesel', 'date_of_birth', 'gender', 'address', 'city', 'postal_code', 'country', 'position'];
        foreach ($requiredFields as $field) {
            if (!isset($params[$field])) {
                $params[$field] = null;
            }
        }

        return self::execute($sql, $params);
    }
    public static function getEmploymentPeriods($employeeId)
    {
        $sql = "SELECT * FROM employment_periods WHERE employee_id = :employee_id ORDER BY start_date DESC";
        return self::fetchAll($sql, ['employee_id' => $employeeId]);
    }

    public static function addEmploymentPeriod($employeeId, $startDate, $createdBy, $endDate = null)
    {
        $sql = "INSERT INTO employment_periods (employee_id, start_date, end_date, created_by, created_at, updated_at) 
                VALUES (:employee_id, :start_date, :end_date, :created_by, NOW(), NOW())";
        return self::execute($sql, [
            'employee_id' => $employeeId,
            'start_date' => $startDate,
            'end_date' => $endDate,
            'created_by' => $createdBy
        ]);
    }

    public static function editEmploymentPeriod($periodId, $startDate, $endDate, $removeEndDate = false)
    {
        $sql = "UPDATE employment_periods 
                SET start_date = :start_date, 
                    end_date = :end_date, 
                    updated_at = NOW() 
                WHERE id = :id";

        $params = [
            'id' => $periodId,
            'start_date' => $startDate,
            'end_date' => $removeEndDate ? null : $endDate
        ];

        return self::execute($sql, $params);
    }

    public static function endEmploymentPeriod($periodId, $endDate)
    {
        $sql = "UPDATE employment_periods 
                SET end_date = :end_date, updated_at = NOW() 
                WHERE id = :id";
        return self::execute($sql, [
            'id' => $periodId,
            'end_date' => $endDate
        ]);
    }
    public static function getEmploymentPeriodById($id)
    {
        $sql = "SELECT * FROM employment_periods WHERE id = :id";
        return self::fetch($sql, ['id' => $id]);
    }

    public static function deleteEmploymentPeriod($id)
    {
        $sql = "DELETE FROM employment_periods WHERE id = :id";
        return self::execute($sql, ['id' => $id]);
    }
    public static function getLastEmploymentPeriod($employeeId)
{
    $sql = "SELECT * FROM employment_periods 
            WHERE employee_id = :employee_id 
            ORDER BY start_date DESC 
            LIMIT 1";
    return self::fetch($sql, ['employee_id' => $employeeId]);
}

    public static function getSearchSuggestions($search, $company_id = null)
    {
        $sql = "SELECT e.id, CONCAT(e.last_name, ' ', e.first_name) as name, e.position,
                   c.name as company_name,
                   CASE WHEN ep.end_date IS NULL THEN 'Aktywny' ELSE 'Zwolniony' END AS status
            FROM employees e
            LEFT JOIN companies c ON e.company_id = c.id
            LEFT JOIN (
                SELECT employee_id, MAX(start_date) as last_start_date
                FROM employment_periods
                GROUP BY employee_id
            ) last_period ON e.id = last_period.employee_id
            LEFT JOIN employment_periods ep ON ep.employee_id = e.id AND ep.start_date = last_period.last_start_date
            WHERE (e.last_name LIKE :search OR e.first_name LIKE :search OR e.position LIKE :search OR CONCAT(e.first_name, ' ', e.last_name) LIKE :search OR CONCAT(e.last_name, ' ', e.first_name) LIKE :search)";
    
        $params = ['search' => "%$search%"];

        if ($company_id) {
            $sql .= " AND e.company_id = :company_id";
            $params['company_id'] = $company_id;
        }

        $sql .= " LIMIT 5";

        return self::fetchAll($sql, $params);
    }

    public static function delete($id)
    {
        try {
            self::beginTransaction();
            
            // Usuń powiązane okresy zatrudnienia
            $sql = "DELETE FROM employment_periods WHERE employee_id = :id";
            self::execute($sql, ['id' => $id]);
            
            // Usuń pracownika
            $sql = "DELETE FROM employees WHERE id = :id";
            self::execute($sql, ['id' => $id]);
            
            self::commit();
            return true;
        } catch (PDOException $e) {
            self::rollBack();
            error_log("Błąd podczas usuwania pracownika: " . $e->getMessage());
            return false;
        }
    }
}
