<?php
// app/models/equipment.php

require_once 'model.php';

class Equipment extends Model {
    public static function getAll() {
        $sql = "SELECT e.*, c.name as company_name 
                FROM equipment e 
                LEFT JOIN companies c ON e.company_id = c.id 
                ORDER BY e.name";
        return self::fetchAll($sql);
    }

    public static function getById($id) {
        $sql = "SELECT e.*, c.name as company_name 
                FROM equipment e 
                LEFT JOIN companies c ON e.company_id = c.id 
                WHERE e.id = :id";
        return self::fetch($sql, ['id' => $id]);
    }

    public static function add($data) {
        $sql = "INSERT INTO equipment (name, company_id, serial_number, description, purchase_date, category, status, last_maintenance_date, next_maintenance_date) 
                VALUES (:name, :company_id, :serial_number, :description, :purchase_date, :category, :status, :last_maintenance_date, :next_maintenance_date)";
        
        // Ustawienie domyślnych wartości dla opcjonalnych pól
        $data['serial_number'] = $data['serial_number'] ?? null;
        $data['description'] = $data['description'] ?? null;
        $data['purchase_date'] = (!empty($data['purchase_date'])) ? $data['purchase_date'] : null;
        $data['category'] = $data['category'] ?? null;
        $data['status'] = $data['status'] ?? 'active';
        $data['last_maintenance_date'] = (!empty($data['last_maintenance_date'])) ? $data['last_maintenance_date'] : null;
        $data['next_maintenance_date'] = (!empty($data['next_maintenance_date'])) ? $data['next_maintenance_date'] : null;
        
        return self::execute($sql, $data);
    }

    public static function update($id, $data) {
        $sql = "UPDATE equipment SET 
                name = :name, 
                company_id = :company_id,
                serial_number = :serial_number, 
                description = :description, 
                purchase_date = :purchase_date, 
                category = :category,
                status = :status,
                last_maintenance_date = :last_maintenance_date,
                next_maintenance_date = :next_maintenance_date
                WHERE id = :id";
        
        // Ustawienie domyślnych wartości dla opcjonalnych pól
        $data['serial_number'] = $data['serial_number'] ?? null;
        $data['description'] = $data['description'] ?? null;
        $data['purchase_date'] = (!empty($data['purchase_date'])) ? $data['purchase_date'] : null;
        $data['category'] = $data['category'] ?? null;
        $data['status'] = $data['status'] ?? 'active';
        $data['last_maintenance_date'] = (!empty($data['last_maintenance_date'])) ? $data['last_maintenance_date'] : null;
        $data['next_maintenance_date'] = (!empty($data['next_maintenance_date'])) ? $data['next_maintenance_date'] : null;
        
        $data['id'] = $id;
        return self::execute($sql, $data);
    }

    public static function delete($id) {
        $sql = "DELETE FROM equipment WHERE id = :id";
        return self::execute($sql, ['id' => $id]);
    }
}