<?php

class Model {
    protected static $db;

    protected static function getDB() {
        if (!isset(self::$db)) {
            $config = require __DIR__ . '/../../config/database.php';
            try {
                self::$db = new PDO(
                    "mysql:host={$config['host']};dbname={$config['dbname']};charset=utf8mb4",
                    $config['user'],
                    $config['password'],
                    [PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION]
                );
            } catch (PDOException $e) {
                debug_log("Nie można połączyć się z bazą danych", $e->getMessage());
                throw new Exception("Problem z połączeniem do bazy danych.");
            }
        }
        return self::$db;
    }

    protected static function execute($sql, $params = []) {
        $db = self::getDB();
        $stmt = $db->prepare($sql);
        
        // Logowanie tylko dla zapytań innych niż SELECT
        if (!preg_match('/^SELECT/i', $sql)) {
            debug_log("Model::execute - SQL", $sql);
            debug_log("Model::execute - Params", $params);
        }
        
        $stmt->execute($params);
        return $stmt;
    }

    protected static function fetch($sql, $params = []) {
        $stmt = self::execute($sql, $params);
        return $stmt->fetch(PDO::FETCH_ASSOC);
    }

    protected static function fetchAll($sql, $params = []) {
        try {
            debug_log("Model::execute - SQL", $sql);
            debug_log("Model::execute - Params", $params);
            
            $stmt = self::execute($sql, $params);
            $result = $stmt->fetchAll(PDO::FETCH_ASSOC);
            
            debug_log("Model::fetchAll - Liczba zwróconych wyników", count($result));
            
            return $result;
        } catch (PDOException $e) {
            debug_log("SQL Error", [
                'message' => $e->getMessage(),
                'query' => $sql,
                'params' => $params
            ]);
            throw $e;
        }
    }

    public static function lastInsertId() {
        return self::getDB()->lastInsertId();
    }

    protected static function beginTransaction() {
        self::getDB()->beginTransaction();
    }

    protected static function commit() {
        self::getDB()->commit();
    }

    protected static function rollBack() {
        self::getDB()->rollBack();
    }

    public static function query($sql, $params = []) {
        debug_log("Model::query - SQL", $sql);
        debug_log("Model::query - Params", $params);
        
        try {
            $stmt = self::$db->prepare($sql);
            $stmt->execute($params);
            $result = $stmt->fetchAll(PDO::FETCH_ASSOC);
            debug_log("Model::query - Liczba zwróconych wyników", count($result));
            return $result;
        } catch (PDOException $e) {
            debug_log("Database error", $e->getMessage());
            throw $e;
        }
    }
}
