<?php

require_once 'model.php';

class User extends Model {
    public static function getByEmail($email) {
        $sql = "SELECT * FROM users WHERE email = :email";
        return self::fetch($sql, ['email' => $email]);
    }

    public static function add($name, $email, $password, $role = 'user', $phone_number = null) {
        $sql = "INSERT INTO users (name, email, password, role, phone_number, created_at, updated_at) 
                VALUES (:name, :email, :password, :role, :phone_number, NOW(), NOW())";
        return self::execute($sql, [
            'name' => $name,
            'email' => $email,
            'password' => $password,
            'role' => $role,
            'phone_number' => $phone_number
        ]);
    }

    public static function getAll() {
        $sql = "SELECT id, name, email, role, phone_number FROM users ORDER BY name";
        return self::fetchAll($sql);
    }

    public static function getById($id) {
        $sql = "SELECT id, name, email, role, phone_number FROM users WHERE id = :id";
        return self::fetch($sql, ['id' => $id]);
    }

   public static function update($id, $data) {
    $sql = "UPDATE users SET ";
    $params = [];
    
    foreach ($data as $key => $value) {
        if ($key !== 'id') {
            $sql .= "$key = :$key, ";
            $params[$key] = $value;
        }
    }
    
    $sql = rtrim($sql, ", ");
    $sql .= " WHERE id = :id";
    $params['id'] = $id;
    
    error_log("Executing SQL: " . $sql);
    error_log("With data: " . print_r($params, true));
    
    $result = self::execute($sql, $params);
    
    error_log("SQL execution result: " . ($result ? "success" : "failure"));
    
    return $result;
}
public static function updateProfile($id, $data) {
    $allowedFields = ['name', 'email', 'phone_number'];
    $filteredData = array_intersect_key($data, array_flip($allowedFields));
    
    $sql = "UPDATE users SET ";
    $params = [];
    
    foreach ($filteredData as $key => $value) {
        $sql .= "$key = :$key, ";
        $params[$key] = $value;
    }
    
    $sql = rtrim($sql, ", ");
    $sql .= ", updated_at = NOW() WHERE id = :id";
    $params['id'] = $id;
    
    error_log("Executing profile update SQL: " . $sql);
    error_log("With data: " . print_r($params, true));
    
    $result = self::execute($sql, $params);
    
    error_log("Profile update SQL execution result: " . ($result ? "success" : "failure"));
    
    return $result;
}

    public static function updatePassword($id, $password) {
        $sql = "UPDATE users SET password = :password, updated_at = NOW() WHERE id = :id";
        return self::execute($sql, ['id' => $id, 'password' => $password]);
    }

    public static function delete($id) {
        $sql = "DELETE FROM users WHERE id = :id";
        return self::execute($sql, ['id' => $id]);
    }
}