<?php

require_once 'model.php';

class VehicleInspection extends Model
{
    public static function getAll()
    {
        $sql = "SELECT vi.*, v.brand, v.model, v.registration_number 
                FROM vehicle_inspections vi 
                JOIN vehicles v ON vi.vehicle_id = v.id 
                ORDER BY vi.inspection_date DESC";
        return self::fetchAll($sql);
    }
    public static function getAllForVehicle($vehicleId)
    {
        $sql = "SELECT * FROM vehicle_inspections WHERE vehicle_id = :vehicle_id ORDER BY inspection_date DESC";
        return self::fetchAll($sql, ['vehicle_id' => $vehicleId]);
    }
    public static function getById($id)
    {
        $sql = "SELECT * FROM vehicle_inspections WHERE id = :id";
        return self::fetch($sql, ['id' => $id]);
    }

    public static function add($data)
    {
        // Jeśli vehicle_id nie jest ustawione, a mamy selected_vehicle, użyj jego id
        if (!isset($data['vehicle_id']) && isset($data['selected_vehicle'])) {
            $data['vehicle_id'] = $data['selected_vehicle']['id'];
        }
    
        $sql = "INSERT INTO vehicle_inspections (vehicle_id, inspection_date, expiration_date, inspection_type, mileage, service_actions, notes, created_by, created_at, updated_at) 
                VALUES (:vehicle_id, :inspection_date, :expiration_date, :inspection_type, :mileage, :service_actions, :notes, :created_by, NOW(), NOW())";
        return self::execute($sql, [
            'vehicle_id' => $data['vehicle_id'],
            'inspection_date' => $data['inspection_date'],
            'expiration_date' => $data['expiration_date'],
            'inspection_type' => $data['inspection_type'],
            'mileage' => $data['mileage'],
            'service_actions' => $data['service_actions'] ?? null,
            'notes' => $data['notes'] ?? null,
            'created_by' => $data['created_by']
        ]);
    }

    public static function update($id, $data)
    {
        $sql = "UPDATE vehicle_inspections 
                SET vehicle_id = :vehicle_id, 
                    inspection_date = :inspection_date,
                    expiration_date = :expiration_date,
                    inspection_type = :inspection_type,
                    mileage = :mileage,
                    service_actions = :service_actions,
                    notes = :notes,
                    updated_at = NOW()
                WHERE id = :id";
        return self::execute($sql, [
            'id' => $id,
            'vehicle_id' => $data->vehicle_id,
            'inspection_date' => $data->inspection_date,
            'expiration_date' => $data->expiration_date,
            'inspection_type' => $data->inspection_type,
            'mileage' => $data->mileage,
            'service_actions' => $data->service_actions,
            'notes' => $data->notes
        ]);
    }

    public static function delete($id)
    {
        $sql = "DELETE FROM vehicle_inspections WHERE id = :id";
        return self::execute($sql, ['id' => $id]);
    }


    public static function getUpcoming()
    {
        $today = date('Y-m-d');
        $oneMonthLater = date('Y-m-d', strtotime('+1 month'));

        $sql = "SELECT vi.*, v.brand, v.model, v.registration_number,
                       (SELECT mileage FROM vehicle_monthly_mileages WHERE vehicle_id = v.id ORDER BY mileage_date DESC LIMIT 1) as current_mileage
                FROM vehicle_inspections vi 
                JOIN vehicles v ON vi.vehicle_id = v.id 
                WHERE (vi.expiration_date BETWEEN :today AND :one_month_later)
                   OR (vi.inspection_type = 'serwisowy' AND 
                       (SELECT CASE 
                           WHEN (SELECT mileage FROM vehicle_monthly_mileages WHERE vehicle_id = v.id ORDER BY mileage_date DESC LIMIT 1) > vi.mileage 
                           THEN (SELECT mileage FROM vehicle_monthly_mileages WHERE vehicle_id = v.id ORDER BY mileage_date DESC LIMIT 1) - vi.mileage
                           ELSE 0
                       END) >= 14000)
                ORDER BY vi.expiration_date ASC";

        return self::fetchAll($sql, ['today' => $today, 'one_month_later' => $oneMonthLater]);
    }
    public static function getDetailsById($id)
    {
        $sql = "SELECT vi.*, v.brand as vehicle_brand, v.model as vehicle_model, v.registration_number as vehicle_registration_number
                FROM vehicle_inspections vi
                JOIN vehicles v ON vi.vehicle_id = v.id
                WHERE vi.id = :id";
        return self::fetch($sql, ['id' => $id]);
    }
}