<?php
// W pliku app/routes/company_routes.php

Flight::route('GET /companies', function() {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $companies = Company::getAll();
        Flight::render('company_list', ['companies' => $companies]);
    }
});

Flight::route('GET /company/add', function() {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        Flight::render('company_add');
    }
});

Flight::route('POST /company/add', function() {
    if (!isLoggedIn()) {
        Flight::redirect('/');
        return;
    }

    try {
        $data = Flight::request()->data->getData();
        
        // Logowanie otrzymanych danych
        error_log('Otrzymane dane firmy: ' . print_r($data, true));
        
        // Podstawowa walidacja
        if (empty($data['name']) || empty($data['nip'])) {
            error_log('Brak wymaganych pól: nazwa lub NIP');
            Flight::redirect('/company/add?error=Nazwa i NIP są wymagane');
            return;
        }

        // Przygotowanie danych
        $companyData = [
            'name' => $data['name'],
            'nip' => $data['nip'],
            'legal_form' => $data['legal_form'] ?? '',
            'regon' => $data['regon'] ?? '',
            'krs' => $data['krs'] ?? '',
            'address' => $data['address'] ?? '',
            'city' => $data['city'] ?? '',
            'postal_code' => $data['postal_code'] ?? '',
            'country' => $data['country'] ?? 'Polska',
            'phone' => $data['phone'] ?? '',
            'email' => $data['email'] ?? '',
            'website' => $data['website'] ?? '',
            'bank_name' => $data['bank_name'] ?? '',
            'bank_account' => $data['bank_account'] ?? '',
            'is_active' => isset($data['is_active']) ? 1 : 0
        ];

        $result = Company::add($companyData);
        
        if ($result) {
            Flight::redirect('/companies?success=Firma została dodana');
        } else {
            error_log('Błąd podczas dodawania firmy');
            Flight::redirect('/company/add?error=Nie udało się dodać firmy');
        }
    } catch (Exception $e) {
        error_log('Błąd podczas dodawania firmy: ' . $e->getMessage());
        Flight::redirect('/company/add?error=Wystąpił błąd podczas dodawania firmy');
    }
});

Flight::route('GET /company/edit/@id', function($id) {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $company = Company::getById($id);
        Flight::render('company_edit', ['company' => $company]);
    }
});

Flight::route('POST /company/edit/@id', function($id) {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $data = Flight::request()->data->getData();
        $data['is_active'] = isset($data['is_active']) ? 1 : 0;
        
        $result = Company::update($id, $data);
        
        if ($result) {
            Flight::redirect('/companies?success=Firma została zaktualizowana');
        } else {
            Flight::redirect("/company/edit/$id?error=Nie udało się zaktualizować firmy");
        }
    }
});

Flight::route('POST /company/delete/@id', function($id) {
    if (!isLoggedIn()) {
        Flight::json(['success' => false, 'message' => 'Brak autoryzacji'], 401);
        return;
    }

    try {
        // Sprawdź czy firma istnieje
        $company = Company::getById($id);
        if (!$company) {
            Flight::json(['success' => false, 'message' => 'Firma nie istnieje'], 404);
            return;
        }

        $result = Company::delete($id);
        
        if ($result['success']) {
            Flight::json(['success' => true]);
        } else {
            Flight::json([
                'success' => false, 
                'message' => $result['message'] ?? 'Wystąpił nieznany błąd'
            ], 400);
        }
    } catch (Exception $e) {
        error_log('Błąd podczas usuwania firmy: ' . $e->getMessage());
        Flight::json([
            'success' => false,
            'message' => 'Wystąpił błąd serwera'
        ], 500);
    }
});
