<?php


Flight::route('GET /costs', function() {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        try {
            $companies = Company::getAll();
            $costTypes = CostType::getAll();
            $costs = Cost::getAll();
            
            error_log("Costs data in route: " . print_r($costs, true));
            
            Flight::render('cost_list', [
                'companies' => $companies,
                'costTypes' => $costTypes,
                'costs' => $costs
            ]);
        } catch (Exception $e) {
            error_log("Error in /costs route: " . $e->getMessage());
            Flight::error($e);
        }
    }
});

Flight::route('GET /cost/add', function() {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $companies = Company::getAll();
        $costTypes = CostType::getAll();
        $vehicles = Vehicle::getAll();
        $equipment = Equipment::getAll();
        $employees = Employee::getAll();

        // Pobierz preferencje użytkownika
        $userId = $_SESSION['user_id'];
        $lastCompanyId = UserPreference::get($userId, 'last_company_id');
        $lastCostTypeId = UserPreference::get($userId, 'last_cost_type_id');
        $lastRelationType = UserPreference::get($userId, 'last_relation_type');

        Flight::render('cost_add', [
            'companies' => $companies, 
            'costTypes' => $costTypes,
            'vehicles' => $vehicles,
            'equipment' => $equipment,
            'employees' => $employees,
            'lastCompanyId' => $lastCompanyId,
            'lastCostTypeId' => $lastCostTypeId,
            'lastRelationType' => $lastRelationType
        ]);
    }
});

Flight::route('POST /cost/add', function() {
    if (!isLoggedIn()) {
        Flight::redirect('/');
        return;
    }

    $userId = $_SESSION['user_id'];
    if (!$userId) {
        Flight::redirect('/cost/add?error=Brak zalogowanego użytkownika');
        return;
    }

    $data = Flight::request()->data->getData();
    
    // Walidacja i przygotowanie danych
    $requiredFields = ['company_id', 'amount'];
    foreach ($requiredFields as $field) {
        if (empty($data[$field])) {
            Flight::redirect('/cost/add?error=Pola Firma i Kwota są wymagane');
            return;
        }
    }
    
    try {
        $costId = Cost::add($data);
        
        if ($costId) {
            // Zapisz preferencje użytkownika
            UserPreference::set($userId, 'last_company_id', $data['company_id']);
            UserPreference::set($userId, 'last_cost_type_id', $data['cost_type_id']);
            if (!empty($data['relation_type']) && $data['relation_type'] !== 'none') {
                UserPreference::set($userId, 'last_relation_type', $data['relation_type']);
            }

            Flight::redirect('/cost/add?success=Koszt został dodany');
        } else {
            Flight::redirect('/cost/add?error=Nie udało się dodać kosztu');
        }
    } catch (Exception $e) {
        error_log("Exception in cost add: " . $e->getMessage());
        Flight::redirect('/cost/add?error=' . urlencode('Wystąpił błąd podczas dodawania kosztu: ' . $e->getMessage()));
    }
});

Flight::route('GET /cost/edit/@id', function($id) {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $cost = Cost::getById($id);
        $companies = Company::getAll();
        $costTypes = CostType::getAll();
        $vehicles = Vehicle::getAll();
        $equipment = Equipment::getAll();
        $employees = Employee::getAll();

        // Pobierz informacje o powiązanym obiekcie
        $costRelation = CostRelation::getByCostId($id);
        if ($costRelation) {
            $cost['relation_type'] = $costRelation['relation_type'];
            $cost['related_id'] = $costRelation['related_id'];
        } else {
            $cost['relation_type'] = 'none';
            $cost['related_id'] = null;
        }

        Flight::render('cost_edit', [
            'cost' => $cost, 
            'companies' => $companies, 
            'costTypes' => $costTypes,
            'vehicles' => $vehicles,
            'equipment' => $equipment,
            'employees' => $employees
        ]);
    }
});

Flight::route('POST /cost/edit/@id', function($id) {
    error_log("\n=== START COST EDIT REQUEST ===");
    error_log("Timestamp: " . date('Y-m-d H:i:s'));
    error_log("Editing cost ID: $id");
    
    if (!isLoggedIn()) {
        error_log("Authentication failed - user not logged in");
        Flight::redirect('/');
        return;
    }

    $data = Flight::request()->data->getData();
    error_log("Received POST data:");
    error_log(print_r($data, true));

    // Explicitly set is_general based on checkbox
    $data['is_general'] = isset($data['is_general']) && $data['is_general'] == '1' ? 1 : 0;
    
    // Ensure relation data is properly handled when is_general is false
    if (!$data['is_general'] && !empty($data['relation_type']) && $data['relation_type'] !== 'none') {
        if (empty($data['related_id'])) {
            Flight::redirect("/cost/edit/$id?error=Wybierz powiązany obiekt");
            return;
        }
    }
    
    try {
        error_log("Attempting to update cost in database");
        $currentCost = Cost::getById($id);
        error_log("Current cost data:");
        error_log(print_r($currentCost, true));
        
        $result = Cost::update($id, $data);
        
        if ($result) {
            error_log("Cost updated successfully");
            Flight::redirect('/costs?success=Koszt został zaktualizowany');
        } else {
            error_log("Failed to update cost - update method returned false");
            Flight::redirect("/cost/edit/$id?error=Nie udało się zaktualizować kosztu");
        }
    } catch (Exception $e) {
        error_log("Exception during cost update:");
        error_log("Message: " . $e->getMessage());
        error_log("Stack trace:");
        error_log($e->getTraceAsString());
        Flight::redirect("/cost/edit/$id?error=" . urlencode('Wystąpił błąd podczas aktualizacji kosztu: ' . $e->getMessage()));
    }
    
    error_log("=== END COST EDIT REQUEST ===\n");
});

Flight::route('POST /cost/delete/@id', function($id) {
    if (!isLoggedIn()) {
        Flight::json(['success' => false, 'message' => 'Unauthorized'], 401);
        return;
    }

    $result = Cost::delete($id);
    
    if ($result) {
        Flight::json(['success' => true]);
    } else {
        Flight::json(['success' => false, 'message' => 'Nie udało się usunąć kosztu'], 500);
    }
});

Flight::route('GET /get-related-entities/@type', function($type) {
    if (!isLoggedIn()) {
        Flight::json(['error' => 'Unauthorized'], 401);
        return;
    }

    try {
        $result = [];
        switch ($type) {
            case 'vehicle':
                $vehicles = Vehicle::getAll();
                $result = array_map(function($vehicle) {
                    return [
                        'id' => $vehicle['id'],
                        'name' => $vehicle['brand'] . ' ' . $vehicle['model'] . ' (' . $vehicle['registration_number'] . ')'
                    ];
                }, $vehicles);
                break;
                
            case 'equipment':
                $equipment = Equipment::getAll();
                $result = array_map(function($item) {
                    return [
                        'id' => $item['id'],
                        'name' => $item['name'] . ' (SN: ' . $item['serial_number'] . ')'
                    ];
                }, $equipment);
                break;
                
            case 'employee':
                $employees = Employee::getAll();
                $result = array_map(function($employee) {
                    return [
                        'id' => $employee['id'],
                        'name' => $employee['first_name'] . ' ' . $employee['last_name']
                    ];
                }, $employees);
                break;
            
            default:
                Flight::json(['error' => 'Invalid entity type'], 400);
                return;
        }
        
        Flight::json($result);
    } catch (Exception $e) {
        error_log("Error in get-related-entities: " . $e->getMessage());
        Flight::json(['error' => $e->getMessage()], 500);
    }
});

Flight::route('GET /api/get-related-objects/@type', function($type) {
    if (!isLoggedIn()) {
        Flight::json(['error' => 'Unauthorized'], 401);
        return;
    }

    $objects = [];
    switch ($type) {
        case 'vehicle':
            $objects = Vehicle::getAll();
            break;
        case 'equipment':
            $objects = Equipment::getAll();
            break;
        case 'employee':
            $objects = Employee::getAll();
            break;
        default:
            Flight::json(['error' => 'Invalid type'], 400);
            return;
    }

    $result = array_map(function($obj) {
        return [
            'id' => $obj['id'],
            'name' => $obj['name'] ?? $obj['first_name'] . ' ' . $obj['last_name'] ?? $obj['model']
        ];
    }, $objects);

    Flight::json($result);
});

// Dodaj nowy route dla API kosztów
Flight::route('GET /api/costs', function() {
    if (!isLoggedIn()) {
        Flight::json(['error' => 'Unauthorized'], 401);
        return;
    }

    try {
        $rawData = Flight::request()->query->getData();
        error_log("Filtry otrzymane w API: " . print_r($rawData, true));
        
        $costs = Cost::getFiltered($rawData);
        $total = Cost::calculateTotal($rawData);
        
        Flight::json([
            'success' => true,
            'data' => $costs,
            'total' => $total
        ]);
    } catch (Exception $e) {
        error_log("Błąd w /api/costs: " . $e->getMessage());
        Flight::json(['error' => $e->getMessage()], 500);
    }
});

Flight::route('GET /cost/details/@id', function($id) {
    if (!isLoggedIn()) {
        Flight::redirect('/');
        return;
    }

    try {
        $cost = Cost::getById($id);
        
        if (!$cost) {
            Flight::notFound();
            return;
        }

        // Pobierz nazwę powiązanego obiektu, jeśli istnieje
        $relatedEntityName = '';
        if (!empty($cost['relation_type']) && $cost['relation_type'] !== 'none' && !empty($cost['related_id'])) {
            switch ($cost['relation_type']) {
                case 'vehicle':
                    $vehicle = Vehicle::getById($cost['related_id']);
                    $relatedEntityName = $vehicle ? $vehicle['brand'] . ' ' . $vehicle['model'] : '';
                    break;
                case 'equipment':
                    $equipment = Equipment::getById($cost['related_id']);
                    $relatedEntityName = $equipment ? $equipment['name'] : '';
                    break;
                case 'employee':
                    $employee = Employee::getById($cost['related_id']);
                    $relatedEntityName = $employee ? $employee['first_name'] . ' ' . $employee['last_name'] : '';
                    break;
            }
        }

        Flight::render('cost_details', [
            'cost' => $cost,
            'relatedEntityName' => $relatedEntityName
        ]);
    } catch (Exception $e) {
        error_log("Error in cost details route: " . $e->getMessage());
        Flight::error($e);
    }
});

// Lista typów kosztów
Flight::route('GET /cost-types', function() {
    if (!isLoggedIn()) {
        Flight::redirect('/');
        return;
    }
    
    $costTypes = CostType::getAll();
    Flight::render('cost_type_list', ['costTypes' => $costTypes]);
});

// Dodawanie typu kosztu
Flight::route('POST /cost-type/add', function() {
    if (!isLoggedIn()) {
        Flight::redirect('/');
        return;
    }

    $name = Flight::request()->data->name;
    
    if (empty($name)) {
        Flight::redirect('/cost-types?error=Nazwa typu kosztu jest wymagana');
        return;
    }

    try {
        CostType::add($name);
        Flight::redirect('/cost-types?success=Typ kosztu został dodany');
    } catch (Exception $e) {
        Flight::redirect('/cost-types?error=' . urlencode($e->getMessage()));
    }
});

// Usuwanie typu kosztu
Flight::route('POST /cost-type/delete/@id', function($id) {
    if (!isLoggedIn()) {
        Flight::json(['success' => false, 'message' => 'Unauthorized'], 401);
        return;
    }

    try {
        CostType::delete($id);
        Flight::json(['success' => true]);
    } catch (Exception $e) {
        Flight::json(['success' => false, 'message' => $e->getMessage()]);
    }
});

// Endpoint do pobierania obiektów określonego typu
Flight::route('GET /api/get-objects/@type', function($type) {
    if (!isLoggedIn()) {
        Flight::json(['error' => 'Unauthorized'], 401);
        return;
    }

    try {
        $objects = [];
        switch($type) {
            case 'vehicle':
                $objects = Vehicle::getAll();
                break;
            case 'equipment':
                $objects = Equipment::getAll();
                break;
            case 'employee':
                $objects = Employee::getAll();
                break;
        }
        Flight::json($objects);
    } catch (Exception $e) {
        Flight::json(['error' => $e->getMessage()], 500);
    }
});
