<?php
// app/routes/document_generator_routes.php

Flight::route('GET /document/generate/@employeeId', function($employeeId) {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        // Pobierz dane pracownika
        $employee = Employee::getById($employeeId);
        // Pobierz wszystkie szablony dokumentów
        $templates = DocumentTemplate::getAll();
        
        error_log("Przygotowanie formularza generowania dokumentu dla pracownika ID: $employeeId");
        
        Flight::render('document_generate', ['employee' => $employee, 'templates' => $templates]);
    }
});

Flight::route('POST /document/generate', function() {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $data = Flight::request()->data->getData();
        error_log("Dane otrzymane z formularza: " . print_r($data, true));
        
        try {
            $result = DocumentGenerator::generateDocument($data);
            error_log("Wynik generowania dokumentu: " . var_export($result, true));
            
            if ($result) {
                error_log("Próba przekierowania na: /employee/details/" . $data['employee_id'] . "?success=document_generated");
                Flight::redirect('/employee/details/' . $data['employee_id'] . '?success=document_generated');
            } else {
                error_log("Próba przekierowania na: /document/generate/" . $data['employee_id'] . "?error=generation_failed");
                Flight::redirect('/document/generate/' . $data['employee_id'] . '?error=generation_failed');
            }
        } catch (Exception $e) {
            error_log("Wyjątek podczas generowania dokumentu: " . $e->getMessage());
            error_log("Stack trace: " . $e->getTraceAsString());
            Flight::redirect('/document/generate/' . $data['employee_id'] . '?error=exception_occurred');
        }
    }
});



Flight::route('POST /document/generate', function() {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $data = Flight::request()->data->getData();
        error_log("Dane otrzymane z formularza: " . print_r($data, true));
        
        try {
            $result = DocumentGenerator::generateDocument($data);
            error_log("Wynik generowania dokumentu: " . var_export($result, true));
            
            if ($result) {
                $employeeId = intval($data['employee_id']);
                Flight::redirect('/employee/details/' . $employeeId . '?success=document_generated');
            } else {
                throw new Exception("Nie udało się wygenerować dokumentu.");
            }
        } catch (Exception $e) {
            error_log("Wyjątek podczas generowania dokumentu: " . $e->getMessage());
            error_log("Stack trace: " . $e->getTraceAsString());
            Flight::redirect('/document/generate/' . $data['employee_id'] . '?error=generation_failed');
        }
    }
});
Flight::route('GET /api/employee/@id', function($id) {
    if (!isLoggedIn()) {
        Flight::json(['error' => 'Unauthorized'], 401);
    } else {
        $employee = Employee::getById($id);
        if ($employee) {
            $company = Company::getById($employee['company_id']);
            $employee['company_name'] = $company ? $company['name'] : '';
            $employee['instructor_name'] = $_SESSION['user_name'];
            Flight::json($employee);
        } else {
            Flight::json(['error' => 'Employee not found'], 404);
        }
    }
});

    Flight::route('GET /api/template-structure/@id', function($id) {
    error_log("Requested template structure for ID: " . $id);
    
    try {
        $structure = DocumentTemplate::getStructure($id);
        error_log("Retrieved structure: " . json_encode($structure));
        
        if (empty($structure)) {
            error_log("Structure is empty for ID: " . $id);
            Flight::json(['error' => 'Template structure is empty'], 404);
        } else {
            Flight::json($structure);
        }
    } catch (Exception $e) {
        error_log("Error retrieving template structure: " . $e->getMessage());
        Flight::json(['error' => 'Internal server error'], 500);
    }
});