<?php
// app/routes/document_routes.php

// Lista dokumentów
Flight::route('GET /documents', function () {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $filters = [
            'category_id' => Flight::request()->query->category_id,
            'company_id' => Flight::request()->query->company_id,
            'related_entity_type' => Flight::request()->query->filter,
            'search' => Flight::request()->query->search,
            'is_generated' => Flight::request()->query->is_generated,
        ];
        $documents = Document::getAll($filters);
        $categories = DocumentCategory::getAll();
        $companies = Company::getAll();
        Flight::render('document_list', [
            'documents' => $documents,
            'categories' => $categories,
            'companies' => $companies,
            'currentFilter' => $filters['related_entity_type'] ?? 'all',
            'currentSearch' => $filters['search'] ?? '',
            'currentCategoryId' => $filters['category_id'] ?? '',
            'currentCompanyId' => $filters['company_id'] ?? ''
        ]);
    }
});
Flight::route('GET /document/add', function () {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $categories = DocumentCategory::getAll();
        $companies = Company::getAll();
        $referer = $_SERVER['HTTP_REFERER'] ?? '/documents';
        $entityType = Flight::request()->query->entity_type;
        $entityId = Flight::request()->query->entity_id;

        $data = prepareDocumentAddForm($entityType, $entityId);

        $data = array_merge($data, [
            'categories' => $categories,
            'companies' => $companies,
            'referer' => $referer,
        ]);

        Flight::render('document_add', $data);
    }
});
// Formularz dodawania dokumentu
Flight::route('POST /document/add', function () {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        error_log("Rozpoczęto dodawanie dokumentu");
        error_log("Otrzymane dane POST: " . print_r($_POST, true));
        error_log("Otrzymane pliki: " . print_r($_FILES, true));

        $data = Flight::request()->data->getData();
        error_log("Otrzymane dane: " . print_r($data, true));
        $data['created_by'] = $_SESSION['user_id'];
        $data['is_generated'] = 0;  // Ręcznie dodawane dokumenty nie są generowane
        $referer = $data['referer'] ?? '/documents';
        // Obsługa dat ważności
        if (isset($data['has_expiry_date']) && $data['has_expiry_date'] == 'on') {
            $data['policy_start_date'] = $data['policy_start_date'] ?? null;
            $data['policy_end_date'] = $data['policy_end_date'] ?? null;
        } else {
            $data['policy_start_date'] = null;
            $data['policy_end_date'] = null;
        }
        // Obsługa przesyłania pliku
        if (isset($_FILES['file']) && $_FILES['file']['error'] == 0) {
            $uploadDir = __DIR__ . '/../../uploads/documents/';
            if (!is_dir($uploadDir)) {
                error_log("Katalog $uploadDir nie istnieje. Próba utworzenia...");
                if (!mkdir($uploadDir, 0755, true)) {
                    error_log("Nie udało się utworzyć katalogu $uploadDir");
                    Flight::redirect($referer . "?error=upload_dir_creation_failed");
                    return;
                }
            }
            $fileName = uniqid() . '_' . $_FILES['file']['name'];
            $filePath = $uploadDir . $fileName;

            error_log("Próba przesłania pliku do: $filePath");
            if (move_uploaded_file($_FILES['file']['tmp_name'], $filePath)) {
                $data['file_path'] = $filePath;
                $data['file_type'] = $_FILES['file']['type'];
                error_log("Plik przesłany pomyślnie");
            } else {
                error_log("Nie udało się przesłać pliku. Kod błędu: " . $_FILES['file']['error']);
                Flight::redirect($referer . "?error=file_upload");
                return;
            }
        } else {
            error_log("Nie przesłano pliku lub wystąpił błąd. Kod błędu: " . (isset($_FILES['file']) ? $_FILES['file']['error'] : 'Brak pliku'));
            Flight::redirect($referer . "?error=no_file");
            return;
        }

        error_log("Próba dodania dokumentu do bazy danych");
        if (Document::add($data)) {
            error_log("Dokument dodany pomyślnie");
            Flight::redirect($referer . "?success=document_added");
        } else {
            error_log("Nie udało się dodać dokumentu do bazy danych");
            Flight::redirect($referer . "?error=1");
        }
    }
});
// Lista kategorii dokumentów
Flight::route('GET /document/categories', function () {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $categories = DocumentCategory::getAll();
        Flight::render('document_categories', ['categories' => $categories]);
    }
});

// Dodawanie nowej kategorii
Flight::route('POST /document/category/add', function () {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $name = Flight::request()->data->name;
        $description = Flight::request()->data->description;
        if (DocumentCategory::add($name, $description)) {
            Flight::redirect('/document/categories?success=added');
        } else {
            Flight::redirect('/document/categories?error=add_failed');
        }
    }
});

// Edycja kategorii
Flight::route('POST /document/category/edit/@id', function ($id) {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $name = Flight::request()->data->name;
        $description = Flight::request()->data->description;
        if (DocumentCategory::update($id, $name, $description)) {
            Flight::redirect('/document/categories?success=updated');
        } else {
            Flight::redirect('/document/categories?error=update_failed');
        }
    }
});

// Usuwanie kategorii
Flight::route('POST /document/category/delete/@id', function ($id) {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        if (DocumentCategory::delete($id)) {
            Flight::redirect('/document/categories?success=deleted');
        } else {
            Flight::redirect('/document/categories?error=delete_failed');
        }
    }
}); // W app/routes/document_routes.php

Flight::route('GET /get-related-entities/@type', function ($type) {
    if (!isLoggedIn()) {
        Flight::json(['error' => 'Unauthorized'], 401);
        return;
    }

    $entities = [];
    switch ($type) {
        case 'employee':
            $entities = Employee::getAll();
            break;
        case 'vehicle':
            $entities = Vehicle::getAll();
            break;
        case 'equipment':
            // Assume we have an Equipment model
            $entities = Equipment::getAll();
            break;
    }

    $formatted = array_map(function ($entity) use ($type) {
        switch ($type) {
            case 'employee':
                return ['id' => $entity['id'], 'name' => $entity['first_name'] . ' ' . $entity['last_name']];
            case 'vehicle':
                return ['id' => $entity['id'], 'name' => $entity['brand'] . ' ' . $entity['model'] . ' (' . $entity['registration_number'] . ')'];
            case 'equipment':
                // Adjust according to your Equipment model
                return ['id' => $entity['id'], 'name' => $entity['name'] . ' (' . $entity['serial_number'] . ')'];
        }
    }, $entities);

    Flight::json($formatted);
});
// Pozostałe trasy (edycja, usuwanie, szczegóły) zostaną dodane później
// Podgląd dokumentu
Flight::route('GET /document/view/@id', function ($id) {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $document = Document::getById($id);
        if (!$document) {
            Flight::notFound();
        } else {
            // Pobierz dodatkowe informacje o powiązanej encji, jeśli istnieje
            $relatedEntity = null;
            if ($document['related_entity_type'] !== 'none' && $document['related_entity_id']) {
                switch ($document['related_entity_type']) {
                    case 'employee':
                        $relatedEntity = Employee::getById($document['related_entity_id']);
                        break;
                    case 'vehicle':
                        $relatedEntity = Vehicle::getById($document['related_entity_id']);
                        break;
                    case 'equipment':
                        $relatedEntity = Equipment::getById($document['related_entity_id']);
                        break;
                }
            }

            $category = DocumentCategory::getById($document['category_id']);
            $company = Company::getById($document['company_id']);
            $createdBy = User::getById($document['created_by']);

            Flight::render('document_view', [
                'document' => $document,
                'category' => $category,
                'company' => $company,
                'createdBy' => $createdBy,
                'relatedEntity' => $relatedEntity
            ]);
        }
    }
});
// Formularz edycji dokumentu
Flight::route('GET /document/edit/@id', function ($id) {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $document = Document::getById($id);
        if (!$document) {
            Flight::notFound();
        } else {
            $categories = DocumentCategory::getAll();
            $companies = Company::getAll();
            $entityType = Flight::request()->query->entity_type;
            $entityId = Flight::request()->query->entity_id;
            $return_to = $entityType && $entityId ? "/{$entityType}/details/{$entityId}" : '/documents';

            Flight::render('document_edit', [
                'document' => $document,
                'categories' => $categories,
                'companies' => $companies,
                'return_to' => $return_to,
                'entityType' => $entityType,
                'entityId' => $entityId
            ]);
        }
    }
});

Flight::route('POST /document/edit/@id', function ($id) {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $data = Flight::request()->data->getData();
        $entityType = Flight::request()->query->entity_type;
        $entityId = Flight::request()->query->entity_id;
        $return_to = $entityType && $entityId ? "/{$entityType}/details/{$entityId}" : '/documents';

        if (isset($data['has_expiry_date']) && $data['has_expiry_date'] == 'on') {
            $data['policy_start_date'] = $data['policy_start_date'] ?? null;
            $data['policy_end_date'] = $data['policy_end_date'] ?? null;
        } else {
            $data['policy_start_date'] = null;
            $data['policy_end_date'] = null;
        }

        // Obsługa przesyłania nowego pliku, jeśli został dostarczony
        if (isset($_FILES['file']) && $_FILES['file']['error'] == 0) {
            $uploadDir = '../uploads/documents/';
            $fileName = uniqid() . '_' . $_FILES['file']['name'];
            $filePath = $uploadDir . $fileName;

            if (move_uploaded_file($_FILES['file']['tmp_name'], $filePath)) {
                $data['file_path'] = $filePath;
                $data['file_type'] = $_FILES['file']['type'];

                // Usuń stary plik
                $oldDocument = Document::getById($id);
                if (file_exists($oldDocument['file_path'])) {
                    unlink($oldDocument['file_path']);
                }
            } else {
                Flight::redirect($return_to . "?error=file_upload");
                return;
            }
        }

        if (Document::update($id, $data)) {
            Flight::redirect($return_to . "?success=document_updated");
        } else {
            Flight::redirect($return_to . "?error=update_failed");
        }
    }
});
// Pobieranie dokumentu
Flight::route('GET /document/download/@id', function ($id) {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $document = Document::getById($id);
        if (!$document) {
            Flight::notFound();
        } else {
            $file_path = $document['file_path'];
            if (file_exists($file_path)) {
                header('Content-Type: ' . $document['file_type']);
                header('Content-Disposition: attachment; filename="' . basename($file_path) . '"');
                header('Content-Length: ' . filesize($file_path));
                readfile($file_path);
                exit;
            } else {
                Flight::notFound();
            }
        }
    }
});



Flight::route('POST /document/delete/@id', function ($id) {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        if (Document::delete($id)) {
            Flight::redirect('/documents?success=deleted');
        } else {
            Flight::redirect('/documents?error=delete_failed');
        }
    }
});
