<?php
// app/routes/document_template_routes.php

Flight::route('GET /document-templates', function() {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $templates = DocumentTemplate::getAll();
        Flight::render('document_template_list', ['templates' => $templates]);
    }
});

Flight::route('GET /document-template/add', function() {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $categories = DocumentCategory::getAll();
        Flight::render('document_template_add', ['categories' => $categories]);
    }
});

Flight::route('POST /document-template/add', function() {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $data = Flight::request()->data->getData();
        
        // Dodajemy sprawdzenie i wartość domyślną dla form_structure
        if (!isset($data['form_structure']) || empty($data['form_structure'])) {
            $data['form_structure'] = '[]';  // Pusta tablica jako string JSON
        }
        
        $data['form_structure'] = json_decode($data['form_structure'], true);
        
        if (DocumentTemplate::add($data)) {
            Flight::redirect('/document-templates?success=Template added');
        } else {
            Flight::redirect('/document-template/add?error=Failed to add template');
        }
    }
});

Flight::route('GET /document-template/edit/@id', function($id) {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $template = DocumentTemplate::getById($id);
        $categories = DocumentCategory::getAll();
        Flight::render('document_template_edit', ['template' => $template, 'categories' => $categories]);
    }
});

Flight::route('POST /document-template/edit/@id', function($id) {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $data = Flight::request()->data->getData();
        
        // Dodajemy sprawdzenie i wartość domyślną dla form_structure
        if (!isset($data['form_structure']) || empty($data['form_structure'])) {
            $data['form_structure'] = '[]';  // Pusta tablica jako string JSON
        }
        
        $data['form_structure'] = json_decode($data['form_structure'], true);
        
        if (DocumentTemplate::update($id, $data)) {
            Flight::redirect('/document-templates?success=Template updated');
        } else {
            Flight::redirect("/document-template/edit/$id?error=Failed to update template");
        }
    }
});

Flight::route('POST /document-template/delete/@id', function($id) {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        if (DocumentTemplate::delete($id)) {
            Flight::redirect('/document-templates?success=Template deleted');
        } else {
            Flight::redirect('/document-templates?error=Failed to delete template');
        }
    }
});
Flight::route('POST /document-template/preview', function() {
    if (!isLoggedIn()) {
        Flight::json(['error' => 'Unauthorized'], 401);
        return;
    }

    $data = Flight::request()->data->getData();
    
    // Pobierz istniejący szablon, jeśli edytujemy
    $existingTemplate = null;
    if (!empty($data['template_id'])) {
        $existingTemplate = DocumentTemplate::getById($data['template_id']);
    }
    
    // Tworzymy tymczasowy szablon
    $tempTemplate = [
        'name' => 'Preview Template',
        'html_template' => $data['html_template'],
        'css_styles' => $data['css_styles'],
        'category_id' => 1, // Tymczasowa kategoria
        'background_image' => $existingTemplate ? $existingTemplate['background_image'] : null,
    ];

    // Obsługa pliku tła
    if (isset($_FILES['background_image']) && $_FILES['background_image']['error'] == 0) {
        $uploadDir = '/var/www/html/panel/uploads/temp/';
        $backgroundImage = $uploadDir . uniqid() . '_' . basename($_FILES['background_image']['name']);
        if (move_uploaded_file($_FILES['background_image']['tmp_name'], $backgroundImage)) {
            chmod($backgroundImage, 0644); // Ustawienie odpowiednich uprawnień
            error_log("Tymczasowy plik tła utworzony: " . $backgroundImage);
            $tempTemplate['background_image'] = $backgroundImage;
        } else {
            error_log("Błąd podczas tworzenia tymczasowego pliku tła");
        }
    }

    $sampleData = [
        'employee_first_name' => 'Janek',
        'employee_last_name' => 'Kowalski',
        'employee_name' => 'Janek Kowalski',
        'company_name' => 'Przykładowa Firma Sp. z o.o.',
        'position' => 'Specjalista ds. marketingu',
        'instructor_name' => 'Anna Nowak',
        'workplace_instruction_date' => date('d.m.Y'),
        'general_instruction_date' => date('d', strtotime('today')) . '-' . date('d.m.Y', strtotime('tomorrow')),    ];

    try {
        $pdfContent = DocumentGenerator::generatePreview($tempTemplate, $sampleData);
        
        // Usuń tymczasowy plik tła tylko jeśli został utworzony w tej sesji
        if (isset($_FILES['background_image']) && $_FILES['background_image']['error'] == 0) {
            if (!empty($tempTemplate['background_image']) && file_exists($tempTemplate['background_image'])) {
                if (unlink($tempTemplate['background_image'])) {
                    error_log("Tymczasowy plik tła usunięty: " . $tempTemplate['background_image']);
                } else {
                    error_log("Błąd podczas usuwania tymczasowego pliku tła: " . $tempTemplate['background_image']);
                }
            }
        }

        // Dodajemy nagłówek Cache-Control, aby zapobiec cachowaniu
        Flight::response()->header("Cache-Control", "no-store, no-cache, must-revalidate, max-age=0");
        Flight::response()->header("Pragma", "no-cache");
        Flight::response()->header("Expires", "0");

        Flight::response()->header("Content-Type", "application/pdf");
        Flight::response()->header("Content-Disposition", "inline; filename=preview.pdf");
        Flight::response()->header("Content-Length", strlen($pdfContent));
        
        echo $pdfContent;
    } catch (Exception $e) {
        error_log("Błąd podczas generowania podglądu: " . $e->getMessage());
        Flight::json(['error' => 'Wystąpił błąd podczas generowania podglądu'], 500);
    }

});

