<?php

require_once '../app/models/employee.php';
require_once '../app/models/company.php';




// Lista pracowników
Flight::route('GET /employee_list', function () {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $filter = Flight::request()->query->filter ?? 'active';
        $search = Flight::request()->query->search ?? '';
        $company_id = Flight::request()->query->company_id ?? null;
        $employee_id = Flight::request()->query->employee_id ?? null;

        if ($employee_id) {
            $employees = [Employee::getById($employee_id)];
        } else {
            $employees = Employee::getAll($filter, $search, $company_id);
        }
        $companies = Company::getAll();

        Flight::render('employee_list', [
            'employees' => $employees,
            'companies' => $companies,
            'currentFilter' => $filter,
            'currentSearch' => $search,
            'currentCompanyId' => $company_id
        ]);
    }
});
Flight::route('GET /add_employee', function () {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $companies = Company::getAll();
        Flight::render('add_employee', ['companies' => $companies]);
    }
});
// Obsługa dodawania pracownika
Flight::route('POST /add_employee', function () {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $data = Flight::request()->data;
        
        // Formatowanie tekstu tylko dla wymaganych pól tekstowych
        $data->first_name = formatText($data->first_name);
        $data->last_name = formatText($data->last_name);

        // Formatowanie opcjonalnych pól tylko jeśli są wypełnione
        $data->address = !empty($data->address) ? formatText($data->address) : null;
        $data->city = !empty($data->city) ? formatText($data->city) : null;
        $data->country = !empty($data->country) ? formatText($data->country) : null;
        $data->position = !empty($data->position) ? formatText($data->position) : null;

        $result = Employee::add(
            $data->first_name,
            $data->last_name,
            $data->pesel,
            $data->nip ?: null,
            $data->date_of_birth,
            $data->gender,
            $data->address ?: null,
            $data->city ?: null,
            $data->postal_code ?: null,
            $data->country ?: null,
            $data->phone_number ?: null,
            $data->email ?: null,
            $data->position ?: null,
            $data->hire_date,
            $_SESSION['user_id'],
            $data->company_id,
            $data->id_card_number ?: null,
            $data->driving_license_number ?: null
        );

        if ($result) {
            Flight::redirect('/employee_list?success=1');
        } else {
            Flight::redirect('/add_employee?error=1');
        }
    }
});

// Szczegóły pracownika
Flight::route('GET /employee/details/@id', function ($id) {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $employee = Employee::getById($id);
        if (!$employee) {
            Flight::notFound();
        }

        // Pobierz informacje o firmie
        $company = Company::getById($employee['company_id']);
        $employmentPeriods = Employee::getEmploymentPeriods($id);
        $employeeDocuments = Document::getForEmployee($id);

        Flight::render('employee_details', [
            'employee' => $employee,
            'employmentPeriods' => $employmentPeriods,
            'company' => $company,
            'employeeDocuments' => $employeeDocuments
        ]);
    }
});

// Formularz edycji pracownika
Flight::route('GET /employee/edit/@id', function ($id) {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $employee = Employee::getById($id);
        $companies = Company::getAll();
        if (!$employee) {
            Flight::notFound();
        }
        Flight::render('employee_edit', ['employee' => $employee, 'companies' => $companies]);
    }
});

// Obsługa edycji pracownika
// Obsługa edycji pracownika
Flight::route('POST /employee/edit/@id', function ($id) {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $data = [
            'first_name' => formatText(Flight::request()->data->first_name),
            'last_name' => formatText(Flight::request()->data->last_name),
            'pesel' => Flight::request()->data->pesel,
            'nip' => Flight::request()->data->nip,
            'date_of_birth' => Flight::request()->data->date_of_birth,
            'gender' => Flight::request()->data->gender,
            'address' => formatText(Flight::request()->data->address),
            'city' => formatText(Flight::request()->data->city),
            'postal_code' => Flight::request()->data->postal_code,
            'country' => formatText(Flight::request()->data->country),
            'phone_number' => Flight::request()->data->phone_number,
            'email' => Flight::request()->data->email,
            'position' => formatText(Flight::request()->data->position),
            'company_id' => Flight::request()->data->company_id,
            'id_card_number' => Flight::request()->data->id_card_number,
            'driving_license_number' => Flight::request()->data->driving_license_number
        ];

        $result = Employee::update($id, $data);

        if ($result) {
            Flight::redirect('/employee/details/' . $id . '?success=1');
        } else {
            Flight::redirect('/employee/edit/' . $id . '?error=1');
        }
    }
});

// Dodawanie okresu zatrudnienia
Flight::route('POST /employee/add_employment_period', function () {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $employeeId = Flight::request()->data->employee_id;
        error_log("Received employee ID add: " . $employeeId);
        $startDate = Flight::request()->data->start_date;
        $endDate = Flight::request()->data->end_date ?: null;

        if (Employee::addEmploymentPeriod($employeeId, $startDate, $_SESSION['user_id'], $endDate)) {
            Flight::redirect("/employee/details/$employeeId?success=Period added");
        } else {
            Flight::redirect("/employee/details/$employeeId?error=Failed to add period");
        }
    }
});

// Edycja okresu zatrudnienia
Flight::route('POST /employee/edit_employment_period', function () {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $data = Flight::request()->data;
        $removeEndDate = isset($data->remove_end_date);
        $result = Employee::editEmploymentPeriod(
            $data->period_id,
            $data->start_date,
            $removeEndDate ? null : $data->end_date,
            $removeEndDate
        );

        if ($result) {
            Flight::redirect("/employee/details/{$data->employee_id}?success=Okres zatrudnienia został zaktualizowany");
        } else {
            Flight::redirect("/employee/details/{$data->employee_id}?error=Nie udało się zaktualizować okresu zatrudnienia");
        }
    }
});

// Zakończenie okresu zatrudnienia
Flight::route('POST /employee/end_employment_period', function () {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $data = Flight::request()->data;
        $result = Employee::endEmploymentPeriod($data->period_id, $data->end_date);

        if ($result) {
            Flight::redirect("/employee/details/{$data->employee_id}?success=Okres zatrudnienia został zakończony");
        } else {
            Flight::redirect("/employee/details/{$data->employee_id}?error=Nie udało się zakończyć okresu zatrudnienia");
        }
    }
});
Flight::route('GET /employee/delete_employment_period/@id', function ($id) {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $period = Employee::getEmploymentPeriodById($id);
        if (!$period) {
            Flight::redirect('/employee_list?error=Okres zatrudnienia nie istnieje');
            return;
        }

        $employeeId = $period['employee_id'];
        $result = Employee::deleteEmploymentPeriod($id);

        if ($result) {
            Flight::redirect("/employee/details/$employeeId?success=Okres zatrudnienia został usunięty");
        } else {
            Flight::redirect("/employee/details/$employeeId?error=Nie udało się usunąć okresu zatrudnienia");
        }
    }
});

// Endpoint dla podpowiedzi wyszukiwania
Flight::route('GET /employee/search_suggestions', function() {
    if (!isLoggedIn()) {
        Flight::json(['error' => 'Unauthorized'], 401);
        return;
    }

    $search = Flight::request()->query->search;
    $company_id = Flight::request()->query->company_id ?? null;

    $suggestions = Employee::getSearchSuggestions($search, $company_id);
    Flight::json($suggestions);
});

// Usuwanie pracownika
Flight::route('POST /employee/delete/@id', function($id) {
    if (!isLoggedIn()) {
        Flight::json(['success' => false, 'message' => 'Unauthorized'], 401);
        return;
    }

    $result = Employee::delete($id);
    
    if ($result) {
        Flight::json(['success' => true]);
    } else {
        Flight::json(['success' => false, 'message' => 'Nie udało się usunąć pracownika'], 500);
    }
});
