<?php
// app/routes/equipment_routes.php

// Lista sprzętu
Flight::route('GET /equipment', function() {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $equipment = Equipment::getAll();
        Flight::render('equipment_list', ['equipment' => $equipment]);
    }
});

// Formularz dodawania sprzętu
Flight::route('GET /equipment/add', function() {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $companies = Company::getAll();
        Flight::render('equipment_add', ['companies' => $companies]);
    }
});

// Obsługa dodawania sprzętu
Flight::route('POST /equipment/add', function() {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $data = Flight::request()->data->getData();
        
        // Sprawdzenie, czy wymagane pola są wypełnione
        if (empty($data['name']) || empty($data['company_id'])) {
            Flight::redirect('/equipment/add?error=missing_required_fields');
            return;
        }
        
        if (Equipment::add($data)) {
            Flight::redirect('/equipment?success=1');
        } else {
            Flight::redirect('/equipment/add?error=1');
        }
    }
});

// Formularz edycji sprzętu
Flight::route('GET /equipment/edit/@id', function($id) {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $item = Equipment::getById($id);
        $companies = Company::getAll();
        if (!$item) {
            Flight::notFound();
        }
        Flight::render('equipment_edit', ['item' => $item, 'companies' => $companies]);
    }
});

// Obsługa edycji sprzętu
Flight::route('POST /equipment/edit/@id', function($id) {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $data = Flight::request()->data->getData();
        
        // Sprawdzenie, czy wymagane pola są wypełnione
        if (empty($data['name']) || empty($data['company_id'])) {
            Flight::redirect("/equipment/edit/$id?error=missing_required_fields");
            return;
        }
        
        if (Equipment::update($id, $data)) {
            Flight::redirect('/equipment?success=2');
        } else {
            Flight::redirect("/equipment/edit/$id?error=1");
        }
    }
});
// Szczegóły sprzętu
Flight::route('GET /equipment/@id', function($id) {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $item = Equipment::getById($id);
        if (!$item) {
            Flight::notFound();
        }
        Flight::render('equipment_details', ['item' => $item]);
    }
});
// Usuwanie sprzętu
Flight::route('POST /equipment/delete/@id', function($id) {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        if (Equipment::delete($id)) {
            Flight::redirect('/equipment?success=3');
        } else {
            Flight::redirect('/equipment?error=delete');
        }
    }
});