<?php
// ./app/routes/policy_routes.php

// Modyfikacja trasy dodawania polisy
Flight::route('POST /policy/add', function() {
    if (!isLoggedIn()) {
        Flight::json(['error' => 'Unauthorized'], 401);
        return;
    }

    $data = Flight::request()->data->getData();
    error_log('Otrzymane dane polisy (surowe): ' . print_r($data, true));

    $data['created_by'] = $_SESSION['user_id'];
    $data['related_entity_type'] = 'vehicle';

    // Obsługa przesyłania pliku
    if (isset($_FILES['file']) && $_FILES['file']['error'] == 0) {
        $uploadDir = '../uploads/documents/';
        $fileName = uniqid() . '_' . $_FILES['file']['name'];
        $filePath = $uploadDir . $fileName;

        if (move_uploaded_file($_FILES['file']['tmp_name'], $filePath)) {
            $data['file_path'] = $filePath;
            $data['file_type'] = $_FILES['file']['type'];
        } else {
            error_log('Błąd podczas przesyłania pliku: ' . print_r($_FILES['file'], true));
            Flight::json(['error' => 'File upload failed'], 500);
            return;
        }
    } else {
        $data['file_path'] = null;
        $data['file_type'] = null;
    }

    // Ustawienie tytułu dokumentu
    $categoryName = DocumentCategory::getById($data['category_id'])['name'];
    $data['title'] = 'Polisa ' . ($categoryName == 'Polisa OC' ? 'OC' : 'AC') . ' - ' . $data['insurance_company'];

    // Ustawienie opisu
    $data['description'] = $data['description'] ?? 'Polisa dla pojazdu';

    // Upewniamy się, że company_id jest ustawione
    $data['company_id'] = $data['company_id'] ?? null;

    error_log('Przetworzone dane polisy: ' . print_r($data, true));

    try {
        if (Document::addPolicy($data)) {
            Flight::json(['success' => true]);
        } else {
            error_log('Nie udało się dodać polisy. Dane: ' . print_r($data, true));
            Flight::json(['error' => 'Failed to add policy'], 500);
        }
    } catch (Exception $e) {
        error_log('Wyjątek podczas dodawania polisy: ' . $e->getMessage());
        error_log('Stack trace: ' . $e->getTraceAsString());
        Flight::json(['error' => 'Exception occurred: ' . $e->getMessage()], 500);
    }
});

// Edycja polisy
Flight::route('POST /policy/edit/@id', function($id) {
    if (!isLoggedIn()) {
        Flight::json(['error' => 'Unauthorized'], 401);
        return;
    }

    $data = Flight::request()->data->getData();
    
    // Dodanie obsługi listy samochodów
    if (isset($data['vehicles'])) {
        $vehicles = [];
        foreach ($data['vehicles'] as $vehicle) {
            if (!empty($vehicle['registration_number'])) {
                $vehicles[] = $vehicle;
            }
        }
        $data['vehicles'] = $vehicles;
    }
    
    try {
        if (Document::updatePolicy($id, $data)) {
            Flight::json(['success' => true]);
        } else {
            Flight::json(['error' => 'Failed to update policy'], 500);
        }
    } catch (Exception $e) {
        error_log('Exception during policy update: ' . $e->getMessage());
        Flight::json(['error' => 'Exception occurred: ' . $e->getMessage()], 500);
    }
});

// Lista polis dla pojazdu
Flight::route('GET /vehicle/@id/policies', function ($id) {
    if (!isLoggedIn()) {
        Flight::json(['error' => 'Unauthorized'], 401);
        return;
    }

    $policies = Document::getPoliciesForVehicle($id);
    Flight::json($policies);
});
Flight::route('GET /policy/categories', function () {
    if (!isLoggedIn()) {
        Flight::json(['error' => 'Unauthorized'], 401);
        return;
    }

    $categories = DocumentCategory::getPolicyCategories();
    Flight::json($categories);
});
Flight::route('GET /policy/@id', function($id) {
    if (!isLoggedIn()) {
        Flight::json(['error' => 'Unauthorized'], 401);
        return;
    }

    $policy = Document::getById($id);
    if ($policy) {
        Flight::json($policy);
    } else {
        Flight::json(['error' => 'Policy not found'], 404);
    }
});
Flight::route('GET /policy/download/@id', function($id) {
    if (!isLoggedIn()) {
        Flight::json(['error' => 'Unauthorized'], 401);
        return;
    }

    $policy = Document::getById($id);
    if (!$policy) {
        Flight::notFound();
        return;
    }

    $filePath = $policy['file_path'];
    if (!file_exists($filePath)) {
        Flight::notFound();
        return;
    }

    $fileName = basename($filePath);
    header('Content-Type: ' . mime_content_type($filePath));
    header('Content-Disposition: attachment; filename="' . $fileName . '"');
    header('Content-Length: ' . filesize($filePath));
    readfile($filePath);
    exit;
});