<?php

Flight::route('GET /tasks', function() {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        try {
            // Pobierz parametry filtrowania z URL
            $filters = [
                'search' => Flight::request()->query->search,
                'status' => Flight::request()->query->status ?? Task::DEFAULT_STATUS_FILTER,
                'assignment' => Flight::request()->query->assignment
            ];
            
            // Przekaż filtry do metody getAll
            $tasks = Task::getAll($filters);
            
            // Przekaż aktualne wartości filtrów do widoku
            Flight::render('tasks', [
                'tasks' => $tasks,
                'currentSearch' => $filters['search'],
                'currentStatus' => $filters['status'],
                'currentAssignment' => $filters['assignment']
            ]);
        } catch (Exception $e) {
            error_log($e->getMessage());
            echo "Wystąpił błąd: " . $e->getMessage();
        }
    }
});

Flight::route('GET /task/add', function() {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        Flight::render('task_add');
    }
});

Flight::route('POST /task/add', function() {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    }
    
    $errors = [];
    $title = trim(Flight::request()->data->title);
    $description = trim(Flight::request()->data->description ?? '');
    $status = Flight::request()->data->status;
    $due_date = trim(Flight::request()->data->due_date ?? '');
    $assigned_to = Flight::request()->data->assigned_to;
    
    // Jeśli assigned_to jest pusty string, zamień na null
    $assigned_to = $assigned_to === '' ? null : $assigned_to;
    
    // Walidacja tytułu
    if (empty($title)) {
        $errors['title'] = 'Tytuł jest wymagany';
    }
    
    // Walidacja priorytetu
    if (empty(Flight::request()->data->priority)) {
        $errors['priority'] = 'Priorytet jest wymagany';
    }
    
    // Walidacja statusu
    if (empty($status)) {
        $errors['status'] = 'Status jest wymagany';
    }
    
    // Walidacja daty tylko jeśli została podana
    if (!empty($due_date) && !strtotime($due_date)) {
        $errors['due_date'] = 'Nieprawidłowy format daty';
    }
    
    if (!empty($errors)) {
        Flight::render('task_add', ['errors' => $errors, 'old' => Flight::request()->data]);
        return;
    }
    
    $priority = Flight::request()->data->priority;
    $created_by = $_SESSION['user_id'];

    $result = Task::add(
        $title, 
        $description, 
        $priority, 
        $due_date, 
        $status, 
        $created_by,
        $assigned_to
    );
    if ($result) {
        Flight::redirect('/tasks?success=1');
    } else {
        Flight::redirect('/task/add?error=1');
    }
});

Flight::route('GET /task/@id', function($id) {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $task = Task::getById($id);
        if (!$task) {
            Flight::notFound();
        }
        Flight::render('task_details', ['task' => $task]);
    }
});

Flight::route('GET /task/edit/@id', function($id) {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $task = Task::getById($id);
        if (!$task) {
            Flight::notFound();
        }
        Flight::render('task_edit', ['task' => $task]);
    }
});

Flight::route('POST /task/edit/@id', function($id) {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    }
    
    $errors = [];
    $title = trim(Flight::request()->data->title);
    $description = trim(Flight::request()->data->description ?? '');
    $priority = Flight::request()->data->priority;
    $due_date = trim(Flight::request()->data->due_date ?? '');
    $status = Flight::request()->data->status;
    $assigned_to = Flight::request()->data->assigned_to;
    
    // Jeśli assigned_to jest pusty string, zamień na null
    $assigned_to = $assigned_to === '' ? null : $assigned_to;
    
    // Walidacja tytułu
    if (empty($title)) {
        $errors['title'] = 'Tytuł jest wymagany';
    }
    
    // Walidacja daty tylko jeśli została podana
    if (!empty($due_date) && !strtotime($due_date)) {
        $errors['due_date'] = 'Nieprawidłowy format daty';
    }
    
    if (!empty($errors)) {
        $task = Task::getById($id);
        Flight::render('task_edit', [
            'task' => $task,
            'errors' => $errors,
            'old' => Flight::request()->data
        ]);
        return;
    }

    $result = Task::update(
        $id, 
        $title, 
        $description, 
        $priority, 
        $due_date, 
        $status,
        $assigned_to
    );
    if ($result) {
        Flight::redirect('/task/' . $id . '?success=1');
    } else {
        Flight::redirect('/task/edit/' . $id . '?error=1');
    }
});

Flight::route('POST /task/delete/@id', function($id) {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $result = Task::delete($id);
        if ($result) {
            // Zmieniamy komunikat, bo teraz zadanie jest zakończone, a nie usunięte
            Flight::redirect('/tasks?success=4'); // Nowy kod sukcesu
        } else {
            Flight::redirect('/tasks?error=1');
        }
    }
});
