<?php

// Lista użytkowników (tylko dla adminów)
Flight::route('GET /users', function() {
    if (!isLoggedIn() || !isAdmin()) {
        Flight::redirect('/');
    } else {
        $users = User::getAll();
        Flight::render('user_list', ['users' => $users]);
    }
});

// Formularz dodawania użytkownika
Flight::route('GET /user/add', function() {
    if (!isLoggedIn() || !isAdmin()) {
        Flight::redirect('/');
    } else {
        Flight::render('user_add');
    }
});

// Obsługa dodawania użytkownika
Flight::route('POST /user/add', function() {
    if (!isLoggedIn() || !isAdmin()) {
        Flight::redirect('/');
    } else {
        $name = Flight::request()->data->name;
        $email = Flight::request()->data->email;
        $password = password_hash(Flight::request()->data->password, PASSWORD_DEFAULT);
        $role = Flight::request()->data->role;
        $phone_number = Flight::request()->data->phone_number;

        $result = User::add($name, $email, $password, $role, $phone_number);
        if ($result) {
            Flight::redirect('/users?success=1');
        } else {
            Flight::redirect('/user/add?error=1');
        }
    }
});

// Formularz edycji użytkownika
Flight::route('GET /user/edit/@id', function($id) {
    if (!isLoggedIn() || !isAdmin()) {
        Flight::redirect('/');
    } else {
        $user = User::getById($id);
        if (!$user) {
            Flight::notFound();
        }
        Flight::render('user_edit', ['user' => $user]);
    }
});

// Obsługa edycji użytkownika
Flight::route('POST /user/edit/@id', function($id) {
    if (!isLoggedIn() || !isAdmin()) {
        Flight::redirect('/');
    } else {
        $data = [
            'name' => Flight::request()->data->name,
            'email' => Flight::request()->data->email,
            'role' => Flight::request()->data->role,
            'phone_number' => Flight::request()->data->phone_number
        ];
        
        $result = User::update($id, $data);
        if ($result) {
            Flight::redirect('/users?success=1');
        } else {
            Flight::redirect('/user/edit/' . $id . '?error=1');
        }
    }
});

// Usuwanie użytkownika
Flight::route('POST /user/delete/@id', function($id) {
    if (!isLoggedIn() || !isAdmin()) {
        Flight::redirect('/');
    } else {
        $result = User::delete($id);
        if ($result) {
            Flight::redirect('/users?deleted=1');
        } else {
            Flight::redirect('/users?error=1');
        }
    }
});

// Profil użytkownika
Flight::route('GET /profile', function() {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $user = User::getById($_SESSION['user_id']);
        Flight::render('user_profile', ['user' => $user]);
    }
});

// Profil użytkownika na podstawie ID (tylko dla adminów)
Flight::route('GET /profile/@id', function($id) {
    if (!isLoggedIn() || !isAdmin()) {
        Flight::redirect('/');
    } else {
        $user = User::getById($id);
        if (!$user) {
            Flight::notFound();
        }
        Flight::render('user_profile', ['user' => $user]);
    }
});

// Aktualizacja profilu użytkownika
Flight::route('POST /profile/update', function() {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $data = [
            'name' => Flight::request()->data->name,
            'email' => Flight::request()->data->email,
            'phone_number' => Flight::request()->data->phone_number
        ];
        
        error_log("Attempting to update user profile with data: " . print_r($data, true));
        
        $result = User::updateProfile($_SESSION['user_id'], $data);
        
        error_log("Update result: " . ($result ? "success" : "failure"));
        
        if ($result) {
            Flight::redirect('/profile?success=1');
        } else {
            error_log("Update failed. User ID: " . $_SESSION['user_id']);
            Flight::redirect('/profile?error=1');
        }
    }
});

// Zmiana hasła
Flight::route('POST /profile/change-password', function() {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $current_password = Flight::request()->data->current_password;
        $new_password = Flight::request()->data->new_password;
        $confirm_password = Flight::request()->data->confirm_password;

        $user = User::getById($_SESSION['user_id']);
        
        if (!password_verify($current_password, $user['password'])) {
            Flight::redirect('/profile?error=current_password');
        } elseif ($new_password !== $confirm_password) {
            Flight::redirect('/profile?error=password_mismatch');
        } else {
            $hashed_password = password_hash($new_password, PASSWORD_DEFAULT);
            $result = User::updatePassword($_SESSION['user_id'], $hashed_password);
            if ($result) {
                Flight::redirect('/profile?success=password_changed');
            } else {
                Flight::redirect('/profile?error=password_change_failed');
            }
        }
    }
});

// Funkcja pomocnicza do sprawdzania, czy użytkownik jest adminem
