<?php

// Lista pojazdów
Flight::route('GET /vehicles', function () {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $vehicles = Vehicle::getAll();
        Flight::render('vehicle_list', ['vehicles' => $vehicles]);
    }
});

// Formularz dodawania pojazdu
Flight::route('GET /vehicles/add', function () {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $companies = Company::getAll();
        Flight::render('vehicle_add', ['companies' => $companies]);
    }
});

// Obsługa dodawania pojazdu
Flight::route('POST /vehicle/add', function () {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $data = Flight::request()->data;
        $result = Vehicle::add(
            $data->brand,
            $data->model,
            $data->year,
            $data->registration_number ?: null,
            $data->vin,
            $data->purchase_date,
            $data->company_id,
            $_SESSION['user_id'],
            $data->first_registration_date ?: null
        );
        if ($result) {
            Flight::redirect('/vehicles?success=1');
        } else {
            Flight::redirect('/vehicle/add?error=1');
        }
    }
});

// Szczegóły pojazdu
Flight::route('GET /vehicle/@id', function ($id) {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $vehicle = Vehicle::getById($id);
        if (!$vehicle) {
            Flight::notFound();
        }
        $inspections = VehicleInspection::getAllForVehicle($id);
        $mileages = Vehicle::getMileagesForVehicle($id); // Dodajemy tę linię
        $vehicleDocuments = Document::getForVehicle($id);

        Flight::render('vehicle_details', [
            'vehicle' => $vehicle,
            'inspections' => $inspections,
            'mileages' => $mileages,
            'vehicleDocuments' => $vehicleDocuments


        ]);
    }
});
// Formularz edycji pojazdu
Flight::route('GET /vehicle/edit/@id', function ($id) {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $vehicle = Vehicle::getById($id);
        $companies = Company::getAll();
        if (!$vehicle) {
            Flight::notFound();
        }
        Flight::render('vehicle_edit', ['vehicle' => $vehicle, 'companies' => $companies]);
    }
});

// Obsługa edycji pojazdu
Flight::route('POST /vehicle/edit/@id', function ($id) {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        try {
            $request = Flight::request();
            $data = $request->data->getData() ?: $request->query->getData();

            if (empty($data['brand'])) {
                throw new Exception("Brand is missing from the form data");
            }

            $result = Vehicle::update($id, $data);
            if ($result) {
                Flight::redirect('/vehicle/' . $id . '?success=1');
            } else {
                throw new Exception("Failed to update vehicle");
            }
        } catch (Exception $e) {
            Flight::redirect('/vehicle/edit/' . $id . '?error=' . urlencode($e->getMessage()));
        }
    }
});

// Usuwanie pojazdu
Flight::route('POST /vehicle/delete/@id', function ($id) {
    if (!isLoggedIn()) {
        Flight::json(['success' => false, 'message' => 'Unauthorized'], 401);
        return;
    }

    $result = Vehicle::delete($id);
    
    if ($result['success']) {
        Flight::json(['success' => true]);
    } else {
        Flight::json([
            'success' => false, 
            'message' => $result['message']
        ], 400);
    }
});

// Przeglądy - lista
Flight::route('GET /inspections', function () {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $inspections = VehicleInspection::getAll();
        Flight::render('inspections', ['inspections' => $inspections]);
    }
});
// Dodaj tę trasę przed istniejącą trasą 'GET /inspection/add'
Flight::route('GET /vehicle/@id/inspection/add', function ($id) {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $vehicle = Vehicle::getById($id);
        $vehicles = Vehicle::getAll();
        Flight::render('add_inspection', ['vehicles' => $vehicles, 'selected_vehicle' => $vehicle]);
    }
});
// Formularz dodawania przeglądu
Flight::route('GET /inspection/add', function () {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $vehicles = Vehicle::getAll();
        Flight::render('add_inspection', ['vehicles' => $vehicles]);
    }
});

Flight::route('POST /get-nearest-mileage', function () {
    if (!isLoggedIn()) {
        Flight::json(['error' => 'Unauthorized'], 401);
    } else {
        $vehicleId = Flight::request()->data->vehicle_id;
        $date = Flight::request()->data->date;
        $nearestMileage = Vehicle::getNearestMileage($vehicleId, $date);
        Flight::json($nearestMileage);
    }
});

// Obsługa dodawania przeglądu
Flight::route('POST /inspection/add', function () {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $data = Flight::request()->data;
        $data['created_by'] = $_SESSION['user_id'];
        $result = VehicleInspection::add($data);
        if ($result) {
            Flight::redirect('/vehicle/' . $data['vehicle_id'] . '?success=inspection_added');
        } else {
            Flight::redirect('/inspection/add?error=1');
        }
    }
});

// Formularz edycji przeglądu
Flight::route('GET /inspection/edit/@id', function ($id) {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $inspection = VehicleInspection::getById($id);
        $vehicles = Vehicle::getAll();
        Flight::render('edit_inspection', ['inspection' => $inspection, 'vehicles' => $vehicles]);
    }
});

// Obsługa edycji przeglądu
Flight::route('POST /inspection/edit/@id', function ($id) {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $data = Flight::request()->data;
        $result = VehicleInspection::update($id, $data);
        if ($result) {
            // Usuwamy tę linię:
            // Vehicle::updateMileage($data->vehicle_id, $data->mileage, $data->inspection_date);
            Flight::redirect('/inspections?success=1');
        } else {
            Flight::redirect('/inspection/edit/' . $id . '?error=1');
        }
    }
});

// Usuwanie przeglądu
Flight::route('POST /inspection/delete/@id', function ($id) {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $result = VehicleInspection::delete($id);
        if ($result) {
            Flight::redirect('/inspections?deleted=1');
        } else {
            Flight::redirect('/inspections?error=1');
        }
    }
});
// Obsługa aktualizacji przebiegu
Flight::route('POST /vehicle/update-mileage/@id', function ($id) {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $mileage = Flight::request()->data->mileage;
        $mileageMonth = Flight::request()->data->mileage_date; // Upewnij się, że to pole formularza ma nazwę 'mileage_date'
        $confirm = Flight::request()->data->confirm;

        if ($confirm) {
            $result = Vehicle::confirmUpdateMileage($id, $mileage, date('Y-m-t', strtotime($mileageMonth . '-01')));
        } else {
            $result = Vehicle::updateMileage($id, $mileage, $mileageMonth);
        }

        if ($result['success']) {
            if (isset($result['warning'])) {
                Flight::redirect('/vehicles?success=1&warning=' . urlencode($result['warning']));
            } else {
                Flight::redirect('/vehicles?success=1');
            }
        } elseif (isset($result['existing'])) {
            // Przekieruj z powrotem do formularza z informacją o istniejącym przebiegu
            Flight::redirect('/vehicle/update-mileage/' . $id . '?existing=1&date=' . $result['mileageDate'] . '&new_mileage=' . $result['newMileage'] . '&existing_mileage=' . $result['existingMileage']);
        } else {
            $error = $result['error'] ?? 'Nie udało się zaktualizować przebiegu.';
            Flight::redirect('/vehicle/update-mileage/' . $id . '?error=' . urlencode($error));
        }
    }
});

// Formularz aktualizacji przebiegu
Flight::route('GET /vehicle/update-mileage/@id', function ($id) {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $vehicle = Vehicle::getById($id);
        $lastMonth = date('Y-m', strtotime('last month'));
        $latestMileage = Vehicle::getLatestMileage($id);
        Flight::render('update_mileage', [
            'vehicle' => $vehicle,
            'defaultDate' => $lastMonth,
            'latestMileage' => $latestMileage
        ]);
    }

});
// Formularz edycji przebiegu
// Formularz edycji przebiegu
Flight::route('GET /vehicle/edit-mileage/@id', function ($id) {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $mileage = Vehicle::getMileageById($id);
        if (!$mileage) {
            Flight::notFound();
        }
        $vehicle = Vehicle::getById($mileage['vehicle_id']);
        Flight::render('edit_mileage', [
            'mileage' => $mileage,
            'vehicle' => $vehicle
        ]);
    }
});

// Obsługa edycji przebiegu
// Obsługa edycji przebiegu
Flight::route('POST /vehicle/edit-mileage/@id', function ($id) {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $mileage = Flight::request()->data->mileage;
        $mileage_date = Flight::request()->data->mileage_date;
        $vehicle_id = Flight::request()->data->vehicle_id;
        $result = Vehicle::editMileage($id, $mileage, $mileage_date, $vehicle_id);
        if ($result['success']) {
            Flight::redirect('/vehicle/' . $vehicle_id . '?success=mileage_edited');
        } else {
            Flight::redirect('/vehicle/edit-mileage/' . $id . '?error=' . urlencode($result['error']));
        }
    }
});

// Usuwanie przebiegu
Flight::route('POST /vehicle/delete-mileage/@id', function ($id) {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $vehicle_id = Vehicle::getMileageVehicleId($id);
        if (!$vehicle_id) {
            Flight::notFound();
        }
        $result = Vehicle::deleteMileage($id);
        if ($result['success']) {
            Flight::redirect('/vehicle/' . $vehicle_id . '?success=mileage_deleted');
        } else {
            Flight::redirect('/vehicle/' . $vehicle_id . '?error=' . urlencode($result['error']));
        }
    }
});

// Dodawanie dokumentu do pojazdu
Flight::route('GET /vehicle/add-document/@id', function ($id) {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $vehicle = Vehicle::getById($id);
        if (!$vehicle) {
            Flight::notFound();
        }
        $categories = DocumentCategory::getAll();
        $companies = Company::getAll();
        Flight::render('document_add', [
            'categories' => $categories,
            'companies' => $companies,
            'entityType' => 'vehicle',
            'entityId' => $id,
            'entityName' => $vehicle['brand'] . ' ' . $vehicle['model'] . ' (' . $vehicle['registration_number'] . ')'
        ]);
    }
});
Flight::route('GET /inspection/details/@id', function ($id) {
    if (!isLoggedIn()) {
        Flight::redirect('/');
    } else {
        $inspection = VehicleInspection::getDetailsById($id);
        if (!$inspection) {
            Flight::notFound();
        }
        Flight::render('inspection_details', ['inspection' => $inspection]);
    }
});

