<?php include 'header.php'; ?>

<div class="container mt-4">
    <div class="card shadow">
        <div class="card-header bg-primary text-white">
            <h2 class="mb-0">Dodaj nowy przegląd</h2>
        </div>
        <div class="card-body">
            <form action="/inspection/add" method="post" class="form-container" id="inspectionForm">
                <div class="form-section mb-4">
                    <h3 class="section-title mb-3">Informacje o przeglądzie</h3>
                    <div class="form-fields">
                        <div class="form-group">
                            <label for="vehicle_id" class="form-label required">Pojazd:</label>
                            <select name="vehicle_id" id="vehicle_id" class="form-control" required>
                                <?php if (!isset($selected_vehicle)) : ?>
                                    <option value="">Wybierz pojazd</option>
                                <?php endif; ?>
                                <?php foreach ($vehicles as $vehicle) : ?>
                                    <option value="<?php echo $vehicle['id']; ?>" <?php echo (isset($selected_vehicle) && $selected_vehicle['id'] == $vehicle['id']) ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($vehicle['brand'] . ' ' . $vehicle['model'] . ' (' . $vehicle['registration_number'] . ')'); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="form-group">
                            <label for="inspection_type" class="form-label required">Typ przeglądu:</label>
                            <select name="inspection_type" id="inspection_type" class="form-control" required>
                                <option value="techniczny">Techniczny</option>
                                <option value="serwisowy">Serwisowy</option>
                            </select>
                        </div>
                        <div class="form-group">
                            <label for="inspection_date" class="form-label required">Data przeglądu:</label>
                            <input type="date" id="inspection_date" name="inspection_date" class="form-control" required>
                        </div>
                        <div class="form-group">
                            <label for="expiration_date" class="form-label required">Data ważności:</label>
                            <input type="date" id="expiration_date" name="expiration_date" class="form-control" required>
                        </div>
                        <div class="form-group">
                            <label for="mileage" class="form-label required">Przebieg (km):</label>
                            <input type="number" id="mileage" name="mileage" class="form-control" required>
                        </div>
                        <div class="form-group">
                            <label for="notes" class="form-label">Uwagi:</label>
                            <textarea id="notes" name="notes" class="form-control" rows="4"></textarea>
                        </div>
                        <div class="form-group" id="service_actions_group" style="display: none;">
                            <label for="service_actions" class="form-label">Wykonane czynności serwisowe:</label>
                            <textarea id="service_actions" name="service_actions" class="form-control" rows="4"></textarea>
                        </div>
                    </div>
                </div>
                <div class="form-footer">
                    <button type="submit" class="btn btn-primary btn-lg">Dodaj przegląd</button>
                </div>
            </form>
        </div>
    </div>
</div>

<script>
document.getElementById('inspection_type').addEventListener('change', function() {
    var serviceActionsGroup = document.getElementById('service_actions_group');
    if (this.value === 'serwisowy') {
        serviceActionsGroup.style.display = 'block';
    } else {
        serviceActionsGroup.style.display = 'none';
    }
});

document.getElementById('inspection_date').addEventListener('change', function() {
    var inspectionDate = new Date(this.value);
    var expirationDate = new Date(inspectionDate);
    expirationDate.setFullYear(expirationDate.getFullYear() + 1);
    document.getElementById('expiration_date').value = expirationDate.toISOString().split('T')[0];

    updateMileage();
});

document.getElementById('vehicle_id').addEventListener('change', updateMileage);

function updateMileage() {
    var vehicleId = document.getElementById('vehicle_id').value;
    var inspectionDate = document.getElementById('inspection_date').value;

    if (vehicleId && inspectionDate) {
        fetch('/get-nearest-mileage', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify({
                    vehicle_id: vehicleId,
                    date: inspectionDate
                })
            })
            .then(response => response.json())
            .then(data => {
                if (data.mileage) {
                    document.getElementById('mileage').value = data.mileage;
                }
            })
            .catch(error => console.error('Error:', error));
    }
}
</script>

<?php include 'footer.php'; ?>