<?php include 'header.php'; ?>

<div class="section-header mb-3 d-flex justify-content-between align-items-center">
    <h2>Dodaj nowy koszt</h2>
    <div class="btn-group">
        <a href="/costs" class="btn btn-success">
            <i class="fas fa-list"></i> Lista kosztów
        </a>
        <button type="submit" form="costForm" class="btn btn-primary">
            <i class="fas fa-save"></i> Zapisz
        </button>
    </div>
</div>

<div class="card shadow">
    <div class="card-body">
        <?php if (isset($_GET['error'])): ?>
            <div class="alert alert-danger" role="alert">
                <?php echo htmlspecialchars($_GET['error']); ?>
            </div>
        <?php endif; ?>

        <?php if (isset($_GET['success'])): ?>
            <div class="alert alert-success" role="alert">
                <?php echo htmlspecialchars($_GET['success']); ?>
            </div>
        <?php endif; ?>

        <form id="costForm" action="/cost/add" method="POST" class="form-container">
            <?php
            $sections = [
                'Dane podstawowe' => ['company_id', 'cost_type_id', 'amount', 'date'],
                'Szczegóły' => ['description', 'is_general', 'relation_type', 'related_id'],
                'Status' => ['status']
            ];

            $fields = [
                'company_id' => 'Firma *',
                'cost_type_id' => 'Typ kosztu',
                'amount' => 'Kwota *',
                'date' => 'Data',
                'description' => 'Opis',
                'is_general' => 'Koszt ogólny',
                'relation_type' => 'Powiązany obiekt',
                'related_id' => 'Wybierz obiekt',
                'status' => 'Status'
            ];

            $required_fields = ['company_id', 'amount'];

            // Zakładamy, że mamy dostęp do ID firmy "KOBAS Budownictwo Sp. z o.o." i ID typu kosztu "operacyjne"
            $default_company_id = 3; // ID firmy "KOBAS Budownictwo Sp. z o.o."
            $default_cost_type_id = 1; // ID typu kosztu "operacyjne"

            foreach ($sections as $section_name => $section_fields):
            ?>
                <div class="form-section mb-4">
                    <h3 class="section-title mb-3"><?php echo $section_name; ?></h3>
                    <div class="form-fields">
                        <?php foreach ($section_fields as $field): ?>
                            <div class="form-group">
                                <label for="<?php echo $field; ?>" class="form-label"><?php echo $fields[$field]; ?></label>
                                <div class="form-field">
                                    <?php if ($field === 'company_id'): ?>
                                        <select class="form-select" id="<?php echo $field; ?>" name="<?php echo $field; ?>" <?php echo in_array($field, $required_fields) ? 'required' : ''; ?>>
                                            <?php foreach ($companies as $company): ?>
                                                <option value="<?php echo $company['id']; ?>" <?php echo ($company['id'] == $default_company_id) ? 'selected' : ''; ?>>
                                                    <?php echo htmlspecialchars($company['name']); ?>
                                                </option>
                                            <?php endforeach; ?>
                                        </select>
                                    <?php elseif ($field === 'cost_type_id'): ?>
                                        <select class="form-select" id="<?php echo $field; ?>" name="<?php echo $field; ?>">
                                            <?php foreach ($costTypes as $costType): ?>
                                                <option value="<?php echo $costType['id']; ?>" <?php echo ($costType['id'] == $default_cost_type_id) ? 'selected' : ''; ?>>
                                                    <?php echo htmlspecialchars($costType['name']); ?>
                                                </option>
                                            <?php endforeach; ?>
                                        </select>
                                    <?php elseif ($field === 'amount'): ?>
                                        <input type="number" class="form-control" id="<?php echo $field; ?>" name="<?php echo $field; ?>" step="0.01" <?php echo in_array($field, $required_fields) ? 'required' : ''; ?>>
                                    <?php elseif ($field === 'date'): ?>
                                        <input type="date" class="form-control" id="<?php echo $field; ?>" name="<?php echo $field; ?>" value="<?php echo date('Y-m-d'); ?>">
                                    <?php elseif ($field === 'description'): ?>
                                        <textarea class="form-control" id="<?php echo $field; ?>" name="<?php echo $field; ?>" rows="3"></textarea>
                                    <?php elseif ($field === 'is_general'): ?>
                                        <div class="form-check">
                                            <input type="checkbox" class="form-check-input" id="<?php echo $field; ?>" 
                                                   name="<?php echo $field; ?>" 
                                                   <?php echo isset($cost['is_general']) && $cost['is_general'] ? 'checked' : ''; ?>>
                                            <label class="form-check-label" for="<?php echo $field; ?>">Koszt ogólny</label>
                                        </div>
                                    <?php elseif ($field === 'relation_type'): ?>
                                        <select class="form-select" id="<?php echo $field; ?>" 
                                                name="<?php echo $field; ?>" 
                                                <?php echo isset($cost['is_general']) && $cost['is_general'] ? 'disabled' : ''; ?>>
                                            <option value="none">Brak</option>
                                            <option value="vehicle">Pojazd</option>
                                            <option value="equipment">Sprzęt</option>
                                            <option value="employee">Pracownik</option>
                                        </select>
                                    <?php elseif ($field === 'related_id'): ?>
                                        <div id="related_id_container" style="display: none;">
                                            <select class="form-select" id="<?php echo $field; ?>" name="<?php echo $field; ?>">
                                                <option value="">Wybierz obiekt</option>
                                            </select>
                                        </div>
                                    <?php elseif ($field === 'status'): ?>
                                        <select class="form-select" id="<?php echo $field; ?>" name="<?php echo $field; ?>">
                                            <option value="opłacone" selected>Opłacone</option>
                                            <option value="nieopłacone">Nieopłacone</option>
                                        </select>
                                    <?php endif; ?>
                                </div>
                            </div>
                        <?php endforeach; ?>
                    </div>
                </div>
            <?php endforeach; ?>
            <div class="text-center mt-4">
                <button type="submit" class="btn btn-primary btn-lg btn-submit">Dodaj koszt</button>
            </div>
        </form>
    </div>
</div>

<?php include 'footer.php'; ?>

<script src="/js/cost_add.js"></script>

<script>
document.addEventListener('DOMContentLoaded', function() {
    initializeCostAdd({
        lastCompanyId: '<?php echo $lastCompanyId; ?>',
        lastCostTypeId: '<?php echo $lastCostTypeId; ?>',
        lastRelationType: '<?php echo $lastRelationType; ?>'
    });
});
</script>
