<?php include 'header.php'; ?>

<div class="container mt-4">
    <div class="card shadow">
        <div class="card-header bg-primary text-white">
            <h2 class="mb-0">Edytuj koszt</h2>
        </div>
        <div class="card-body">
            <?php if (isset($_GET['error'])): ?>
                <div class="alert alert-danger" role="alert">
                    <?php echo htmlspecialchars($_GET['error']); ?>
                </div>
            <?php endif; ?>

            <?php if (isset($_GET['success'])): ?>
                <div class="alert alert-success" role="alert">
                    <?php echo htmlspecialchars($_GET['success']); ?>
                </div>
            <?php endif; ?>

            <form action="/cost/edit/<?php echo $cost['id']; ?>" method="POST" class="form-container">
                <?php
                $sections = [
                    'Dane podstawowe' => ['company_id', 'cost_type_id', 'amount', 'date'],
                    'Szczegóły' => ['description', 'is_general', 'relation_type', 'related_id'],
                    'Status' => ['status']
                ];

                $fields = [
                    'company_id' => 'Firma *',
                    'cost_type_id' => 'Typ kosztu',
                    'amount' => 'Kwota *',
                    'date' => 'Data',
                    'description' => 'Opis',
                    'is_general' => 'Koszt ogólny',
                    'relation_type' => 'Powiązany obiekt',
                    'related_id' => 'Wybierz obiekt',
                    'status' => 'Status'
                ];

                $required_fields = ['company_id', 'amount'];

                foreach ($sections as $section_name => $section_fields):
                ?>
                    <div class="form-section mb-4">
                        <h3 class="section-title mb-3"><?php echo $section_name; ?></h3>
                        <div class="form-fields">
                            <?php foreach ($section_fields as $field): ?>
                                <div class="form-group">
                                    <label for="<?php echo $field; ?>" class="form-label"><?php echo $fields[$field]; ?></label>
                                    <div class="form-field">
                                        <?php if ($field === 'company_id'): ?>
                                            <select class="form-select" id="<?php echo $field; ?>" name="<?php echo $field; ?>" <?php echo in_array($field, $required_fields) ? 'required' : ''; ?>>
                                                <?php foreach ($companies as $company): ?>
                                                    <option value="<?php echo $company['id']; ?>" <?php echo ($company['id'] == $cost['company_id']) ? 'selected' : ''; ?>>
                                                        <?php echo htmlspecialchars($company['name']); ?>
                                                    </option>
                                                <?php endforeach; ?>
                                            </select>
                                        <?php elseif ($field === 'cost_type_id'): ?>
                                            <select class="form-select" id="<?php echo $field; ?>" name="<?php echo $field; ?>">
                                                <?php foreach ($costTypes as $costType): ?>
                                                    <option value="<?php echo $costType['id']; ?>" <?php echo ($costType['id'] == $cost['cost_type_id']) ? 'selected' : ''; ?>>
                                                        <?php echo htmlspecialchars($costType['name']); ?>
                                                    </option>
                                                <?php endforeach; ?>
                                            </select>
                                        <?php elseif ($field === 'amount'): ?>
                                            <input type="number" class="form-control" id="<?php echo $field; ?>" name="<?php echo $field; ?>" step="0.01" value="<?php echo $cost['amount']; ?>" <?php echo in_array($field, $required_fields) ? 'required' : ''; ?>>
                                        <?php elseif ($field === 'date'): ?>
                                            <input type="date" class="form-control" id="<?php echo $field; ?>" name="<?php echo $field; ?>" value="<?php echo $cost['date']; ?>">
                                        <?php elseif ($field === 'description'): ?>
                                            <textarea class="form-control" id="<?php echo $field; ?>" name="<?php echo $field; ?>" rows="3"><?php echo htmlspecialchars($cost['description']); ?></textarea>
                                        <?php elseif ($field === 'is_general'): ?>
                                            <input type="hidden" name="is_general" value="0">
                                            <div class="form-check">
                                                <input type="checkbox" class="form-check-input" id="<?php echo $field; ?>" 
                                                       name="<?php echo $field; ?>" value="1"
                                                       <?php echo $cost['is_general'] ? 'checked' : ''; ?>>
                                                <label class="form-check-label" for="<?php echo $field; ?>">Koszt ogólny</label>
                                            </div>
                                        <?php elseif ($field === 'relation_type'): ?>
                                            <select class="form-select" id="<?php echo $field; ?>" 
                                                    name="<?php echo $field; ?>" 
                                                    <?php echo $cost['is_general'] ? 'disabled' : ''; ?>>
                                                <option value="none" <?php echo empty($cost['relation_type']) ? 'selected' : ''; ?>>Brak</option>
                                                <option value="vehicle" <?php echo $cost['relation_type'] === 'vehicle' ? 'selected' : ''; ?>>Pojazd</option>
                                                <option value="equipment" <?php echo $cost['relation_type'] === 'equipment' ? 'selected' : ''; ?>>Sprzęt</option>
                                                <option value="employee" <?php echo $cost['relation_type'] === 'employee' ? 'selected' : ''; ?>>Pracownik</option>
                                            </select>
                                        <?php elseif ($field === 'related_id'): ?>
                                            <div id="related_id_container" style="display: <?php echo empty($cost['relation_type']) ? 'none' : 'block'; ?>;">
                                                <select class="form-select" id="<?php echo $field; ?>" name="<?php echo $field; ?>">
                                                    <!-- Options will be populated dynamically -->
                                                </select>
                                            </div>
                                        <?php elseif ($field === 'status'): ?>
                                            <select class="form-select" id="<?php echo $field; ?>" name="<?php echo $field; ?>">
                                                <option value="opłacone" <?php echo $cost['status'] === 'opłacone' ? 'selected' : ''; ?>>Opłacone</option>
                                                <option value="nieopłacone" <?php echo $cost['status'] === 'nieopłacone' ? 'selected' : ''; ?>>Nieopłacone</option>
                                            </select>
                                        <?php endif; ?>
                                    </div>
                                </div>
                            <?php endforeach; ?>
                        </div>
                    </div>
                <?php endforeach; ?>
                <div class="text-center mt-4">
                    <button type="submit" class="btn btn-primary btn-lg btn-submit">Zapisz zmiany</button>
                </div>
            </form>
        </div>
    </div>
</div>

<?php include 'footer.php'; ?>

<script>
document.addEventListener('DOMContentLoaded', function() {
    const isGeneralCheckbox = document.getElementById('is_general');
    const relationTypeSelect = document.getElementById('relation_type');
    const relatedIdContainer = document.getElementById('related_id_container');
    const relatedId = document.getElementById('related_id');

    console.log('Initial state:', {
        isGeneral: isGeneralCheckbox?.checked,
        relationType: relationTypeSelect?.value,
        relatedIdVisible: relatedIdContainer?.style.display
    });

    // Dodajmy nasłuchiwanie na submit formularza
    document.querySelector('form').addEventListener('submit', function(e) {
        // e.preventDefault(); // odkomentuj do debugowania
        
        const formData = new FormData(this);
        console.log('Submitting form with data:', {
            is_general: formData.get('is_general'),
            relation_type: formData.get('relation_type'),
            related_id: formData.get('related_id')
        });
    });

    // Obsługa checkboxa "Koszt ogólny"
    if (isGeneralCheckbox) {
        isGeneralCheckbox.addEventListener('change', function() {
            console.log('Checkbox changed:', {
                checked: this.checked,
                previousRelationType: relationTypeSelect.value
            });

            if (this.checked) {
                console.log('Setting cost as general');
                relationTypeSelect.value = 'none';
                relationTypeSelect.disabled = true;
                relatedIdContainer.style.display = 'none';
                relatedId.value = '';
            } else {
                console.log('Setting cost as specific');
                relationTypeSelect.disabled = false;
                // Usuńmy disabled przy submicie
                relationTypeSelect.form.addEventListener('submit', function() {
                    relationTypeSelect.disabled = false;
                });
                if (relationTypeSelect.value !== 'none') {
                    relatedIdContainer.style.display = 'block';
                    fetchRelatedEntities(relationTypeSelect.value);
                }
            }
        });

        // Ustaw początkowy stan
        if (isGeneralCheckbox.checked) {
            console.log('Initially general cost, setting up form');
            relationTypeSelect.value = 'none';
            relationTypeSelect.disabled = true;
            relatedIdContainer.style.display = 'none';
        }
    }

    // Obsługa zmiany typu relacji
    if (relationTypeSelect) {
        relationTypeSelect.addEventListener('change', function() {
            console.log('Relation type changed:', {
                newValue: this.value,
                isGeneralChecked: isGeneralCheckbox.checked
            });

            if (this.value === 'none') {
                console.log('No relation selected, hiding related id container');
                relatedIdContainer.style.display = 'none';
                relatedId.innerHTML = '<option value="">Wybierz obiekt</option>';
            } else {
                console.log('Relation selected, showing related id container');
                relatedIdContainer.style.display = 'block';
                fetchRelatedEntities(this.value);
            }
        });
    }

    function fetchRelatedEntities(type) {
        fetch('/get-related-entities/' + type)
            .then(response => response.json())
            .then(data => {
                relatedId.innerHTML = '<option value="">Wybierz obiekt</option>';
                data.forEach(item => {
                    const option = document.createElement('option');
                    option.value = item.id;
                    option.textContent = item.name;
                    if (item.id == <?php echo json_encode($cost['related_id']); ?>) {
                        option.selected = true;
                    }
                    relatedId.appendChild(option);
                });
            })
            .catch(error => {
                console.error('Error:', error);
                relatedId.innerHTML = '<option value="">Błąd podczas ładowania danych</option>';
            });
    }

    // Inicjalizacja przy ładowaniu strony
    if (!isGeneralCheckbox.checked && relationTypeSelect.value !== 'none') {
        fetchRelatedEntities(relationTypeSelect.value);
    }
});
</script>
