<?php include 'header.php'; ?>

<?php if (isset($_GET['success'])): ?>
    <div class="alert alert-success" role="alert">
        <?php echo htmlspecialchars($_GET['success']); ?>
    </div>
<?php endif; ?>

<div class="container">
    <div class="section-header mb-3 d-flex justify-content-between align-items-center">
        <h2>Lista kosztów</h2>
        <div>
            <button id="filterToggle" class="btn btn-secondary me-2">
                <i class="fas fa-filter"></i> Filtry
            </button>
            <a href="/cost-types" class="btn btn-info me-2">
                <i class="fas fa-tags"></i> Typy kosztów
            </a>
            <a href="/cost/add" class="btn btn-primary">
                <i class="fas fa-plus"></i> Dodaj koszt
            </a>
        </div>
    </div>

    <div id="filterPanel" class="card shadow mb-4" style="display: none;">
        <div class="card-body">
            <form id="filterForm" class="compact-form">
                <div class="row g-2">
                    <div class="col-md-3 col-sm-6">
                        <label for="dateFrom" class="form-label-sm">Data od:</label>
                        <input type="date" id="dateFrom" name="dateFrom" class="form-control form-control-sm">
                    </div>
                    <div class="col-md-3 col-sm-6">
                        <label for="dateTo" class="form-label-sm">Data do:</label>
                        <input type="date" id="dateTo" name="dateTo" class="form-control form-control-sm">
                    </div>
                    <div class="col-md-3 col-sm-6">
                        <label for="company" class="form-label-sm">Firma:</label>
                        <select id="company" name="company" class="form-select form-select-sm">
                            <option value="">Wszystkie</option>
                            <?php foreach ($companies as $company): ?>
                                <option value="<?php echo $company['id']; ?>"><?php echo htmlspecialchars($company['name']); ?></option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                    <div class="col-md-3 col-sm-6">
                        <label for="costType" class="form-label-sm">Typ kosztu:</label>
                        <select id="costType" name="costType" class="form-select form-select-sm">
                            <option value="">Wszystkie</option>
                            <?php foreach ($costTypes as $costType): ?>
                                <option value="<?php echo $costType['id']; ?>"><?php echo htmlspecialchars($costType['name']); ?></option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                    <div class="col-md-3 col-sm-6">
                        <label for="relationType" class="form-label-sm">Typ obiektu:</label>
                        <select id="relationType" name="relationType" class="form-select form-select-sm">
                            <option value="">Wszystkie</option>
                            <option value="vehicle">Pojazdy</option>
                            <option value="equipment">Sprzęt</option>
                            <option value="employee">Pracownicy</option>
                            <option value="general">Koszty ogólne</option>
                        </select>
                    </div>
                    <div class="col-md-3 col-sm-6" id="relatedObjectContainer" style="display: none;">
                        <label for="relatedId" class="form-label-sm">Wybierz obiekt:</label>
                        <select id="relatedId" name="relatedId" class="form-select form-select-sm">
                            <option value="">Wszystkie</option>
                        </select>
                    </div>
                </div>
                <div class="row g-2 mt-2">
                    <div class="col-md-3 col-sm-6">
                        <label for="status" class="form-label-sm">Status:</label>
                        <select id="status" name="status" class="form-select form-select-sm">
                            <option value="">Wszystkie</option>
                            <option value="opłacone">Opłacone</option>
                            <option value="nieopłacone">Nieopłacone</option>
                        </select>
                    </div>
                    <div class="col-md-6 col-sm-12">
                        <label for="keyword" class="form-label-sm">Słowo kluczowe:</label>
                        <input type="text" id="keyword" name="keyword" class="form-control form-control-sm" placeholder="Szukaj w opisie...">
                    </div>
                    <div class="col-md-3 col-sm-12 d-flex align-items-end">
                        <button type="submit" class="btn btn-primary btn-sm me-2">Zastosuj filtry</button>
                        <button type="reset" class="btn btn-secondary btn-sm">Wyczyść</button>
                    </div>
                </div>
            </form>
        </div>
    </div>

    <div id="costsSummary" class="card shadow mb-3" style="display: none;">
        <div class="card-body">
            <div class="d-flex justify-content-between align-items-center">
                <h5 class="mb-0">Podsumowanie</h5>
                <div>
                    <strong>Suma kosztów: </strong>
                    <span id="totalCosts" class="text-primary"></span>
                </div>
            </div>
        </div>
    </div>

    <div id="costsTableContainer">
        <?php include 'partials/costs_table.php'; ?>
    </div>
</div>

<script>
document.addEventListener('DOMContentLoaded', function() {
    const filterToggle = document.getElementById('filterToggle');
    const filterPanel = document.getElementById('filterPanel');
    const filterForm = document.getElementById('filterForm');
    const costsTableContainer = document.getElementById('costsTableContainer');

    // Dodajemy zmienną do śledzenia, czy dane są już ładowane
    let isLoading = false;

    filterToggle.addEventListener('click', function() {
        filterPanel.style.display = filterPanel.style.display === 'none' ? 'block' : 'none';
    });

    function loadCosts(filters = {}) {
        if (isLoading) {
            console.log('Loading in progress, skipping request');
            return;
        }
        isLoading = true;
        console.log('Starting loadCosts with filters:', filters);

        const queryString = new URLSearchParams(filters).toString();
        console.log('Generated query string:', queryString);

        costsTableContainer.innerHTML = '<div class="text-center"><i class="fas fa-spinner fa-spin"></i> Ładowanie...</div>';

        fetch('/api/costs?' + queryString)
            .then(response => {
                if (!response.ok) {
                    throw new Error('Network response was not ok');
                }
                return response.json();
            })
            .then(data => {
                console.log('Received data:', data);
                
                // Wyświetl podsumowanie
                const costsSummary = document.getElementById('costsSummary');
                const totalCosts = document.getElementById('totalCosts');
                
                if (data.success && data.total !== undefined) {
                    costsSummary.style.display = 'block';
                    totalCosts.textContent = new Intl.NumberFormat('pl-PL', {
                        style: 'currency',
                        currency: 'PLN'
                    }).format(data.total);
                } else {
                    costsSummary.style.display = 'none';
                }

                if (data.success && data.data.length > 0) {
                    let html = `
                    <div class="card shadow">
                        <div class="card-body">
                            <div class="table-responsive">
                                <table class="table">
                                    <thead>
                                        <tr>
                                            <th>Lp.</th>
                                            <th>Data</th>
                                            <th>Kwota</th>
                                            <th>Obiekt</th>
                                            <th>Opis</th>
                                            <th>Akcje</th>
                                        </tr>
                                    </thead>
                                    <tbody>`;

                    data.data.forEach((cost, index) => {
                        let objectName = 'Ogólny';
                        if (!cost.is_general) {
                            switch (cost.relation_type) {
                                case 'vehicle':
                                    objectName = cost.related_name || 'Brak danych';
                                    break;
                                case 'equipment':
                                    objectName = 'Sprzęt: ' + (cost.related_name || 'Brak danych');
                                    break;
                                case 'employee':
                                    objectName = 'Pracownik: ' + (cost.related_name || 'Brak danych');
                                    break;
                                default:
                                    objectName = 'Ogólny';
                            }
                        }

                        const description = cost.description || '';
                        const truncatedDescription = description.length > 50 ? 
                            description.substring(0, 50) + '...' : 
                            description;

                        html += `
                            <tr>
                                <td data-label="Lp.">${index + 1}</td>
                                <td data-label="Data">${cost.date}</td>
                                <td data-label="Kwota">${Number(cost.amount).toLocaleString('pl-PL', {minimumFractionDigits: 2, maximumFractionDigits: 2})} zł</td>
                                <td data-label="Obiekt">${objectName}</td>
                                <td data-label="Opis">${truncatedDescription}</td>
                                <td data-label="Akcje">
                                    <div class="btn-group" role="group" aria-label="Akcje kosztu">
                                        <a href="/cost/details/${cost.id}" class="btn btn-outline-primary btn-sm" title="Szczegóły">
                                            <i class="fas fa-info-circle"></i>
                                        </a>
                                        <a href="/cost/edit/${cost.id}" class="btn btn-outline-secondary btn-sm" title="Edytuj">
                                            <i class="fas fa-edit"></i>
                                        </a>
                                        <button type="button" class="btn btn-outline-danger btn-sm" title="Usuń" onclick="confirmDelete(${cost.id})">
                                            <i class="fas fa-trash-alt"></i>
                                        </button>
                                    </div>
                                </td>
                            </tr>`;
                    });

                    html += `
                                    </tbody>
                                </table>
                            </div>
                        </div>
                    </div>`;
                    
                    costsTableContainer.innerHTML = html;
                } else {
                    costsTableContainer.innerHTML = '<div class="alert alert-info">Brak kosztów do wyświetlenia.</div>';
                }
            })
            .catch(error => {
                console.error('Error in loadCosts:', error);
                costsTableContainer.innerHTML = '<div class="alert alert-danger">Wystąpił błąd podczas ładowania danych: ' + error.message + '</div>';
            })
            .finally(() => {
                isLoading = false;
            });
    }

    filterForm.addEventListener('submit', function(e) {
        e.preventDefault();
        console.log('Form submitted');
        
        const formData = new FormData(filterForm);
        const filters = Object.fromEntries(formData.entries());
        
        // Usuń puste filtry
        Object.keys(filters).forEach(key => {
            if (!filters[key]) {
                delete filters[key];
            }
        });
        
        console.log('Processed filters:', filters);
        loadCosts(filters);
    });

    filterForm.addEventListener('reset', function(e) {
        e.preventDefault();
        console.log('Form reset triggered');
        filterForm.reset();
        console.log('Loading costs without filters');
        loadCosts();
    });

    // Dodaj te zmienne na początku skryptu
    const relationTypeSelect = document.getElementById('relationType');
    const relatedObjectContainer = document.getElementById('relatedObjectContainer');
    const relatedIdSelect = document.getElementById('relatedId');

    // Dodaj ten kod przed końcem addEventListener('DOMContentLoaded')
    relationTypeSelect.addEventListener('change', function() {
        const selectedType = this.value;
        
        if (selectedType && selectedType !== 'general') {
            relatedObjectContainer.style.display = 'block';
            
            fetch(`/api/get-objects/${selectedType}`)
                .then(response => response.json())
                .then(data => {
                    relatedIdSelect.innerHTML = '<option value="">Wszystkie</option>';
                    
                    data.forEach(object => {
                        const option = document.createElement('option');
                        option.value = object.id;
                        switch(selectedType) {
                            case 'vehicle':
                                option.textContent = `${object.brand} ${object.model}`;
                                break;
                            case 'equipment':
                                option.textContent = object.name;
                                break;
                            case 'employee':
                                option.textContent = `${object.first_name} ${object.last_name}`;
                                break;
                        }
                        relatedIdSelect.appendChild(option);
                    });
                });
        } else {
            relatedObjectContainer.style.display = 'none';
            relatedIdSelect.value = '';
        }
    });
});
</script>

<?php include 'footer.php'; ?>
