<?php
// app/views/document_add.php
include 'header.php';
error_log("Otrzymane dane POST: " . print_r($_POST, true));
error_log("Otrzymane pliki: " . print_r($_FILES, true));

$prefilledData = getPrefilledData($entityType, $entityId);
?>

<div class="container mt-4">
    <div class="card shadow">
        <div class="card-header bg-primary text-white">
            <h2 class="mb-0">Dodaj nowy dokument</h2>
            <?php if ($prefilledData['related_entity_name']): ?>
                <p class="mb-0">dla: <?php echo htmlspecialchars($prefilledData['related_entity_name']); ?></p>
            <?php endif; ?>
        </div>
        <div class="card-body">
            <?php if (isset($_GET['error'])): ?>
                <div class="alert alert-danger">
                    <?php
                    switch ($_GET['error']) {
                        case 'file_upload':
                            echo "Wystąpił błąd podczas przesyłania pliku.";
                            break;
                        case 'no_file':
                            echo "Nie wybrano pliku do przesłania.";
                            break;
                        default:
                            echo "Wystąpił błąd podczas dodawania dokumentu.";
                    }
                    ?>
                </div>
            <?php endif; ?>
            <form action="/document/add" method="post" enctype="multipart/form-data" class="form-container">
                <div class="form-section mb-4">
                    <h3 class="section-title mb-3">Informacje o dokumencie</h3>
                    <div class="form-fields">
                        <div class="form-group">
                            <label for="title" class="form-label required">Tytuł:</label>
                            <input type="text" id="title" name="title" class="form-control" value="<?php echo htmlspecialchars($prefilledData['title']); ?>" required>
                        </div>
                        <div class="form-group">
                            <label for="description" class="form-label">Opis:</label>
                            <textarea id="description" name="description" class="form-control"></textarea>
                        </div>
                        <div class="form-group">
                            <label for="category_id" class="form-label required">Kategoria:</label>
                            <select id="category_id" name="category_id" class="form-select" required>
                                <option value="">Wybierz kategorię</option>
                                <?php foreach ($categories as $category): ?>
                                    <option value="<?php echo $category['id']; ?>">
                                        <?php echo htmlspecialchars($category['name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="form-group">
                            <label for="company_id" class="form-label required">Firma:</label>
                            <select id="company_id" name="company_id" class="form-select" required>
                                <option value="">Wybierz firmę</option>
                                <?php foreach ($companies as $company): ?>
                                    <option value="<?php echo $company['id']; ?>" <?php echo ($company['id'] == $prefilledData['company_id']) ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($company['name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                    </div>
                </div>
                 
                <div class="form-section mb-4">
                    <h3 class="section-title mb-3">Plik dokumentu</h3>
                    <div class="form-fields">
                        <div class="form-group">
                            <label for="file" class="form-label required">Plik:</label>
                            <input type="file" id="file" name="file" class="form-control" required>
                        </div>
                    </div>
                </div>
                <div class="form-section mb-4">
                    <h3 class="section-title mb-3">Powiązanie dokumentu</h3>
                    <div class="form-fields">
                        <div class="form-group">
                            <label for="related_entity_type" class="form-label">Powiązany obiekt:</label>
                            <select id="related_entity_type" name="related_entity_type" class="form-select">
                                <option value="none" <?php echo !$entityType ? 'selected' : ''; ?>>Brak</option>
                                <option value="employee" <?php echo $entityType === 'employee' ? 'selected' : ''; ?>>Pracownik</option>
                                <option value="vehicle" <?php echo $entityType === 'vehicle' ? 'selected' : ''; ?>>Pojazd</option>
                                <option value="equipment" <?php echo $entityType === 'equipment' ? 'selected' : ''; ?>>Sprzęt</option>
                            </select>
                        </div>
                        <div class="form-group" id="related_entity_container" style="display: <?php echo $entityType ? 'block' : 'none'; ?>;">
                            <label for="related_entity_id" class="form-label">Wybierz obiekt:</label>
                            <select id="related_entity_id" name="related_entity_id" class="form-select">
                                <?php if ($entityId): ?>
                                    <option value="<?php echo $entityId; ?>" selected>
                                        <?php echo htmlspecialchars($prefilledData['related_entity_name']); ?>
                                    </option>
                                <?php endif; ?>
                            </select>
                        </div>
                    </div>
                </div>
                
                <div class="form-section mb-4">
                    <h3 class="section-title mb-3">Termin ważności</h3>
                    <div class="form-fields">
                        <div class="form-group">
                            <div class="form-check">
                                <input type="checkbox" id="has_expiry_date" name="has_expiry_date" class="form-check-input">
                                <label for="has_expiry_date" class="form-check-label">Dokument ma termin ważności</label>
                            </div>
                        </div>
                        <div id="expiry_date_fields" style="display:none;">
                            <div class="form-group">
                                <label for="policy_start_date" class="form-label">Data rozpoczęcia ważności:</label>
                                <input type="date" id="policy_start_date" name="policy_start_date" class="form-control">
                            </div>
                            <div class="form-group">
                                <label for="policy_end_date" class="form-label">Data zakończenia ważności:</label>
                                <input type="date" id="policy_end_date" name="policy_end_date" class="form-control">
                            </div>
                        </div>
                    </div>
                </div>
               
                
                <input type="hidden" name="referer" value="<?php echo htmlspecialchars($referer); ?>">
                <div class="text-center mt-4">
                    <button type="submit" class="btn btn-primary btn-lg btn-submit">Dodaj dokument</button>
                </div>
            </form>
        </div>
    </div>
</div>

<script>
    document.getElementById('has_expiry_date').addEventListener('change', function() {
        var expiryFields = document.getElementById('expiry_date_fields');
        expiryFields.style.display = this.checked ? 'block' : 'none';
    });
    
    document.getElementById('related_entity_type').addEventListener('change', function () {
        var container = document.getElementById('related_entity_container');
        var select = document.getElementById('related_entity_id');

        if (this.value === 'none') {
            container.style.display = 'none';
            select.innerHTML = '';
        } else {
            container.style.display = 'block';
            // Fetch related entities based on type
            fetch('/get-related-entities/' + this.value)
                .then(response => response.json())
                .then(data => {
                    select.innerHTML = '<option value="">Wybierz obiekt</option>';
                    data.forEach(item => {
                        var option = document.createElement('option');
                        option.value = item.id;
                        option.textContent = item.name;
                        select.appendChild(option);
                    });
                })
                .catch(error => {
                    console.error('Error:', error);
                    select.innerHTML = '<option value="">Błąd podczas ładowania danych</option>';
                });
        }
    });
</script>

<?php include 'footer.php'; ?>