<?php include 'header.php'; ?>

<div class="container mt-4">
    <div class="section-header mb-3 d-flex justify-content-between align-items-center">
        <h2>Kategorie dokumentów</h2>
        <a href="/document/add" class="btn btn-primary">
            <i class="fas fa-plus"></i> Dodaj dokument
        </a>
    </div>

    <div class="card shadow">
        <div class="card-body">
            <?php if (isset($_GET['success']) || isset($_GET['error'])): ?>
                <div class="alert <?php echo isset($_GET['success']) ? 'alert-success' : 'alert-danger'; ?>">
                    <?php
                    if (isset($_GET['success'])) {
                        switch ($_GET['success']) {
                            case 'added':
                                echo "Kategoria została dodana pomyślnie.";
                                break;
                            case 'updated':
                                echo "Kategoria została zaktualizowana pomyślnie.";
                                break;
                            case 'deleted':
                                echo "Kategoria została usunięta pomyślnie.";
                                break;
                        }
                    } elseif (isset($_GET['error'])) {
                        switch ($_GET['error']) {
                            case 'add_failed':
                                echo "Nie udało się dodać kategorii.";
                                break;
                            case 'update_failed':
                                echo "Nie udało się zaktualizować kategorii.";
                                break;
                            case 'delete_failed':
                                echo "Nie udało się usunąć kategorii.";
                                break;
                        }
                    }
                    ?>
                </div>
            <?php endif; ?>

            <div class="row">
                <div class="col-md-4">
                    <div class="card mb-4">
                        <div class="card-header">
                            <h3 class="card-title">Nowa kategoria</h3>
                        </div>
                        <div class="card-body">
                            <form action="/document/category/add" method="post" class="form-container">
                                <div class="form-group">
                                    <label for="name" class="form-label required">Nazwa kategorii:</label>
                                    <input type="text" id="name" name="name" class="form-control" required>
                                </div>
                                <div class="form-group">
                                    <label for="description" class="form-label">Opis:</label>
                                    <textarea id="description" name="description" class="form-control"></textarea>
                                </div>
                                <button type="submit" class="btn btn-primary btn-block">
                                    <i class="fas fa-plus"></i> Dodaj
                                </button>
                            </form>
                        </div>
                    </div>
                </div>
                <div class="col-md-8">
                    <div class="card">
                        <div class="card-header">
                            <h3 class="card-title">Istniejące kategorie</h3>
                        </div>
                        <div class="card-body">
                            <div class="table-responsive">
                                <table class="table">
                                    <thead>
                                        <tr>
                                            <th>Nazwa</th>
                                            <th>Opis</th>
                                            <th>Akcje</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <?php foreach ($categories as $category): ?>
                                            <tr>
                                                <td><?php echo htmlspecialchars($category['name']); ?></td>
                                                <td><?php echo htmlspecialchars($category['description']); ?></td>
                                                <td>
                                                    <div class="btn-group" role="group">
                                                        <button class="btn btn-sm btn-outline-secondary" 
                                                                data-id="<?php echo $category['id']; ?>" 
                                                                data-name="<?php echo htmlspecialchars($category['name']); ?>" 
                                                                data-description="<?php echo htmlspecialchars($category['description']); ?>">
                                                            <i class="fas fa-edit"></i>
                                                        </button>
                                                        <form method="post" action="/document/category/delete/<?php echo $category['id']; ?>" style="display:inline;">
                                                            <button type="submit" class="btn btn-sm btn-outline-danger" onclick="return confirm('Czy na pewno chcesz usunąć tę kategorię?')">
                                                                <i class="fas fa-trash-alt"></i>
                                                            </button>
                                                        </form>
                                                    </div>
                                                </td>
                                            </tr>
                                        <?php endforeach; ?>
                                    </tbody>
                                </table>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<!-- Modal do edycji kategorii -->
<div class="modal fade" id="editCategoryModal" tabindex="-1" role="dialog" aria-labelledby="editCategoryModalLabel" aria-hidden="true">
    <div class="modal-dialog" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="editCategoryModalLabel">Edytuj kategorię</h5>
                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
            </div>
            <div class="modal-body">
                <form id="editCategoryForm" method="post" class="form-container">
                    <div class="form-group">
                        <label for="edit-name" class="form-label required">Nazwa kategorii:</label>
                        <input type="text" id="edit-name" name="name" class="form-control" required>
                    </div>
                    <div class="form-group">
                        <label for="edit-description" class="form-label">Opis:</label>
                        <textarea id="edit-description" name="description" class="form-control"></textarea>
                    </div>
                    <button type="submit" class="btn btn-primary btn-block">Zapisz zmiany</button>
                </form>
            </div>
        </div>
    </div>
</div>

<script>
document.addEventListener('DOMContentLoaded', function() {
    const editButtons = document.querySelectorAll('.btn-outline-secondary');
    editButtons.forEach(button => {
        button.addEventListener('click', function(e) {
            e.preventDefault();
            const id = this.getAttribute('data-id');
            const name = this.getAttribute('data-name');
            const description = this.getAttribute('data-description');
            showEditForm(id, name, description);
        });
    });

    // Dodajemy obsługę zamknięcia modala
    const closeModalButtons = document.querySelectorAll('.modal .close');
    closeModalButtons.forEach(button => {
        button.addEventListener('click', function() {
            const modal = button.closest('.modal');
            if (modal) {
                $(modal).modal('hide');
            }
        });
    });
});

function showEditForm(id, name, description) {
    document.getElementById('editCategoryForm').action = '/document/category/edit/' + id;
    document.getElementById('edit-name').value = name;
    document.getElementById('edit-description').value = description;
    $('#editCategoryModal').modal('show');
}
</script>

<?php include 'footer.php'; ?>