<?php include 'header.php'; ?>

<div class="container mt-4">
    <div class="card shadow">
        <div class="card-header bg-primary text-white">
            <h2 class="mb-0">Edytuj dokument</h2>
        </div>
        <?php if (isset($_GET['error'])): ?>
            <div class="alert alert-danger">
                <?php
                switch ($_GET['error']) {
                    case 'file_upload':
                        echo "Wystąpił błąd podczas przesyłania pliku.";
                        break;
                    case 'update_failed':
                        echo "Nie udało się zaktualizować dokumentu.";
                        break;
                    default:
                        echo "Wystąpił błąd.";
                }
                ?>
            </div>
        <?php endif; ?>
        <form action="/document/edit/<?php echo $document['id']; ?>?redirect_to=<?php echo urlencode($return_to); ?>" method="post" enctype="multipart/form-data" class="form-container">
            <input type="hidden" name="entity_type" value="<?php echo htmlspecialchars($entityType ?? ''); ?>">
            <input type="hidden" name="entity_id" value="<?php echo htmlspecialchars($entityId ?? ''); ?>">

            <div class="form-section mb-4">
                <h3 class="section-title mb-3">Informacje o dokumencie</h3>
                <div class="form-fields">
                    <div class="form-group">
                        <label for="title" class="form-label required">Tytuł:</label>
                        <input type="text" id="title" name="title" class="form-control" value="<?php echo htmlspecialchars($document['title']); ?>" required>
                    </div>
                    <div class="form-group">
                        <label for="description" class="form-label">Opis:</label>
                        <textarea id="description" name="description" class="form-control"><?php echo htmlspecialchars($document['description']); ?></textarea>
                    </div>
                    <div class="form-group">
                        <label for="category_id" class="form-label required">Kategoria:</label>
                        <select id="category_id" name="category_id" class="form-select" required>
                            <?php foreach ($categories as $category): ?>
                                <option value="<?php echo $category['id']; ?>" <?php echo $category['id'] == $document['category_id'] ? 'selected' : ''; ?>>
                                    <?php echo htmlspecialchars($category['name']); ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                    <div class="form-group">
                        <label for="company_id" class="form-label required">Firma:</label>
                        <select id="company_id" name="company_id" class="form-select" required>
                            <?php foreach ($companies as $company): ?>
                                <option value="<?php echo $company['id']; ?>" <?php echo $company['id'] == $document['company_id'] ? 'selected' : ''; ?>>
                                    <?php echo htmlspecialchars($company['name']); ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                </div>
            </div>

            <div class="form-section mb-4">
                <h3 class="section-title mb-3">Powiązanie dokumentu</h3>
                <div class="form-fields">
                    <div class="form-group">
                        <label for="related_entity_type" class="form-label">Powiązany obiekt:</label>
                        <select id="related_entity_type" name="related_entity_type" class="form-select">
                            <option value="none" <?php echo $document['related_entity_type'] == 'none' ? 'selected' : ''; ?>>Brak</option>
                            <option value="employee" <?php echo $document['related_entity_type'] == 'employee' ? 'selected' : ''; ?>>Pracownik</option>
                            <option value="vehicle" <?php echo $document['related_entity_type'] == 'vehicle' ? 'selected' : ''; ?>>Pojazd</option>
                            <option value="equipment" <?php echo $document['related_entity_type'] == 'equipment' ? 'selected' : ''; ?>>Sprzęt</option>
                        </select>
                    </div>
                    <div class="form-group" id="related_entity_container" style="display: <?php echo $document['related_entity_type'] != 'none' ? 'block' : 'none'; ?>;">
                        <label for="related_entity_id" class="form-label">Wybierz obiekt:</label>
                        <select id="related_entity_id" name="related_entity_id" class="form-select">
                            <!-- Options will be populated dynamically -->
                        </select>
                    </div>
                </div>
            </div>

            <div class="form-section mb-4">
                <h3 class="section-title mb-3">Termin ważności</h3>
                <div class="form-fields">
                    <div class="form-group">
                        <label for="has_expiry_date" class="form-label">Dokument ma termin ważności:</label>
                        <input type="checkbox" id="has_expiry_date" name="has_expiry_date" <?php echo (!empty($document['policy_start_date']) || !empty($document['policy_end_date'])) ? 'checked' : ''; ?>>
                    </div>
                    <div id="expiry_date_fields" style="display:<?php echo (!empty($document['policy_start_date']) || !empty($document['policy_end_date'])) ? 'block' : 'none'; ?>;">
                        <div class="form-group">
                            <label for="policy_start_date" class="form-label">Data rozpoczęcia ważności:</label>
                            <input type="date" id="policy_start_date" name="policy_start_date" class="form-control" value="<?php echo htmlspecialchars($document['policy_start_date'] ?? ''); ?>">
                        </div>
                        <div class="form-group">
                            <label for="policy_end_date" class="form-label">Data zakończenia ważności:</label>
                            <input type="date" id="policy_end_date" name="policy_end_date" class="form-control" value="<?php echo htmlspecialchars($document['policy_end_date'] ?? ''); ?>">
                        </div>
                    </div>
                </div>
            </div>

            <div class="form-section mb-4">
                <h3 class="section-title mb-3">Plik dokumentu</h3>
                <div class="form-fields">
                    <div class="form-group">
                        <label for="file">Nowy plik (opcjonalnie):</label>
                        <input type="file" id="file" name="file" class="form-control">
                    </div>
                </div>
            </div>

            <div class="form-group">
                <label>Aktualny plik:</label>
                <a href="<?php echo htmlspecialchars($document['file_path']); ?>" target="_blank"><?php echo htmlspecialchars(basename($document['file_path'])); ?></a>
            </div>

            <div class="form-footer">
                <button type="submit" class="btn btn-primary">Zapisz zmiany</button>
            </div>
        </form>
    </div>
</div>

<script>
    document.getElementById('has_expiry_date').addEventListener('change', function() {
        var expiryFields = document.getElementById('expiry_date_fields');
        expiryFields.style.display = this.checked ? 'block' : 'none';
    });
    document.getElementById('related_entity_type').addEventListener('change', function () {
        var container = document.getElementById('related_entity_container');
        var select = document.getElementById('related_entity_id');

        if (this.value === 'none') {
            container.style.display = 'none';
            select.innerHTML = '';
        } else {
            container.style.display = 'block';
            // Fetch related entities based on type
            fetch('/get-related-entities/' + this.value)
                .then(response => response.json())
                .then(data => {
                    select.innerHTML = '<option value="">Wybierz obiekt</option>';
                    data.forEach(item => {
                        var option = document.createElement('option');
                        option.value = item.id;
                        option.textContent = item.name;
                        if (item.id == <?php echo json_encode($document['related_entity_id']); ?>) {
                            option.selected = true;
                        }
                        select.appendChild(option);
                    });
                })
                .catch(error => {
                    console.error('Error:', error);
                    select.innerHTML = '<option value="">Błąd podczas ładowania danych</option>';
                });
        }
    });

    // Trigger the change event to load related entities if needed
    document.getElementById('related_entity_type').dispatchEvent(new Event('change'));
</script>

<?php include 'footer.php'; ?>