<?php include 'header.php'; ?>

<div class="section-header mb-3 d-flex justify-content-between align-items-center">
    <h2>Lista dokumentów</h2>
    <div class="btn-group" role="group" aria-label="Akcje dokumentów">
        <a href="/document/add" class="btn btn-primary btn-add-document">
            <i class="fas fa-plus"></i> Dodaj dokument
        </a>
        <a href="/document/categories" class="btn btn-secondary">
            <i class="fas fa-tags"></i> Kategorie
        </a>
        <a href="/document-templates" class="btn btn-info"> <!-- Poprawiony link do szablonów -->
            <i class="fas fa-file-alt"></i> Szablony
        </a>
    </div>
</div>

<div class="card shadow">
    <div class="card-body">
        <!-- Belka z wyszukiwaniem i filtrami -->
        <div class="filter-bar mb-3">
            <div class="search-group">
                <div class="search-input-wrapper">
                    <input type="text" id="search-input" class="form-control" placeholder="Szukaj dokumentu..."
                        value="<?php echo htmlspecialchars($currentSearch); ?>">
                    <i class="fas fa-search search-icon"></i>
                    <i class="fas fa-times clear-search-icon" id="clear-search-icon" style="display: none;"></i>
                </div>
                <div id="search-suggestions" class="search-suggestions"></div>
            </div>
            <div class="category-filter">
                <select id="category-select" class="form-control">
                    <option value="">Wszystkie kategorie</option>
                    <?php foreach ($categories as $category): ?>
                        <option value="<?php echo $category['id']; ?>" <?php echo $currentCategoryId == $category['id'] ? 'selected' : ''; ?>>
                            <?php echo htmlspecialchars($category['name']); ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>
            <div class="company-filter">
                <select id="company-select" class="form-control">
                    <option value="">Wszystkie firmy</option>
                    <?php foreach ($companies as $company): ?>
                        <option value="<?php echo $company['id']; ?>" <?php echo $currentCompanyId == $company['id'] ? 'selected' : ''; ?>>
                            <?php echo htmlspecialchars($company['name']); ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>
        </div>

        <div class="table-responsive">
            <table class="table">
                <thead>
                    <tr>
                        <th>Lp.</th>
                        <th>Nazwa dokumentu</th>
                        <th>Powiązany obiekt</th>
                        <th>Data dodania</th>
                        <th>Kategoria</th>
                        <th>Typ dodania</th>
                        <th>Akcje</th>
                    </tr>
                </thead>
                <tbody id="document-list">
                    <?php foreach ($documents as $index => $document): ?>
                        <tr>
                            <td><?php echo $index + 1; ?></td>
                            <td><?php echo htmlspecialchars($document['title']); ?></td>
                            <td>
                                <?php
                                if ($document['related_entity_type'] && $document['related_entity_id']) {
                                    echo htmlspecialchars($document['related_entity_name']);
                                } else {
                                    echo "Brak";
                                }
                                ?>
                            </td>
                            <td><?php echo date('Y-m-d', strtotime($document['created_at'])); ?></td>
                            <td><?php echo htmlspecialchars($document['category_name']); ?></td>
                            <td><?php echo $document['is_generated'] ? 'Automatycznie' : 'Ręcznie'; ?></td>
                            <td>
                                <div class="btn-group" role="group" aria-label="Akcje dokumentu">
                                    <a href="/document/download/<?php echo $document['id']; ?>" class="btn btn-outline-primary btn-sm" title="Pobierz">
                                        <i class="fas fa-download"></i>
                                    </a>
                                    <a href="/document/edit/<?php echo $document['id']; ?>?redirect_to=<?php echo urlencode('/documents'); ?>" class="btn btn-outline-secondary btn-sm" title="Edytuj">
                                        <i class="fas fa-edit"></i>
                                    </a>
                                    <a href="/document/view/<?php echo $document['id']; ?>" class="btn btn-outline-info btn-sm" title="Szczegóły">
                                        <i class="fas fa-eye"></i>
                                    </a>
                                    <button type="button" class="btn btn-outline-danger btn-sm delete-document" data-id="<?php echo $document['id']; ?>" title="Usuń">
                                        <i class="fas fa-trash-alt"></i>
                                    </button>
                                </div>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>
</div>

<script>
document.addEventListener('DOMContentLoaded', function () {
    console.log('Skrypt dokumentów załadowany');
    const filterButtons = document.querySelectorAll('.filter-btn');
    const searchInput = document.getElementById('search-input');
    const categorySelect = document.getElementById('category-select');
    const companySelect = document.getElementById('company-select');
    const searchSuggestions = document.getElementById('search-suggestions');
    const clearSearchIcon = document.getElementById('clear-search-icon');
    let debounceTimer;

    function updateList() {
        const filter = document.querySelector('.filter-btn.active')?.dataset.filter || '';
        const search = searchInput.value;
        const categoryId = categorySelect?.value || '';
        const companyId = companySelect.value;

        let url = `?search=${encodeURIComponent(search)}&company_id=${companyId}`;
        if (filter) url += `&filter=${filter}`;
        if (categoryId) url += `&category_id=${categoryId}`;

        window.location.href = url;
    }

    function toggleClearIcon() {
        clearSearchIcon.style.display = searchInput.value ? 'block' : 'none';
    }

    clearSearchIcon.addEventListener('click', function() {
        searchInput.value = '';
        toggleClearIcon();
        updateList();
    });

    searchInput.addEventListener('input', function() {
        toggleClearIcon();
        clearTimeout(debounceTimer);
        debounceTimer = setTimeout(() => {
            updateList();
        }, 300);
    });

    filterButtons.forEach(button => {
        button.addEventListener('click', function () {
            filterButtons.forEach(btn => btn.classList.remove('active'));
            this.classList.add('active');
            updateList();
        });
    });

    if (categorySelect) categorySelect.addEventListener('change', updateList);
    companySelect.addEventListener('change', updateList);

    searchInput.addEventListener('keypress', function (e) {
        if (e.key === 'Enter') {
            updateList();
        }
    });

    const searchIcon = document.querySelector('.search-icon');
    searchIcon.addEventListener('click', updateList);

    // Obsługa przycisku usuwania
    const deleteButtons = document.querySelectorAll('.delete-document');
    console.log('Znalezione przyciski usuwania:', deleteButtons.length);
    deleteButtons.forEach(button => {
        button.addEventListener('click', function(e) {
            e.preventDefault();
            const documentId = this.dataset.id;
            confirmDocumentDelete(documentId);
        });
    });

    toggleClearIcon(); // Wywołaj na początku, aby ustawić początkowy stan ikony
});

function confirmDocumentDelete(documentId) {
    console.log('Próba usunięcia dokumentu o ID:', documentId);
    if (confirm('Czy na pewno chcesz usunąć ten dokument?')) {
        const form = document.createElement('form');
        form.method = 'POST';
        form.action = `/document/delete/${documentId}`;
        document.body.appendChild(form);
        console.log('Formularz utworzony:', form);
        form.submit();
        console.log('Formularz wysłany');
    }
}
</script>

<?php include 'footer.php'; ?>
