<?php include 'header.php'; ?>

<div class="container mt-4">
    <div class="card shadow">
        <div class="card-header bg-primary text-white">
            <h2 class="mb-0">Edytuj szablon dokumentu</h2>
        </div>
        <?php if (isset($_GET['error'])): ?>
            <div class="alert alert-danger">
                <?php
                switch ($_GET['error']) {
                    case 'update_failed':
                        echo "Nie udało się zaktualizować szablonu.";
                        break;
                    default:
                        echo "Wystąpił błąd.";
                }
                ?>
            </div>
        <?php endif; ?>
        <form id="templateForm" action="/document-template/edit/<?php echo $template['id']; ?>" method="post" class="form-container" enctype="multipart/form-data">
            <input type="hidden" name="template_id" value="<?php echo $template['id']; ?>">

            <div class="form-section mb-4">
                <h3 class="section-title mb-3">Informacje o szablonie</h3>
                <div class="form-fields">
                    <div class="form-group">
                        <label for="name" class="form-label required">Nazwa szablonu:</label>
                        <input type="text" id="name" name="name" class="form-control" value="<?php echo htmlspecialchars($template['name']); ?>" required>
                    </div>
                    <div class="form-group">
                        <label for="category_id" class="form-label required">Kategoria:</label>
                        <select id="category_id" name="category_id" class="form-select" required>
                            <option value="">Wybierz kategorię</option>
                            <?php foreach ($categories as $category): ?>
                                <option value="<?php echo $category['id']; ?>" <?php echo ($category['id'] == $template['category_id']) ? 'selected' : ''; ?>><?php echo htmlspecialchars($category['name']); ?></option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                </div>
            </div>

            <div class="form-section mb-4">
                <h3 class="section-title mb-3">Zawartość szablonu</h3>
                <div class="form-fields">
                    <div class="form-group">
                        <label for="html_template" class="form-label required">Szablon HTML:</label>
                        <textarea id="html_template" name="html_template" class="form-control" rows="10" required><?php echo htmlspecialchars($template['html_template'] ?? ''); ?></textarea>
                    </div>
                    <div class="form-group">
                        <label for="css_styles" class="form-label">Style CSS:</label>
                        <textarea id="css_styles" name="css_styles" class="form-control" rows="5"><?php echo htmlspecialchars($template['css_styles'] ?? ''); ?></textarea>
                    </div>
                    <div class="form-group">
                        <label for="form_structure" class="form-label">Struktura formularza (JSON):</label>
                        <textarea id="form_structure" name="form_structure" class="form-control" rows="10"><?php echo htmlspecialchars($template['form_structure'] ?? '[]'); ?></textarea>
                    </div>
                    <div class="form-group">
                        <label for="background_image">Obraz lub PDF tła:</label>
                        <input type="file" id="background_image" name="background_image" class="form-control" accept=".jpg,.jpeg,.png,.gif,.pdf">
                        <?php if (!empty($template['background_image'])): ?>
                            <p>Aktualny plik tła: <?php echo htmlspecialchars(basename($template['background_image'])); ?></p>
                        <?php endif; ?>
                    </div>
                </div>
            </div>

            <div class="form-footer">
                <button type="submit" class="btn btn-primary">Aktualizuj szablon</button>
                <button type="button" id="previewButton" class="btn btn-secondary">Podgląd</button>
            </div>
        </form>
    </div>
</div>

<div id="previewContainer" style="display: none;">
    <h3>Podgląd dokumentu</h3>
    <iframe id="previewFrame" style="width: 100%; height: 600px; border: 1px solid #ccc;"></iframe>
</div>

<script>
    document.addEventListener('DOMContentLoaded', function() {
        const previewButton = document.getElementById('previewButton');
        const previewContainer = document.getElementById('previewContainer');
        const previewFrame = document.getElementById('previewFrame');
        const templateForm = document.getElementById('templateForm');

        previewButton.addEventListener('click', function(e) {
            e.preventDefault();
            const formData = new FormData(templateForm);
            formData.append('action', 'preview');

            fetch('/document-template/preview', {
                method: 'POST',
                body: formData
            })
            .then(response => response.blob())
            .then(blob => {
                const url = URL.createObjectURL(blob);
                previewFrame.src = url;
                previewContainer.style.display = 'block';
            })
            .catch(error => {
                console.error('Error:', error);
                alert('Wystąpił błąd podczas generowania podglądu.');
            });
        });
    });
</script>

<?php include 'footer.php'; ?>