<?php include 'header.php'; ?>

<div class="container mt-4">
    <div class="card shadow">
        <div class="card-header bg-primary text-white">
            <h2 class="mb-0">Szczegóły dokumentu</h2>
        </div>
        <div class="card-body">
            <div class="form-container">
                <div class="form-section mb-4">
                    <h3 class="section-title mb-3">Informacje podstawowe</h3>
                    <div class="form-fields">
                        <?php
                        $basicDetails = [
                            'Tytuł' => $document['title'],
                            'Kategoria' => $category['name'],
                            'Firma' => $company['name'],
                            'Typ pliku' => $document['file_type'],
                        ];

                        foreach ($basicDetails as $label => $value):
                        ?>
                            <div class="form-group">
                                <label class="form-label"><?php echo htmlspecialchars($label); ?>:</label>
                                <div class="form-control-plaintext"><?php echo htmlspecialchars($value); ?></div>
                            </div>
                        <?php endforeach; ?>
                    </div>
                </div>

                <div class="form-section mb-4">
                    <h3 class="section-title mb-3">Daty</h3>
                    <div class="form-fields">
                        <?php
                        $dateDetails = [
                            'Data utworzenia' => date('d.m.Y', strtotime($document['created_at'])),
                            'Data rozpoczęcia' => !empty($document['policy_start_date']) ? date('d.m.Y', strtotime($document['policy_start_date'])) : 'Nie określono',
                            'Data zakończenia' => !empty($document['policy_end_date']) ? date('d.m.Y', strtotime($document['policy_end_date'])) : 'Nie określono',
                        ];

                        foreach ($dateDetails as $label => $value):
                        ?>
                            <div class="form-group">
                                <label class="form-label"><?php echo htmlspecialchars($label); ?>:</label>
                                <div class="form-control-plaintext"><?php echo htmlspecialchars($value); ?></div>
                            </div>
                        <?php endforeach; ?>
                    </div>
                </div>

                <div class="form-section mb-4">
                    <h3 class="section-title mb-3">Informacje dodatkowe</h3>
                    <div class="form-fields">
                        <?php
                        $additionalDetails = [
                            'Utworzony przez' => $createdBy['name'],
                            'Numer dokumentu' => $document['policy_number'] ?? 'Nie dotyczy',
                            'Powiązany obiekt' => $relatedEntity ? (
                                $document['related_entity_type'] === 'employee' ? $relatedEntity['first_name'] . ' ' . $relatedEntity['last_name'] :
                                ($document['related_entity_type'] === 'vehicle' ? $relatedEntity['brand'] . ' ' . $relatedEntity['model'] . ' (' . $relatedEntity['registration_number'] . ')' :
                                $relatedEntity['name'] . ' (' . $relatedEntity['serial_number'] . ')')
                            ) : 'Brak',
                        ];

                        foreach ($additionalDetails as $label => $value):
                        ?>
                            <div class="form-group">
                                <label class="form-label"><?php echo htmlspecialchars($label); ?>:</label>
                                <div class="form-control-plaintext"><?php echo htmlspecialchars($value); ?></div>
                            </div>
                        <?php endforeach; ?>
                    </div>
                </div>

                <div class="form-section mb-4">
                    <h3 class="section-title mb-3">Opis</h3>
                    <div class="form-fields">
                        <div class="form-group">
                            <div class="form-control-plaintext"><?php echo nl2br(htmlspecialchars($document['description'])); ?></div>
                        </div>
                    </div>
                </div>

                <div class="form-footer">
                    <a href="/document/download/<?php echo $document['id']; ?>" class="btn btn-primary" title="Pobierz dokument">
                        Pobierz
                    </a>
                    <a href="/document/edit/<?php echo $document['id']; ?>" class="btn btn-secondary" title="Edytuj">
                        Edytuj
                    </a>
                    <form action="/document/delete/<?php echo $document['id']; ?>" method="post" style="display: inline;">
                        <button type="submit" class="btn btn-danger" onclick="return confirm('Czy na pewno chcesz usunąć ten dokument?')">
                            Usuń
                        </button>
                    </form>
                </div>
            </div>
        </div>
    </div>
</div>

<?php include 'footer.php'; ?>