<?php include 'header.php'; ?>

<div class="section-header mb-3 d-flex justify-content-between align-items-center">
    <h2>Szczegóły pracownika</h2>
</div>

<div class="container">
    <?php if (isset($_GET['success']) && $_GET['success'] == 'document_generated'): ?>
        <div class="alert alert-success">Dokument został pomyślnie wygenerowany.</div>
    <?php endif; ?>

    <div class="card shadow mb-4">
        <div class="card-body">
            <div class="employee-details">
                <div class="inner-card">
                    <div class="card-body">
                        <h3 class="card-title">Dane osobowe</h3>
                        <?php
                        $personalDetails = [
                            'Imię' => $employee['first_name'],
                            'Nazwisko' => $employee['last_name'],
                            'PESEL' => $employee['pesel'],
                            'Data urodzenia' => $employee['date_of_birth'],
                            'Płeć' => [
                                'male' => 'Mężczyzna',
                                'female' => 'Kobieta'
                            ][$employee['gender']] ?? $employee['gender'],
                            'Numer dowodu osobistego' => $employee['id_card_number'] ?? 'Nie podano',
                            'Numer prawa jazdy' => $employee['driving_license_number'] ?? 'Nie podano',
                        ];

                        foreach ($personalDetails as $label => $value): ?>
                            <div class="mb-2">
                                <strong><?php echo htmlspecialchars($label); ?>:</strong>
                                <p class="mb-0"><?php echo htmlspecialchars($value); ?></p>
                            </div>
                        <?php endforeach; ?>
                    </div>
                </div>
                <div class="inner-card">
                    <div class="card-body">
                        <h3 class="card-title">Dane teleadresowe</h3>
                        <?php
                        $contactDetails = [
                            'Adres' => $employee['address'],
                            'Miasto' => $employee['city'],
                            'Kod pocztowy' => $employee['postal_code'],
                            'Kraj' => $employee['country'],
                            'Numer telefonu' => $employee['phone_number'] ?? 'Nie podano',
                            'Email' => $employee['email'] ?? 'Nie podano',
                        ];

                        foreach ($contactDetails as $label => $value):
                            if ($value): ?>
                                <div class="mb-2">
                                    <strong><?php echo htmlspecialchars($label); ?>:</strong>
                                    <p class="mb-0"><?php echo htmlspecialchars($value); ?></p>
                                </div>
                            <?php endif;
                        endforeach; ?>
                    </div>
                </div>
                <div class="inner-card">
                    <div class="card-body">
                        <h3 class="card-title">Dane zawodowe</h3>
                        <?php
                        $professionalDetails = [
                            'Stanowisko' => $employee['position'],
                            'Firma' => $employee['company_name'] ?? 'Brak przypisanej firmy',
                            'NIP' => $employee['nip'] ?? 'Nie podano',
                        ];

                        foreach ($professionalDetails as $label => $value): ?>
                            <div class="mb-2">
                                <strong><?php echo htmlspecialchars($label); ?>:</strong>
                                <p class="mb-0"><?php echo htmlspecialchars($value); ?></p>
                            </div>
                        <?php endforeach; ?>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <div class="card shadow mb-3">
        <div class="card-body">
            <h3 class="card-title">Okresy zatrudnienia</h3>
            <a href="#" class="btn btn-primary mb-3" onclick="showAddEmploymentPeriodForm()">Dodaj okres zatrudnienia</a>
            <div class="table-responsive">
                <table class="table">
                    <thead>
                        <tr>
                            <th>Data rozpoczęcia</th>
                            <th>Data zakończenia</th>
                            <th>Akcje</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($employmentPeriods as $period): ?>
                            <tr>
                                <td><?php echo htmlspecialchars($period['start_date']); ?></td>
                                <td><?php echo $period['end_date'] ? htmlspecialchars($period['end_date']) : 'Na stałe'; ?></td>
                                <td>
                                    <div class="btn-group" role="group">
                                        <a href="#" class="btn btn-outline-secondary btn-sm" title="Edytuj"
                                           onclick="showEditEmploymentPeriodForm(<?php echo $period['id']; ?>, '<?php echo $period['start_date']; ?>', '<?php echo $period['end_date']; ?>')">
                                            <i class="fas fa-edit"></i>
                                        </a>
                                        <?php if (!$period['end_date']): ?>
                                            <a href="#" class="btn btn-outline-warning btn-sm" title="Zakończ"
                                               onclick="showEndEmploymentPeriodForm(<?php echo $period['id']; ?>)">
                                                <i class="fas fa-stop"></i>
                                            </a>
                                        <?php endif; ?>
                                        <a href="#" class="btn btn-outline-danger btn-sm" title="Usuń"
                                           onclick="confirmDeleteEmploymentPeriod(<?php echo $period['id']; ?>)">
                                            <i class="fas fa-trash-alt"></i>
                                        </a>
                                    </div>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>

    <div class="card shadow mb-3">
        <div class="card-body">
            <h3 class="card-title">Dokumenty pracownika</h3>
            <a href="/document/add?entity_type=employee&entity_id=<?php echo $employee['id']; ?>" class="btn btn-primary mb-3">Dodaj dokument</a>
            <a href="/document/generate/<?php echo $employee['id']; ?>" class="btn btn-primary mb-3">Generuj dokument</a>
            <div class="table-responsive">
                <table class="table">
                    <thead>
                        <tr>
                            <th>Nazwa dokumentu</th>
                            <th>Kategoria</th>
                            <th>Data dodania</th>
                            <th>Akcje</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($employeeDocuments)): ?>
                            <tr>
                                <td colspan="4">Brak dokumentów dla tego pracownika.</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($employeeDocuments as $document): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($document['title']); ?></td>
                                    <td><?php echo htmlspecialchars($document['category_name']); ?></td>
                                    <td><?php echo date('Y-m-d', strtotime($document['created_at'])); ?></td>
                                    <td>
                                        <div class="btn-group" role="group">
                                            <a href="/document/download/<?php echo $document['id']; ?>" class="btn btn-outline-primary btn-sm" title="Pobierz">
                                                <i class="fas fa-download"></i>
                                            </a>
                                            <a href="/document/view/<?php echo $document['id']; ?>" class="btn btn-outline-info btn-sm" title="Szczegóły">
                                                <i class="fas fa-eye"></i>
                                            </a>
                                            <a href="/document/edit/<?php echo $document['id']; ?>" class="btn btn-outline-secondary btn-sm" title="Edytuj">
                                                <i class="fas fa-edit"></i>
                                            </a>
                                            <a href="#" class="btn btn-outline-danger btn-sm" title="Usuń"
                                               onclick="confirmDeleteDocument(<?php echo $document['id']; ?>)">
                                                <i class="fas fa-trash-alt"></i>
                                            </a>
                                        </div>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</div>

<script>
// Dodajemy funkcję, która sprawdza, czy element istnieje przed próbą dostępu do niego
function safeGetElement(id) {
    return document.getElementById(id);
}

function confirmDeleteEmploymentPeriod(periodId) {
    if (confirm('Czy na pewno chcesz usunąć ten okres zatrudnienia?')) {
        window.location.href = '/employee/delete_employment_period/' + periodId;
    }
}

function showAddEmploymentPeriodForm() {
    var modal = safeGetElement('addEmploymentPeriodModal');
    if (modal) modal.style.display = 'block';
}

function showEditEmploymentPeriodForm(periodId, startDate, endDate) {
    var editPeriodId = safeGetElement('edit-period-id');
    var editStartDate = safeGetElement('edit-start-date');
    var editEndDate = safeGetElement('edit-end-date');
    var removeEndDateCheckbox = safeGetElement('remove-end-date');
    var modal = safeGetElement('editEmploymentPeriodModal');

    if (editPeriodId) editPeriodId.value = periodId;
    if (editStartDate) editStartDate.value = startDate;

    if (editEndDate && removeEndDateCheckbox) {
        if (endDate) {
            editEndDate.value = endDate;
            editEndDate.disabled = false;
            removeEndDateCheckbox.checked = false;
        } else {
            editEndDate.value = '';
            editEndDate.disabled = true;
            removeEndDateCheckbox.checked = true;
        }
    }

    if (modal) modal.style.display = 'block';
}

function showEndEmploymentPeriodForm(periodId) {
    var endPeriodId = safeGetElement('end-period-id');
    var modal = safeGetElement('endEmploymentPeriodModal');

    if (endPeriodId) endPeriodId.value = periodId;
    if (modal) modal.style.display = 'block';
}

function closeModal(modalId) {
    var modal = safeGetElement(modalId);
    if (modal) modal.style.display = 'none';
}

window.onclick = function (event) {
    if (event.target.className === 'modal') {
        event.target.style.display = 'none';
    }
}

// Przenosimy ten kod do funkcji, która zostanie wywołana po załadowaniu DOM
function initializeEventListeners() {
    var removeEndDateCheckbox = safeGetElement('remove-end-date');
    if (removeEndDateCheckbox) {
        removeEndDateCheckbox.addEventListener('change', function () {
            var endDateInput = safeGetElement('edit-end-date');
            if (endDateInput) {
                if (this.checked) {
                    endDateInput.value = '';
                    endDateInput.disabled = true;
                } else {
                    endDateInput.disabled = false;
                }
            }
        });
    }
}

// Wywołujemy funkcję inicjalizującą po załadowaniu DOM
document.addEventListener('DOMContentLoaded', initializeEventListeners);

function confirmDeleteDocument(documentId) {
    if (confirm('Czy na pewno chcesz usunąć ten dokument?')) {
        var form = document.createElement('form');
        form.method = 'POST';
        form.action = '/document/delete/' + documentId;
        document.body.appendChild(form);
        form.submit();
    }
}
</script>

<!-- Modal do dodawania okresu zatrudnienia -->
<div id="addEmploymentPeriodModal" class="modal fade-in">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h3 class="modal-title">Dodaj nowy okres zatrudnienia</h3>
                <button type="button" class="close" onclick="closeModal('addEmploymentPeriodModal')">&times;</button>
            </div>
            <div class="modal-body">
                <form action="/employee/add_employment_period" method="post">
                    <input type="hidden" name="employee_id" value="<?php echo $employee['id']; ?>">
                    <div class="form-group">
                        <label for="add-start-date" class="form-label">Data rozpoczęcia:</label>
                        <input type="date" id="add-start-date" name="start_date" class="form-control" required>
                    </div>
                    <div class="form-group">
                        <label for="add-end-date" class="form-label">Data zakończenia:</label>
                        <input type="date" id="add-end-date" name="end_date" class="form-control">
                    </div>
                    <div class="modal-footer">
                        <button type="submit" class="btn btn-primary">Dodaj okres</button>
                        <button type="button" onclick="closeModal('addEmploymentPeriodModal')" class="btn btn-secondary">Anuluj</button>
                    </div>
                </form>
            </div>
        </div>
    </div>
</div>

<!-- Modal do edycji okresu zatrudnienia -->
<div id="editEmploymentPeriodModal" class="modal fade-in">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h3 class="modal-title">Edytuj okres zatrudnienia</h3>
                <button type="button" class="close" onclick="closeModal('editEmploymentPeriodModal')">&times;</button>
            </div>
            <div class="modal-body">
                <form action="/employee/edit_employment_period" method="post">
                    <input type="hidden" id="edit-period-id" name="period_id">
                    <input type="hidden" name="employee_id" value="<?php echo $employee['id']; ?>">
                    <div class="form-group">
                        <label for="edit-start-date" class="form-label">Data rozpoczęcia:</label>
                        <input type="date" id="edit-start-date" name="start_date" class="form-control" required>
                    </div>
                    <div class="form-group">
                        <label for="edit-end-date" class="form-label">Data zakończenia:</label>
                        <input type="date" id="edit-end-date" name="end_date" class="form-control">
                        <label>
                            <input type="checkbox" id="remove-end-date" name="remove_end_date"> Usuń datę zakończenia
                        </label>
                    </div>
                    <div class="modal-footer">
                        <button type="submit" class="btn btn-primary">Zapisz zmiany</button>
                        <button type="button" onclick="closeModal('editEmploymentPeriodModal')" class="btn btn-secondary">Anuluj</button>
                    </div>
                </form>
            </div>
        </div>
    </div>
</div>

<!-- Modal do zakończenia okresu zatrudnienia -->
<div id="endEmploymentPeriodModal" class="modal fade-in">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h3 class="modal-title">Zakończ okres zatrudnienia</h3>
                <button type="button" class="close" onclick="closeModal('endEmploymentPeriodModal')">&times;</button>
            </div>
            <div class="modal-body">
                <form action="/employee/end_employment_period" method="post">
                    <input type="hidden" id="end-period-id" name="period_id">
                    <input type="hidden" name="employee_id" value="<?php echo $employee['id']; ?>">
                    <div class="form-group">
                        <label for="end-date" class="form-label">Data zakończenia:</label>
                        <input type="date" id="end-date" name="end_date" class="form-control" required>
                    </div>
                    <div class="modal-footer">
                        <button type="submit" class="btn btn-primary">Zakończ okres</button>
                        <button type="button" onclick="closeModal('endEmploymentPeriodModal')" class="btn btn-secondary">Anuluj</button>
                    </div>
                </form>
            </div>
        </div>
    </div>
</div>

<?php include 'footer.php'; ?>