<?php include 'header.php'; ?>

<div class="section-header mb-3 d-flex justify-content-between align-items-center">
    <h2>Lista pracowników</h2>
    <a href="/add_employee" class="btn btn-primary btn-add-employee">
        <i class="fas fa-plus"></i> Dodaj pracownika
    </a>
</div>

<!-- Belka z filtrami -->
<div class="filter-bar mb-3">
    <div class="filter-tabs">
        <button class="btn btn-outline-primary <?php echo $currentFilter === 'all' ? 'active' : ''; ?>" data-filter="all">Wszyscy</button>
        <button class="btn btn-outline-primary <?php echo $currentFilter === 'active' ? 'active' : ''; ?>" data-filter="active">Aktywni</button>
        <button class="btn btn-outline-primary <?php echo $currentFilter === 'inactive' ? 'active' : ''; ?>" data-filter="inactive">Nieaktywni</button>
    </div>
</div>

<div class="card shadow">
    <div class="card-body">
        <div class="filter-bar mb-3">
            <div class="search-group">
                <div class="search-input-wrapper">
                    <input type="text" id="search-input" class="form-control" placeholder="Szukaj..." value="<?php echo htmlspecialchars($currentSearch); ?>">
                    <i class="fas fa-search search-icon"></i>
                    <i class="fas fa-times clear-search-icon" id="clear-search-icon" style="display: none;"></i>
                </div>
            </div>
            <div class="company-filter">
                <select id="company-select" class="form-control">
                    <option value="">Wszystkie firmy</option>
                    <?php foreach ($companies as $company): ?>
                        <option value="<?php echo $company['id']; ?>" <?php echo $currentCompanyId == $company['id'] ? 'selected' : ''; ?>>
                            <?php echo htmlspecialchars($company['name']); ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>
        </div>

        <div class="table-responsive">
            <table class="table">
                <thead>
                    <tr>
                        <th>Lp.</th>
                        <th>Nazwisko</th>
                        <th>Imię</th>
                        <th>Telefon</th>
                        <th>Stanowisko</th>
                        <th>Status</th>
                        <th>Firma</th>
                        <th>Akcje</th>
                    </tr>
                </thead>
                <tbody id="employee-list">
                    <?php foreach ($employees as $index => $employee): ?>
                        <tr>
                            <td><?php echo $index + 1; ?></td>
                            <td><?php echo htmlspecialchars($employee['last_name']); ?></td>
                            <td><?php echo htmlspecialchars($employee['first_name']); ?></td>
                            <td><?php echo htmlspecialchars($employee['phone_number']); ?></td>
                            <td><?php echo htmlspecialchars($employee['position']); ?></td>
                            <td><?php echo htmlspecialchars($employee['status']); ?></td>
                            <td><?php echo htmlspecialchars($employee['company_name']); ?></td>
                            <td>
                                <div class="btn-group" role="group" aria-label="Akcje pracownika">
                                    <a href="/employee/details/<?php echo $employee['id']; ?>" class="btn btn-outline-primary btn-sm" title="Szczegóły">
                                        <i class="fas fa-info-circle"></i>
                                    </a>
                                    <a href="/employee/edit/<?php echo $employee['id']; ?>" class="btn btn-outline-secondary btn-sm" title="Edytuj">
                                        <i class="fas fa-edit"></i>
                                    </a>
                                    <button type="button" class="btn btn-outline-danger btn-sm" title="Usuń" onclick="confirmDelete(<?php echo $employee['id']; ?>)">
                                        <i class="fas fa-trash-alt"></i>
                                    </button>
                                </div>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>
</div>

<style>
.search-input-wrapper {
    position: relative;
}
.search-icon, .clear-search-icon {
    position: absolute;
    top: 50%;
    transform: translateY(-50%);
    right: 10px;
    cursor: pointer;
}
.clear-search-icon {
    right: 30px;
}
</style>

<script>
document.addEventListener('DOMContentLoaded', function() {
    const searchInput = document.getElementById('search-input');
    const employeeList = document.getElementById('employee-list');
    const companySelect = document.getElementById('company-select');
    const filterButtons = document.querySelectorAll('.filter-tabs button');
    const clearSearchIcon = document.getElementById('clear-search-icon');

    let debounceTimer;

    function toggleClearIcon() {
        clearSearchIcon.style.display = searchInput.value ? 'block' : 'none';
    }

    clearSearchIcon.addEventListener('click', function() {
        searchInput.value = '';
        toggleClearIcon();
        filterEmployees();
    });

    searchInput.addEventListener('input', function() {
        toggleClearIcon();
        clearTimeout(debounceTimer);
        debounceTimer = setTimeout(() => {
            filterEmployees();
        }, 300);
    });

    companySelect.addEventListener('change', filterEmployees);

    filterButtons.forEach(button => {
        button.addEventListener('click', function() {
            filterButtons.forEach(btn => btn.classList.remove('active'));
            this.classList.add('active');
            filterEmployees();
        });
    });

    function filterEmployees() {
        const searchTerm = searchInput.value.trim();
        const selectedCompany = companySelect.value;
        const activeFilter = document.querySelector('.filter-tabs button.active').dataset.filter;

        let url = `/employee_list?filter=${activeFilter}&company_id=${selectedCompany}`;
        if (searchTerm) {
            url += `&search=${encodeURIComponent(searchTerm)}`;
        }

        fetch(url)
            .then(response => response.text())
            .then(html => {
                const parser = new DOMParser();
                const doc = parser.parseFromString(html, 'text/html');
                const newEmployeeList = doc.getElementById('employee-list');
                if (newEmployeeList) {
                    employeeList.innerHTML = newEmployeeList.innerHTML;
                } else {
                    employeeList.innerHTML = '<tr><td colspan="7">Brak wyników</td></tr>';
                }
            })
            .catch(error => {
                console.error('Error:', error);
                employeeList.innerHTML = '<tr><td colspan="7">Wystąpił błąd podczas wczytywania danych</td></tr>';
            });
    }

    searchInput.addEventListener('keypress', function(e) {
        if (e.key === 'Enter') {
            e.preventDefault();
            filterEmployees();
        }
    });

    toggleClearIcon();
    filterEmployees();
});

function confirmDelete(employeeId) {
    if (confirm('Czy na pewno chcesz usunąć tego pracownika?')) {
        fetch(`/employee/delete/${employeeId}`, {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
            },
        })
        .then(response => response.json())
        .then(data => {
            if (data.success) {
                // Odśwież listę pracowników
                window.location.reload();
            } else {
                alert('Wystąpił błąd podczas usuwania pracownika: ' + (data.message || 'Nieznany błąd'));
            }
        })
        .catch(error => {
            console.error('Error:', error);
            alert('Wystąpił błąd podczas usuwania pracownika');
        });
    }
}
</script>

<?php include 'footer.php'; ?>
