<?php include 'header.php'; ?>

<div class="container mt-4">
    <div class="card shadow mb-4">
        <div class="card-header bg-primary text-white">
            <h2 class="mb-0">Zadania</h2>
        </div>
        <div class="card-body">
            <!-- Sekcja zadań z przyciskami w jednym wierszu -->
            <div class="form-section mb-4">
                <div class="d-flex justify-content-between align-items-center mb-3">
                    <h3 class="section-title mb-0">Ostatnie zadania</h3>
                    <div class="btn-group">
                        <a href="/tasks" class="btn btn-success btn-sm">
                            <i class="fas fa-list"></i> Lista zadań
                        </a>
                        <a href="/task/add" class="btn btn-success btn-sm">
                            <i class="fas fa-plus"></i> Dodaj zadanie
                        </a>
                    </div>
                </div>
                <div class="form-fields">
                    <?php if (empty($recentTasks)): ?>
                        <p class="card-text">Brak aktualnych zadań.</p>
                    <?php else: ?>
                        <ul class="list-group list-group-flush">
                            <?php foreach ($recentTasks as $task): 
                                $priorityClass = [
                                    'low' => 'border-success',
                                    'medium' => 'border-warning',
                                    'high' => 'border-danger'
                                ][$task['priority']];
                                
                                $daysUntilDue = (strtotime($task['due_date']) - time()) / (60 * 60 * 24);
                                $dueDateClass = $daysUntilDue < 0 ? 'text-danger' : 
                                              ($daysUntilDue <= 7 ? 'text-warning' : 'text-success');
                            ?>
                                <li class="list-group-item task-item border-start border-4 <?php echo $priorityClass; ?>">
                                    <div class="task-main-row">
                                        <div class="d-flex align-items-center gap-2">
                                            <span class="priority-icon">
                                                <i class="fas fa-circle fs-5 <?php echo str_replace('border-', 'text-', $priorityClass); ?>"></i>
                                            </span>
                                            <a href="/task/<?php echo $task['id']; ?>" class="task-title h4 mb-0 text-decoration-none">
                                                <?php echo htmlspecialchars($task['title']); ?>
                                            </a>
                                        </div>
                                    </div>
                                    <div class="task-details mt-2">
                                        <div class="d-flex flex-wrap gap-4">
                                            <span class="badge bg-secondary">
                                                <i class="fas fa-tasks me-1"></i>
                                                <?php echo Task::getStatuses()[$task['status']]; ?>
                                            </span>
                                            <span class="<?php echo $dueDateClass; ?>">
                                                <i class="fas fa-calendar me-1"></i>
                                                <?php 
                                                $dueDate = strtotime($task['due_date']);
                                                if ($dueDate && $dueDate !== strtotime('1970-01-01')) {
                                                    if ($daysUntilDue == 0) {
                                                        echo 'Dzisiaj';
                                                    } elseif ($daysUntilDue == 1) {
                                                        echo 'Jutro';
                                                    } elseif ($daysUntilDue > 1 && $daysUntilDue < 7) {
                                                        echo 'Za ' . round($daysUntilDue) . ' dni';
                                                    } else {
                                                        echo date('d.m.Y', $dueDate);
                                                    }
                                                } else {
                                                    echo 'Bez terminu';
                                                }
                                                ?>
                                            </span>
                                            <?php if ($task['assigned_to']): ?>
                                                <span class="text-muted">
                                                    <i class="fas fa-user me-1"></i>
                                                    <?php echo htmlspecialchars($task['first_name'] . ' ' . $task['last_name']); ?>
                                                </span>
                                            <?php endif; ?>
                                        </div>
                                    </div>
                                </li>
                            <?php endforeach; ?>
                        </ul>
                    <?php endif; ?>
                </div>
            </div>

            <div class="form-section mb-4">
                <h3 class="section-title mb-3">Nadchodzące przeglądy pojazdów</h3>
                <div class="form-fields">
                    <?php if (empty($upcomingInspections)): ?>
                        <p class="card-text">Brak nadchodzących przeglądów.</p>
                    <?php else: ?>
                        <ul class="list-group list-group-flush">
                            <?php foreach ($upcomingInspections as $inspection):
                                $expirationDate = strtotime($inspection['expiration_date']);
                                $daysUntilExpiration = ($expirationDate - time()) / (60 * 60 * 24);
                                $badgeText = $inspection['inspection_type'] == 'techniczny' ? 'Techniczny' : 'Serwisowy';
                                
                                if ($daysUntilExpiration < 0) {
                                    $textColorClass = 'text-danger';
                                } elseif ($daysUntilExpiration <= 7) {
                                    $textColorClass = 'text-danger';
                                } elseif ($daysUntilExpiration <= 30) {
                                    $textColorClass = 'text-warning';
                                } else {
                                    $textColorClass = 'text-success';
                                }
                                ?>
                                <li class="list-group-item d-flex justify-content-between align-items-center">
                                    <span class="<?php echo $textColorClass; ?> fw-bold me-2"><?php echo $badgeText; ?></span>
                                    <span><?php echo htmlspecialchars($inspection['brand'] . ' ' . $inspection['model'] . ' (' . $inspection['registration_number'] . ')'); ?></span>
                                    <span><?php echo date('d.m.Y', $expirationDate); ?></span>
                                </li>
                            <?php endforeach; ?>
                        </ul>
                    <?php endif; ?>
                </div>
            </div>
            
            <div class="form-section mb-4">
                <h3 class="section-title mb-3">Pracownicy z kończącymi się umowami (30 dni)</h3>
                <div class="form-fields">
                    <?php if (empty($employeesWithEndingContracts)): ?>
                        <p class="card-text">Brak pracowników z kończącymi się umowami w ciągu najbliższych 30 dni.</p>
                    <?php else: ?>
                        <ul class="list-group list-group-flush">
                            <?php foreach ($employeesWithEndingContracts as $employee):
                                $daysUntilEnd = (strtotime($employee['end_date']) - time()) / (60 * 60 * 24);
                                $urgentClass = $daysUntilEnd <= 7 ? 'text-danger' : '';
                                ?>
                                <li class="list-group-item <?php echo $urgentClass; ?>">
                                    <?php echo htmlspecialchars($employee['first_name'] . ' ' . $employee['last_name']); ?> - Kończy umowę: <?php echo date('d.m.Y', strtotime($employee['end_date'])); ?>
                                </li>
                            <?php endforeach; ?>
                        </ul>
                    <?php endif; ?>
                </div>
            </div>
            
            <div class="form-section mb-4">
                <h3 class="section-title mb-3">Nadchodzące polisy pojazdów</h3>
                <div class="form-fields">
                    <?php if (empty($upcomingVehiclePolicies)): ?>
                        <p class="card-text">Brak nadchodzących polis pojazdów.</p>
                    <?php else: ?>
                        <ul class="list-group list-group-flush">
                            <?php foreach ($upcomingVehiclePolicies as $policy):
                                $endDate = strtotime($policy['policy_end_date']);
                                $daysUntilEnd = ($endDate - time()) / (60 * 60 * 24);
                                
                                if ($daysUntilEnd < 0) {
                                    $textColorClass = 'text-danger';
                                } elseif ($daysUntilEnd <= 7) {
                                    $textColorClass = 'text-danger';
                                } elseif ($daysUntilEnd <= 30) {
                                    $textColorClass = 'text-warning';
                                } else {
                                    $textColorClass = 'text-success';
                                }
                                ?>
                                <li class="list-group-item d-flex justify-content-between align-items-center">
                                    <span class="<?php echo $textColorClass; ?> fw-bold me-2">
                                        <?php echo htmlspecialchars($policy['category_name']); ?>
                                    </span>
                                    <span><?php echo htmlspecialchars($policy['brand'] . ' ' . $policy['model'] . ' (' . $policy['registration_number'] . ')'); ?></span>
                                    <span><?php echo date('d.m.Y', strtotime($policy['policy_end_date'])); ?></span>
                                </li>
                            <?php endforeach; ?>
                        </ul>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    </div>
</div>

<?php include 'footer.php'; ?>
