<?php include 'header.php'; ?>

<?php if (isset($_GET['success'])): ?>
    <div class="alert alert-success alert-dismissible fade show" role="alert">
        <?php 
        // Zamiana match na switch dla kompatybilności z PHP 7+
        $message = '';
        switch($_GET['success']) {
            case '1':
                $message = 'Zadanie zostało pomyślnie dodane';
                break;
            case '2':
                $message = 'Zadanie zostało zaktualizowane';
                break;
            case '3':
                $message = 'Zadanie zostało usunięte';
                break;
            case '4':
                $message = 'Zadanie zostało oznaczone jako zakończone';
                break;
            default:
                $message = 'Operacja zakończona sukcesem';
        }
        echo $message;
        ?>
        <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
    </div>
<?php endif; ?>

<div class="section-header mb-3 d-flex justify-content-between align-items-center">
    <h2>Lista zadań</h2>
    <a href="/task/add" class="btn btn-success">
        <i class="fas fa-plus"></i> Dodaj zadanie
    </a>
</div>

<div class="card shadow">
    <div class="card-body">
        <div class="filter-bar mb-3">
            <div class="search-group">
                <div class="search-input-wrapper">
                    <input type="text" id="search-input" class="form-control" placeholder="Szukaj zadania..." value="<?php echo htmlspecialchars($currentSearch ?? ''); ?>">
                    <i class="fas fa-search search-icon"></i>
                    <i class="fas fa-times clear-search-icon" id="clear-search-icon" style="display: none;"></i>
                </div>
            </div>
            <div class="status-filter">
                <select id="status-select" class="form-control">
                    <option value="not_done" <?php echo ($currentStatus ?? Task::DEFAULT_STATUS_FILTER) == 'not_done' ? 'selected' : ''; ?>>
                        Bez zakończonych
                    </option>
                    <option value="">Wszystkie statusy</option>
                    <?php foreach (Task::getStatuses() as $value => $label): ?>
                        <option value="<?php echo $value; ?>" <?php echo ($currentStatus ?? '') == $value ? 'selected' : ''; ?>>
                            <?php echo $label; ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>
            <div class="assignment-filter">
                <select id="assignment-select" class="form-control">
                    <option value="all" <?php echo ($currentAssignment ?? Task::DEFAULT_ASSIGNMENT_FILTER) == 'all' ? 'selected' : ''; ?>>
                        Wszystkie zadania
                    </option>
                    <option value="my" <?php echo ($currentAssignment ?? Task::DEFAULT_ASSIGNMENT_FILTER) == 'my' ? 'selected' : ''; ?>>
                        Tylko moje
                    </option>
                    <option value="my_and_general" <?php echo ($currentAssignment ?? Task::DEFAULT_ASSIGNMENT_FILTER) == 'my_and_general' ? 'selected' : ''; ?>>
                        Moje + ogólne
                    </option>
                </select>
            </div>
        </div>

        <div class="table-responsive">
            <table class="table">
                <thead>
                    <tr>
                        <th>Lp.</th>
                        <th>Tytuł</th>
                        <th>Priorytet</th>
                        <th>Termin</th>
                        <th>Status</th>
                        <th>Przypisane do</th>
                        <th>Akcje</th>
                    </tr>
                </thead>
                <tbody id="task-list">
                    <?php foreach ($tasks as $index => $task): 
                        $priorityClass = [
                            'low' => 'text-success',
                            'medium' => 'text-warning',
                            'high' => 'text-danger'
                        ][$task['priority']];
                        
                        $daysUntilDue = (strtotime($task['due_date']) - time()) / (60 * 60 * 24);
                        $dueDateClass = $daysUntilDue < 0 ? 'text-danger' : 
                                      ($daysUntilDue <= 7 ? 'text-warning' : 'text-success');
                    ?>
                        <tr>
                            <td data-label="Lp."><?php echo $index + 1; ?></td>
                            <td data-label="Tytuł"><?php echo htmlspecialchars($task['title']); ?></td>
                            <td data-label="Priorytet">
                                <span class="<?php echo $priorityClass; ?>">
                                    <i class="fas fa-flag"></i>
                                    <?php echo Task::getPriorities()[$task['priority']]; ?>
                                </span>
                            </td>
                            <td data-label="Termin" class="<?php echo $dueDateClass; ?>">
                                <?php 
                                $dueDate = strtotime($task['due_date']);
                                echo ($dueDate && $dueDate !== strtotime('1970-01-01')) 
                                    ? date('d.m.Y', $dueDate) 
                                    : 'Bez terminu'; 
                                ?>
                            </td>
                            <td data-label="Status"><?php echo Task::getStatuses()[$task['status']]; ?></td>
                            <td data-label="Przypisane do">
                                <?php echo $task['assigned_to'] ? htmlspecialchars($task['user_name']) : '-'; ?>
                            </td>
                            <td data-label="Akcje">
                                <div class="btn-group" role="group" aria-label="Akcje zadania">
                                    <a href="/task/<?php echo $task['id']; ?>" class="btn btn-outline-primary btn-sm" title="Szczegóły">
                                        <i class="fas fa-info-circle"></i>
                                    </a>
                                    <a href="/task/edit/<?php echo $task['id']; ?>" class="btn btn-outline-secondary btn-sm" title="Edytuj">
                                        <i class="fas fa-edit"></i>
                                    </a>
                                    <button type="button" class="btn btn-outline-success btn-sm" title="Zakończ" onclick="confirmDelete(<?php echo $task['id']; ?>)">
                                        <i class="fas fa-check"></i>
                                    </button>
                                </div>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>
</div>

<script>
function confirmDelete(taskId) {
    if (confirm('Czy na pewno chcesz oznaczyć to zadanie jako zakończone?')) {
        var form = document.createElement('form');
        form.method = 'POST';
        form.action = '/task/delete/' + taskId;
        document.body.appendChild(form);
        form.submit();
    }
}
</script>

<script src="/js/tasks.js"></script>

<?php include 'footer.php'; ?>
