<?php include 'header.php'; ?>

<div class="section-header mb-3 d-flex justify-content-between align-items-center">
    <h2>Szczegóły pojazdu</h2>
    <div class="actions-group">
        <a href="/vehicle/edit/<?php echo $vehicle['id']; ?>" class="btn btn-outline-secondary btn-sm">
            <i class="fas fa-edit"></i> Edytuj
        </a>
        <a href="#" class="btn btn-outline-danger btn-sm" onclick="confirmDelete(<?php echo $vehicle['id']; ?>)">
            <i class="fas fa-trash-alt"></i> Usuń
        </a>
    </div>
</div>

<div class="container">
    <div class="card shadow mb-4">
        <div class="card-body">
            <div class="vehicle-details">
                <div class="inner-card">
                    <div class="card-body">
                        <h3 class="card-title">Dane pojazdu</h3>
                        <?php
                        $vehicleDetails = [
                            'Marka' => $vehicle['brand'],
                            'Model' => $vehicle['model'],
                            'Rok produkcji' => $vehicle['year'],
                            'Nr rejestracyjny' => $vehicle['registration_number'],
                            'VIN' => $vehicle['vin'],
                            'Data zakupu' => $vehicle['purchase_date'],
                            'Firma' => $vehicle['company_name'],
                        ];

                        foreach ($vehicleDetails as $label => $value): ?>
                            <div class="mb-2">
                                <strong><?php echo htmlspecialchars($label); ?>:</strong>
                                <p class="mb-0"><?php echo htmlspecialchars($value); ?></p>
                            </div>
                        <?php endforeach; ?>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <div class="card shadow mb-3">
        <div class="card-body">
            <h3 class="card-title">Przeglądy</h3>
            <a href="<?php echo $vehicle['id']; ?>/inspection/add/" class="btn btn-primary mb-3">
                <i class="fas fa-plus"></i> Dodaj przegląd
            </a>
            <div class="table-responsive">
                <table class="table">
                    <thead>
                        <tr>
                            <th>Data</th>
                            <th>Typ</th>
                            <th>Upływa</th>
                            <th>Przebieg</th>
                            <th>Akcje</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($inspections as $inspection): ?>
                            <tr data-type="<?php echo htmlspecialchars($inspection['inspection_type']); ?>">
                                <td><?php echo htmlspecialchars($inspection['inspection_date']); ?></td>
                                <td><?php echo htmlspecialchars($inspection['inspection_type']); ?></td>
                                <td><?php echo htmlspecialchars($inspection['expiration_date']); ?></td>
                                <td><?php echo htmlspecialchars($inspection['mileage']); ?> km</td>
                                <td>
                                    <div class="btn-group" role="group">
                                        <a href="/inspection/edit/<?php echo $inspection['id']; ?>" class="btn btn-outline-secondary btn-sm" title="Edytuj">
                                            <i class="fas fa-edit"></i>
                                        </a>
                                        <a href="/inspection/details/<?php echo $inspection['id']; ?>" class="btn btn-outline-info btn-sm" title="Szczegóły">
                                            <i class="fas fa-eye"></i>
                                        </a>
                                        <a href="#" class="btn btn-outline-danger btn-sm" title="Usuń" onclick="confirmDeleteInspection(<?php echo $inspection['id']; ?>); return false;">
                                            <i class="fas fa-trash-alt"></i>
                                        </a>
                                    </div>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>

    <div class="card shadow mb-3">
        <div class="card-body">
            <h3 class="card-title">Historia przebiegów</h3>
            <a href="/vehicle/update-mileage/<?php echo $vehicle['id']; ?>" class="btn btn-primary mb-3">
                <i class="fas fa-plus"></i> Dodaj przebieg
            </a>
            <div class="table-responsive">
                <table class="table" id="mileages-table">
                    <thead>
                        <tr>
                            <th>Data</th>
                            <th>Przebieg</th>
                            <th>Różnica</th>
                            <th>Akcje</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($mileages as $index => $mileage): ?>
                            <tr>
                                <td><?php echo htmlspecialchars($mileage['mileage_date']); ?></td>
                                <td><?php echo number_format($mileage['mileage'], 0, ',', ' '); ?> km</td>
                                <td>
                                    <?php
                                    if ($index < count($mileages) - 1) {
                                        $difference = $mileage['mileage'] - $mileages[$index + 1]['mileage'];
                                        echo number_format($difference, 0, ',', ' ') . ' km';
                                    } else {
                                        echo '-';
                                    }
                                    ?>
                                </td>
                                <td>
                                    <div class="btn-group" role="group">
                                        <a href="/vehicle/edit-mileage/<?php echo $mileage['id']; ?>" class="btn btn-outline-secondary btn-sm" title="Edytuj">
                                            <i class="fas fa-edit"></i>
                                        </a>
                                        <a href="#" class="btn btn-outline-danger btn-sm" title="Usuń" onclick="confirmDeleteMileage(<?php echo $mileage['id']; ?>); return false;">
                                            <i class="fas fa-trash-alt"></i>
                                        </a>
                                    </div>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>

    <div class="card shadow mb-3">
        <div class="card-body">
            <h3 class="card-title">Dokumenty pojazdu</h3>
            <a href="/document/add?entity_type=vehicle&entity_id=<?php echo $vehicle['id']; ?>" class="btn btn-primary mb-3">
                <i class="fas fa-plus"></i> Dodaj dokument
            </a>
            <div class="table-responsive">
                <table class="table">
                    <thead>
                        <tr>
                            <th>Nazwa dokumentu</th>
                            <th>Kategoria</th>
                            <th>Data dodania</th>
                            <th>Akcje</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($vehicleDocuments)): ?>
                            <tr>
                                <td colspan="4">Brak dokumentów dla tego pojazdu.</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($vehicleDocuments as $document): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($document['title']); ?></td>
                                    <td><?php echo htmlspecialchars($document['category_name']); ?></td>
                                    <td><?php echo date('Y-m-d', strtotime($document['created_at'])); ?></td>
                                    <td>
                                        <div class="btn-group" role="group">
                                            <a href="/document/download/<?php echo $document['id']; ?>" class="btn btn-outline-primary btn-sm" title="Pobierz">
                                                <i class="fas fa-download"></i>
                                            </a>
                                            <a href="/document/view/<?php echo $document['id']; ?>" class="btn btn-outline-info btn-sm" title="Szczegóły">
                                                <i class="fas fa-eye"></i>
                                            </a>
                                            <a href="/document/edit/<?php echo $document['id']; ?>" class="btn btn-outline-secondary btn-sm" title="Edytuj">
                                                <i class="fas fa-edit"></i>
                                            </a>
                                            <a href="#" class="btn btn-outline-danger btn-sm" title="Usuń" onclick="confirmDeleteDocument(<?php echo $document['id']; ?>); return false;">
                                                <i class="fas fa-trash-alt"></i>
                                            </a>
                                        </div>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</div>

<script>
function confirmDelete(vehicleId) {
    if (confirm('Czy na pewno chcesz usunąć ten pojazd?')) {
        var form = document.createElement('form');
        form.method = 'POST';
        form.action = '/vehicle/delete/' + vehicleId;
        document.body.appendChild(form);
        form.submit();
    }
}

function confirmDeleteInspection(inspectionId) {
    if (confirm('Czy na pewno chcesz usunąć ten przegląd?')) {
        var form = document.createElement('form');
        form.method = 'POST';
        form.action = '/inspection/delete/' + inspectionId;
        document.body.appendChild(form);
        form.submit();
    }
}

function confirmDeleteMileage(mileageId) {
    if (confirm('Czy na pewno chcesz usunąć ten przebieg?')) {
        var form = document.createElement('form');
        form.method = 'POST';
        form.action = '/vehicle/delete-mileage/' + mileageId;
        document.body.appendChild(form);
        form.submit();
    }
}

function confirmDeleteDocument(documentId) {
    if (confirm('Czy na pewno chcesz usunąć ten dokument?')) {
        var form = document.createElement('form');
        form.method = 'POST';
        form.action = '/document/delete/' + documentId;
        document.body.appendChild(form);
        form.submit();
    }
}
</script>

<?php include 'footer.php'; ?>