<?php
// Konfiguracja logowania dla środowiska deweloperskiego
ini_set('display_errors', 0); // Nie pokazuj błędów użytkownikom
ini_set('display_startup_errors', 0);
// Loguj wszystkie błędy oprócz powiadomień i przestarzałych funkcji
error_reporting(E_ALL & ~E_NOTICE & ~E_DEPRECATED);
ini_set('log_errors', 1);
ini_set('error_log', '/var/www/html/panel/error.log');

function custom_error_handler($errno, $errstr, $errfile, $errline) {
    error_log("Error [$errno] $errstr on line $errline in file $errfile");
}
set_error_handler("custom_error_handler");

// Funkcja do logowania debugowania
function debug_log($message, $data = null) {
    $log = "[" . date('Y-m-d H:i:s') . "] " . $message;
    if ($data !== null) {
        $log .= ": " . print_r($data, true);
    }
    error_log($log);
}

require '../vendor/autoload.php';
require_once '../app/helpers/string_helper.php';
session_start();

// Funkcja do automatycznego ładowania plików
function loadFiles($directory, $pattern) {
    $files = glob($directory . '/' . $pattern);
    foreach ($files as $file) {
        $className = pathinfo($file, PATHINFO_FILENAME);
        if (!class_exists($className, false)) {
            require_once $file;
         //   error_log("Załadowano plik: " . $file);
        } else {
          //  error_log("Pominięto już załadowany plik: " . $file);
        }
    }
}

// Ładowanie plików pomocniczych
loadFiles('../app/helpers', '*.php');

// Ładowanie wszystkich modeli
loadFiles('../app/models', '*.php');

// Ładowanie wszystkich plików routingu
loadFiles('../app/routes', '*_routes.php');

// Zmieniona obsługa błędów, aby obsługiwać zarówno Exception, jak i Error
Flight::map('error', function($e){
    error_log($e->getMessage());
    if ($e instanceof Error) {
        // Obsługa błędów PHP
        $message = 'Wystąpił błąd aplikacji. Prosimy spróbować później.';
        $code = 500;
    } else {
        // Obsługa wyjątków
        $message = $e->getMessage();
        $code = ($e instanceof Exception) ? $e->getCode() : 500;
    }
    
    // Upewniamy się, że kod statusu jest prawidłowy
    if (!is_int($code) || $code < 100 || $code > 599) {
        $code = 500;
    }

    Flight::json(['error' => $message], $code);
});

// Strona główna
Flight::route('/', function () {
    if (isLoggedIn()) {
        Flight::redirect('/home');
    } else {
        Flight::render('login');
    }
});

// Strona domowa po zalogowaniu
Flight::route('/home', function () {
    HomeController::index();
});

// Wylogowanie
Flight::route('/logout', function () {
    session_destroy();
    Flight::redirect('/');
});

// Obsługa błędów 404
Flight::map('notFound', function() {
    Flight::render('404');
});

// Konfiguracja Flight
Flight::set('flight.views.path', '../app/views');

// Uruchomienie aplikacji
Flight::start();
