document.addEventListener('DOMContentLoaded', function () {
    console.log('DOM loaded');
    const relationTypeSelect = document.getElementById('relation_type');
    const relatedIdContainer = document.getElementById('related_id_container');

    console.log('relation_type element:', relationTypeSelect);
    console.log('related_id_container element:', relatedIdContainer);

    if (relationTypeSelect) {
        relationTypeSelect.addEventListener('change', function (e) {
            console.log('Relation type changed to:', this.value);
        });
    }
});

function fetchRelatedEntities(type) {
    const relatedIdContainer = document.getElementById('related_id_container');
    const relatedId = document.getElementById('related_id');

    if (!relatedIdContainer || !relatedId) {
        console.error('Required elements not found');
        return;
    }

    if (type === 'none') {
        relatedIdContainer.style.display = 'none';
        return;
    }

    relatedIdContainer.style.display = 'block';
    relatedId.innerHTML = '<option value="">Ładowanie...</option>';

    fetch(`/get-related-entities/${type}`)
        .then(response => {
            if (!response.ok) {
                throw new Error('Network response was not ok');
            }
            return response.json();
        })
        .then(data => {
            relatedId.innerHTML = '<option value="">Wybierz obiekt</option>';
            data.forEach(item => {
                const option = document.createElement('option');
                option.value = item.id;
                option.textContent = item.name;
                relatedId.appendChild(option);
            });
        })
        .catch(error => {
            console.error('Error:', error);
            relatedId.innerHTML = '<option value="">Błąd podczas ładowania danych</option>';
        });
}

function savePreference(key, value) {
    localStorage.setItem(key, value);
    fetch('/user/save-preference', {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json',
        },
        body: JSON.stringify({ key, value }),
    });
}

function initializeCostAdd(preferences) {
    const isGeneralCheckbox = document.getElementById('is_general');
    const relationTypeSelect = document.getElementById('relation_type');
    const relatedIdContainer = document.getElementById('related_id_container');
    const companySelect = document.getElementById('company_id');
    const costTypeSelect = document.getElementById('cost_type_id');

    // Obsługa checkboxa "Koszt ogólny"
    if (isGeneralCheckbox) {
        isGeneralCheckbox.addEventListener('change', function () {
            if (this.checked) {
                // Jeśli zaznaczono "Koszt ogólny"
                relationTypeSelect.value = 'none';
                relationTypeSelect.disabled = true;
                relatedIdContainer.style.display = 'none';
            } else {
                // Jeśli odznaczono "Koszt ogólny"
                relationTypeSelect.disabled = false;
            }
        });
    }

    if (preferences.lastCompanyId) {
        companySelect.value = preferences.lastCompanyId;
    }
    if (preferences.lastCostTypeId) {
        costTypeSelect.value = preferences.lastCostTypeId;
    }
    if (preferences.lastRelationType) {
        relationTypeSelect.value = preferences.lastRelationType;
        fetchRelatedEntities(preferences.lastRelationType);
    }

    // Zapisywanie preferencji w Local Storage i wysyłanie na serwer
    companySelect.addEventListener('change', () => {
        savePreference('last_company_id', companySelect.value);
    });

    costTypeSelect.addEventListener('change', () => {
        savePreference('last_cost_type_id', costTypeSelect.value);
    });

    // Obsługa zmiany typu relacji
    relationTypeSelect.addEventListener('change', function () {
        const selectedType = this.value;
        savePreference('last_relation_type', selectedType);

        if (selectedType === 'none') {
            relatedIdContainer.style.display = 'none';
        } else {
            relatedIdContainer.style.display = 'block';
            fetchRelatedEntities(selectedType);
        }
    });
}
