console.log('document_generator.js loaded');

// Dodaj obsługę globalnych błędów
window.addEventListener('error', function (event) {
    console.error('Global error:', event.error);
});

document.addEventListener('DOMContentLoaded', function () {
    console.log('DOM fully loaded and parsed');

    const templateSelect = document.getElementById('template_id');
    const dynamicFormFields = document.getElementById('dynamicFormFields');
    const employeeId = document.querySelector('input[name="employee_id"]')?.value;

    console.log('Initial elements:', { templateSelect, dynamicFormFields, employeeId });

    if (templateSelect && dynamicFormFields && employeeId) {
        templateSelect.addEventListener('change', function () {
            const templateId = this.value;
            console.log('Template selected:', templateId);

            if (templateId) {
                console.log('Fetching template structure for ID:', templateId);
                fetch(`/api/template-structure/${templateId}`)
                    .then(response => {
                        console.log('Raw response:', response);
                        if (!response.ok) {
                            throw new Error(`HTTP error! status: ${response.status}`);
                        }
                        return response.json();
                    })
                    .then(data => {
                        console.log("Received template structure:", data);
                        dynamicFormFields.innerHTML = '';
                        if (Array.isArray(data) && data.length > 0) {
                            data.forEach(field => {
                                console.log('Processing field:', field);
                                const fieldHtml = createFieldHtml(field);
                                dynamicFormFields.innerHTML += fieldHtml;
                            });
                            console.log('Form fields generated. HTML:', dynamicFormFields.innerHTML);
                            prefillEmployeeData(employeeId);
                        } else {
                            console.error('Received data is not an array or is empty');
                            dynamicFormFields.innerHTML = '<p>Nie udało się załadować struktury formularza.</p>';
                        }
                    })
                    .catch(error => {
                        console.error('Error fetching template structure:', error);
                        dynamicFormFields.innerHTML = '<p>Wystąpił błąd podczas ładowania formularza.</p>';
                    });
            } else {
                console.log('No template selected, clearing form fields');
                dynamicFormFields.innerHTML = '';
            }
        });
    } else {
        console.error('Required elements not found');
    }

    // Funkcja do tworzenia HTML dla pól formularza
    function createFieldHtml(field) {
        console.log('Tworzenie HTML dla pola:', field);
        let html = `
            <div class="form-group">
                <label for="${field.name}" class="form-label">${field.label}:</label>
        `;

        switch (field.type) {
            case 'text':
            case 'date':
            case 'number':
            case 'email':
                html += `<input type="${field.type}" id="${field.name}" name="${field.name}" class="form-control" ${field.required ? 'required' : ''}>`;
                break;
            case 'textarea':
                html += `<textarea id="${field.name}" name="${field.name}" class="form-control" ${field.required ? 'required' : ''}></textarea>`;
                break;
            case 'select':
                html += `<select id="${field.name}" name="${field.name}" class="form-select" ${field.required ? 'required' : ''}>`;
                field.options.forEach(option => {
                    html += `<option value="${option.value}">${option.label}</option>`;
                });
                html += `</select>`;
                break;
            default:
                html += `<input type="text" id="${field.name}" name="${field.name}" class="form-control" ${field.required ? 'required' : ''}>`;
        }

        html += `</div>`;
        console.log('Wygenerowany HTML:', html);
        return html;
    }

    // Funkcja do wypełniania formularza danymi pracownika
    function prefillEmployeeData(employeeId) {
        console.log('Wypełnianie danych pracownika, ID:', employeeId);
        fetch(`/api/employee/${employeeId}`)
            .then(response => response.json())
            .then(data => {
                console.log('Otrzymane dane pracownika:', data);
                Object.keys(data).forEach(key => {
                    const element = document.getElementById(key);
                    if (element) {
                        element.value = data[key];
                    }
                });

                // Dodajemy specyficzne pole dla imienia i nazwiska
                const fullNameElement = document.getElementById('employee_name');
                if (fullNameElement) {
                    fullNameElement.value = `${data.first_name} ${data.last_name}`;
                }


                // Pozostałe pola
                const instructorNameElement = document.getElementById('instructor_name');
                if (instructorNameElement) {
                    instructorNameElement.value = data.instructor_name;
                }

                // Ustawianie dat
                const currentDate = new Date();

                const workplaceInstructionDateElement = document.getElementById('workplace_instruction_date');
                if (workplaceInstructionDateElement) {
                    workplaceInstructionDateElement.value = formatDate(currentDate, 'YYYY-MM-DD');
                }

                const generalInstructionDateElement = document.getElementById('general_instruction_date');
                if (generalInstructionDateElement) {
                    generalInstructionDateElement.value = formatDateRange(currentDate);
                }

                console.log('workplace_instruction_date:', workplaceInstructionDateElement?.value);
                console.log('general_instruction_date:', generalInstructionDateElement?.value);
            })
            .catch(error => {
                console.error('Błąd podczas pobierania danych pracownika:', error);
            });
    }

    function formatDate(date, format) {
        const day = date.getDate().toString().padStart(2, '0');
        const month = (date.getMonth() + 1).toString().padStart(2, '0');
        const year = date.getFullYear();

        return `${year}-${month}-${day}`;
    }

    function formatDateRange(date) {
        const day = date.getDate().toString().padStart(2, '0');
        const month = (date.getMonth() + 1).toString().padStart(2, '0');
        const year = date.getFullYear();

        const tomorrow = new Date(date);
        tomorrow.setDate(tomorrow.getDate() + 1);
        const tomorrowDay = tomorrow.getDate().toString().padStart(2, '0');

        return `${day}-${tomorrowDay}.${month}.${year}`;
    }

    // Obsługa podglądu dokumentu
    const previewButton = document.getElementById('previewButton');
    const previewContainer = document.getElementById('previewContainer');
    const previewFrame = document.getElementById('previewFrame');
    const templateForm = document.getElementById('templateForm');

    if (previewButton && previewContainer && previewFrame && templateForm) {
        previewButton.addEventListener('click', function (e) {
            e.preventDefault();
            console.log('Kliknięto przycisk podglądu');

            console.log('Formularz znaleziony, przygotowywanie danych');
            const formData = new FormData(templateForm);
            formData.append('action', 'preview');

            // Upewnij się, że ID szablonu jest dołączone
            const templateId = templateForm.querySelector('input[name="template_id"]')?.value;
            if (templateId) {
                formData.append('template_id', templateId);
            }

            // Dodaj obsługę pliku tła
            const backgroundImageInput = document.getElementById('background_image');
            if (backgroundImageInput && backgroundImageInput.files.length > 0) {
                formData.append('background_image', backgroundImageInput.files[0]);
            }

            fetch('/document-template/preview', {
                method: 'POST',
                body: formData
            })
                .then(response => response.blob())
                .then(blob => {
                    const url = URL.createObjectURL(blob);
                    previewFrame.src = url;
                    previewContainer.style.display = 'block';
                })
                .catch(error => {
                    console.error('Error:', error);
                    alert('Wystąpił błąd podczas generowania podglądu.');
                });
        });
    } else {
        console.log('Elementy potrzebne do podglądu nie zostały znalezione');
    }
});