document.addEventListener('DOMContentLoaded', function() {
    const filterButtons = document.querySelectorAll('.filter-btn');
    const searchInput = document.getElementById('search-input');
    const searchBtn = document.getElementById('search-btn');
    const companySelect = document.getElementById('company-select');

    filterButtons.forEach(button => {
        button.addEventListener('click', function() {
            filterButtons.forEach(btn => btn.classList.remove('active'));
            this.classList.add('active');
            updateEmployeeList();
        });
    });

    searchBtn.addEventListener('click', updateEmployeeList);
    companySelect.addEventListener('change', updateEmployeeList);

    function updateEmployeeList() {
        const filter = document.querySelector('.filter-btn.active').dataset.filter;
        const search = searchInput.value;
        const companyId = companySelect ? companySelect.value : '';

        fetch(`/employees?filter=${filter}&search=${search}&company_id=${companyId}`)
            .then(response => response.json())
            .then(data => {
                const tableBody = document.querySelector('.data-table tbody');
                tableBody.innerHTML = '';
                data.forEach(employee => {
                    const row = `
                        <tr>
                            <td data-label="Nazwisko">${employee.last_name}</td>
                            <td data-label="Imię">${employee.first_name}</td>
                            <td data-label="Telefon">${employee.phone_number}</td>
                            <td data-label="Stanowisko">${employee.position}</td>
                            <td data-label="Status">${employee.status}</td>
                            <td data-label="Firma">${employee.company_name}</td>
                            <td data-label="Akcje">
                                <a href="/employee/edit/${employee.id}" class="button">Edytuj</a>
                                <a href="/employee/details/${employee.id}" class="button">Szczegóły</a>
                            </td>
                        </tr>
                    `;
                    tableBody.innerHTML += row;
                });
            })
            .catch(error => {
                console.error('Error:', error);
            });
    }
});