<?php
define('ROOT_PATH', dirname(__DIR__));
require_once ROOT_PATH . '/app/models/model.php';
require_once ROOT_PATH . '/app/models/user.php';
require_once ROOT_PATH . '/app/models/Cost.php';
require_once ROOT_PATH . '/app/models/company.php';
require_once ROOT_PATH . '/app/models/cost_type.php';
require_once ROOT_PATH . '/config/database.php';

class CostTest {
    private $testResults = [];
    private $testCostId;

    public function runTests() {
        try {
            echo "Rozpoczynam testy modułu kosztów...\n\n";

            // Symulujemy sesję
            $_SESSION['user_id'] = 1;

            // Test funkcjonalności Cost
            $this->testGetAll();
            $this->testFiltering();
            $this->testValidation();

            $this->displayResults();

        } catch (Exception $e) {
            echo "Błąd podczas testów: " . $e->getMessage() . "\n";
        }
    }

    private function testGetAll() {
        try {
            $costs = Cost::getAll();
            $this->addResult('Pobieranie wszystkich kosztów',
                is_array($costs),
                'Pobrano listę kosztów',
                'Błąd podczas pobierania kosztów'
            );
        } catch (Exception $e) {
            $this->addResult('Pobieranie wszystkich kosztów', false, '', $e->getMessage());
        }
    }

    private function testFiltering() {
        try {
            $filters = [
                'dateFrom' => date('Y-m-d', strtotime('-1 month')),
                'dateTo' => date('Y-m-d')
            ];
            
            $costs = Cost::getFiltered($filters);
            $this->addResult('Filtrowanie kosztów',
                is_array($costs),
                'Filtrowanie działa poprawnie',
                'Błąd podczas filtrowania'
            );
        } catch (Exception $e) {
            $this->addResult('Filtrowanie kosztów', false, '', $e->getMessage());
        }
    }

    private function testValidation() {
        try {
            $testCases = [
                [
                    'data' => [
                        'amount' => -100
                    ],
                    'expectedError' => 'Firma jest wymagana'
                ],
                [
                    'data' => [
                        'company_id' => 1,
                        'amount' => -100,
                        'date' => 'invalid-date'
                    ],
                    'expectedError' => 'Kwota musi być większa od 0'
                ],
                [
                    'data' => [
                        'company_id' => 1,
                        'amount' => 100,
                        'date' => 'invalid-date'
                    ],
                    'expectedError' => 'Nieprawidłowy format daty'
                ]
            ];

            $allTestsPassed = true;
            $errors = [];

            foreach ($testCases as $index => $testCase) {
                try {
                    Cost::add($testCase['data']);
                    $allTestsPassed = false;
                    $errors[] = "Test case " . ($index + 1) . " should have failed";
                } catch (Exception $e) {
                    if (strpos($e->getMessage(), $testCase['expectedError']) === false) {
                        $allTestsPassed = false;
                        $errors[] = "Test case " . ($index + 1) . " failed with unexpected error: " . $e->getMessage();
                    }
                }
            }

            $this->addResult('Walidacja danych',
                $allTestsPassed,
                'Wszystkie przypadki testowe przeszły poprawnie',
                'Błędy walidacji: ' . implode(', ', $errors)
            );
        } catch (Exception $e) {
            $this->addResult('Walidacja danych', false, '', $e->getMessage());
        }
    }

    private function addResult($testName, $success, $successMessage, $errorMessage) {
        $this->testResults[] = [
            'name' => $testName,
            'success' => $success,
            'message' => $success ? $successMessage : $errorMessage
        ];
    }

    private function displayResults() {
        echo "\nWyniki testów:\n";
        echo "=============\n\n";

        foreach ($this->testResults as $result) {
            echo $result['name'] . ": " . 
                 ($result['success'] ? "✅ SUKCES" : "❌ BŁĄD") . 
                 "\nKomentarz: " . $result['message'] . "\n\n";
        }
    }
}

// Uruchomienie testów
$tester = new CostTest();
$tester->runTests(); 